'use strict';

const defaultI18n = require('./default-i18n-2d921004.js');

const STATE_INCLUDED_COUNTRIES = ['AU', 'BR', 'CA', 'CH', 'ES', 'HK', 'IE', 'IN', 'IT', 'JP', 'MY', 'MX', 'US'];
const POSTAL_CODE_EXCLUDED_COUNTRIES = ['HK'];
const CITY_EXCLUDED_COUNTRIES = ['SG'];
const hasPostal = (countryCode) => {
  return !POSTAL_CODE_EXCLUDED_COUNTRIES.includes(countryCode);
};
const hasCity = (countryCode) => {
  return !CITY_EXCLUDED_COUNTRIES.includes(countryCode);
};
const hasState = (countryCode) => {
  return STATE_INCLUDED_COUNTRIES.includes(countryCode);
};
const countryChoices = [
  { value: 'AF', label: defaultI18n.__('Afghanistan', 'surecart') },
  { value: 'AL', label: defaultI18n.__('Albania', 'surecart') },
  { value: 'DZ', label: defaultI18n.__('Algeria', 'surecart') },
  { value: 'AS', label: defaultI18n.__('American Samoa', 'surecart') },
  { value: 'AD', label: defaultI18n.__('Andorra', 'surecart') },
  { value: 'AO', label: defaultI18n.__('Angola', 'surecart') },
  { value: 'AI', label: defaultI18n.__('Anguilla', 'surecart') },
  { value: 'AQ', label: defaultI18n.__('Antarctica', 'surecart') },
  { value: 'AG', label: defaultI18n.__('Antigua and Barbuda', 'surecart') },
  { value: 'AR', label: defaultI18n.__('Argentina', 'surecart') },
  { value: 'AM', label: defaultI18n.__('Armenia', 'surecart') },
  { value: 'AW', label: defaultI18n.__('Aruba', 'surecart') },
  { value: 'AU', label: defaultI18n.__('Australia', 'surecart') },
  { value: 'AT', label: defaultI18n.__('Austria', 'surecart') },
  { value: 'AZ', label: defaultI18n.__('Azerbaijan', 'surecart') },
  { value: 'BS', label: defaultI18n.__('Bahamas', 'surecart') },
  { value: 'BH', label: defaultI18n.__('Bahrain', 'surecart') },
  { value: 'BD', label: defaultI18n.__('Bangladesh', 'surecart') },
  { value: 'BB', label: defaultI18n.__('Barbados', 'surecart') },
  { value: 'BY', label: defaultI18n.__('Belarus', 'surecart') },
  { value: 'BE', label: defaultI18n.__('Belgium', 'surecart') },
  { value: 'BZ', label: defaultI18n.__('Belize', 'surecart') },
  { value: 'BJ', label: defaultI18n.__('Benin', 'surecart') },
  { value: 'BM', label: defaultI18n.__('Bermuda', 'surecart') },
  { value: 'BT', label: defaultI18n.__('Bhutan', 'surecart') },
  { value: 'BO', label: defaultI18n.__('Bolivia', 'surecart') },
  { value: 'BQ', label: defaultI18n.__('Bonaire, Sint Eustatius and Saba', 'surecart') },
  { value: 'BA', label: defaultI18n.__('Bosnia and Herzegovina', 'surecart') },
  { value: 'BW', label: defaultI18n.__('Botswana', 'surecart') },
  { value: 'BV', label: defaultI18n.__('Bouvet Island', 'surecart') },
  { value: 'BR', label: defaultI18n.__('Brazil', 'surecart') },
  { value: 'IO', label: defaultI18n.__('British Indian Ocean Territory', 'surecart') },
  { value: 'BN', label: defaultI18n.__('Brunei Darussalam', 'surecart') },
  { value: 'BG', label: defaultI18n.__('Bulgaria', 'surecart') },
  { value: 'BF', label: defaultI18n.__('Burkina Faso', 'surecart') },
  { value: 'BI', label: defaultI18n.__('Burundi', 'surecart') },
  { value: 'CV', label: defaultI18n.__('Cabo Verde', 'surecart') },
  { value: 'KH', label: defaultI18n.__('Cambodia', 'surecart') },
  { value: 'CM', label: defaultI18n.__('Cameroon', 'surecart') },
  { value: 'CA', label: defaultI18n.__('Canada', 'surecart') },
  { value: 'KY', label: defaultI18n.__('Cayman Islands', 'surecart') },
  { value: 'CF', label: defaultI18n.__('Central African Republic', 'surecart') },
  { value: 'TD', label: defaultI18n.__('Chad', 'surecart') },
  { value: 'CL', label: defaultI18n.__('Chile', 'surecart') },
  { value: 'CN', label: defaultI18n.__('China', 'surecart') },
  { value: 'CX', label: defaultI18n.__('Christmas Island', 'surecart') },
  { value: 'CC', label: defaultI18n.__('Cocos (Keeling) Islands', 'surecart') },
  { value: 'CO', label: defaultI18n.__('Colombia', 'surecart') },
  { value: 'KM', label: defaultI18n.__('Comoros', 'surecart') },
  { value: 'CG', label: defaultI18n.__('Congo', 'surecart') },
  { value: 'CD', label: defaultI18n.__('Congo, The Democratic Republic of the', 'surecart') },
  { value: 'CK', label: defaultI18n.__('Cook Islands', 'surecart') },
  { value: 'CR', label: defaultI18n.__('Costa Rica', 'surecart') },
  { value: 'HR', label: defaultI18n.__('Croatia', 'surecart') },
  { value: 'CU', label: defaultI18n.__('Cuba', 'surecart') },
  { value: 'CW', label: defaultI18n.__('Curaçao', 'surecart') },
  { value: 'CY', label: defaultI18n.__('Cyprus', 'surecart') },
  { value: 'CZ', label: defaultI18n.__('Czechia', 'surecart') },
  { value: 'CI', label: defaultI18n.__("Côte d'Ivoire", 'surecart') },
  { value: 'DK', label: defaultI18n.__('Denmark', 'surecart') },
  { value: 'DJ', label: defaultI18n.__('Djibouti', 'surecart') },
  { value: 'DM', label: defaultI18n.__('Dominica', 'surecart') },
  { value: 'DO', label: defaultI18n.__('Dominican Republic', 'surecart') },
  { value: 'EC', label: defaultI18n.__('Ecuador', 'surecart') },
  { value: 'EG', label: defaultI18n.__('Egypt', 'surecart') },
  { value: 'SV', label: defaultI18n.__('El Salvador', 'surecart') },
  { value: 'GQ', label: defaultI18n.__('Equatorial Guinea', 'surecart') },
  { value: 'ER', label: defaultI18n.__('Eritrea', 'surecart') },
  { value: 'EE', label: defaultI18n.__('Estonia', 'surecart') },
  { value: 'SZ', label: defaultI18n.__('Eswatini', 'surecart') },
  { value: 'ET', label: defaultI18n.__('Ethiopia', 'surecart') },
  { value: 'FK', label: defaultI18n.__('Falkland Islands (Malvinas)', 'surecart') },
  { value: 'FO', label: defaultI18n.__('Faroe Islands', 'surecart') },
  { value: 'FJ', label: defaultI18n.__('Fiji', 'surecart') },
  { value: 'FI', label: defaultI18n.__('Finland', 'surecart') },
  { value: 'FR', label: defaultI18n.__('France', 'surecart') },
  { value: 'GF', label: defaultI18n.__('French Guiana', 'surecart') },
  { value: 'PF', label: defaultI18n.__('French Polynesia', 'surecart') },
  { value: 'TF', label: defaultI18n.__('French Southern Territories', 'surecart') },
  { value: 'GA', label: defaultI18n.__('Gabon', 'surecart') },
  { value: 'GM', label: defaultI18n.__('Gambia', 'surecart') },
  { value: 'GE', label: defaultI18n.__('Georgia', 'surecart') },
  { value: 'DE', label: defaultI18n.__('Germany', 'surecart') },
  { value: 'GH', label: defaultI18n.__('Ghana', 'surecart') },
  { value: 'GI', label: defaultI18n.__('Gibraltar', 'surecart') },
  { value: 'GR', label: defaultI18n.__('Greece', 'surecart') },
  { value: 'GL', label: defaultI18n.__('Greenland', 'surecart') },
  { value: 'GD', label: defaultI18n.__('Grenada', 'surecart') },
  { value: 'GP', label: defaultI18n.__('Guadeloupe', 'surecart') },
  { value: 'GT', label: defaultI18n.__('Guatemala', 'surecart') },
  { value: 'GG', label: defaultI18n.__('Guernsey', 'surecart') },
  { value: 'GN', label: defaultI18n.__('Guinea', 'surecart') },
  { value: 'GW', label: defaultI18n.__('Guinea-Bissau', 'surecart') },
  { value: 'GY', label: defaultI18n.__('Guyana', 'surecart') },
  { value: 'HT', label: defaultI18n.__('Haiti', 'surecart') },
  { value: 'HM', label: defaultI18n.__('Heard Island and McDonald Islands', 'surecart') },
  { value: 'VA', label: defaultI18n.__('Holy See (Vatican City State)', 'surecart') },
  { value: 'HN', label: defaultI18n.__('Honduras', 'surecart') },
  { value: 'HK', label: defaultI18n.__('Hong Kong', 'surecart') },
  { value: 'HU', label: defaultI18n.__('Hungary', 'surecart') },
  { value: 'IS', label: defaultI18n.__('Iceland', 'surecart') },
  { value: 'IN', label: defaultI18n.__('India', 'surecart') },
  { value: 'ID', label: defaultI18n.__('Indonesia', 'surecart') },
  { value: 'IR', label: defaultI18n.__('Iran, Islamic Republic of', 'surecart') },
  { value: 'IQ', label: defaultI18n.__('Iraq', 'surecart') },
  { value: 'IE', label: defaultI18n.__('Ireland', 'surecart') },
  { value: 'IM', label: defaultI18n.__('Isle of Man', 'surecart') },
  { value: 'IL', label: defaultI18n.__('Israel', 'surecart') },
  { value: 'IT', label: defaultI18n.__('Italy', 'surecart') },
  { value: 'JM', label: defaultI18n.__('Jamaica', 'surecart') },
  { value: 'JP', label: defaultI18n.__('Japan', 'surecart') },
  { value: 'JE', label: defaultI18n.__('Jersey', 'surecart') },
  { value: 'JO', label: defaultI18n.__('Jordan', 'surecart') },
  { value: 'KZ', label: defaultI18n.__('Kazakhstan', 'surecart') },
  { value: 'KE', label: defaultI18n.__('Kenya', 'surecart') },
  { value: 'KI', label: defaultI18n.__('Kiribati', 'surecart') },
  { value: 'KW', label: defaultI18n.__('Kuwait', 'surecart') },
  { value: 'KG', label: defaultI18n.__('Kyrgyzstan', 'surecart') },
  { value: 'LA', label: defaultI18n.__("Lao People's Democratic Republic", 'surecart') },
  { value: 'LV', label: defaultI18n.__('Latvia', 'surecart') },
  { value: 'LB', label: defaultI18n.__('Lebanon', 'surecart') },
  { value: 'LS', label: defaultI18n.__('Lesotho', 'surecart') },
  { value: 'LR', label: defaultI18n.__('Liberia', 'surecart') },
  { value: 'LY', label: defaultI18n.__('Libya', 'surecart') },
  { value: 'LI', label: defaultI18n.__('Liechtenstein', 'surecart') },
  { value: 'LT', label: defaultI18n.__('Lithuania', 'surecart') },
  { value: 'LU', label: defaultI18n.__('Luxembourg', 'surecart') },
  { value: 'MO', label: defaultI18n.__('Macao', 'surecart') },
  { value: 'MG', label: defaultI18n.__('Madagascar', 'surecart') },
  { value: 'MW', label: defaultI18n.__('Malawi', 'surecart') },
  { value: 'MY', label: defaultI18n.__('Malaysia', 'surecart') },
  { value: 'MV', label: defaultI18n.__('Maldives', 'surecart') },
  { value: 'ML', label: defaultI18n.__('Mali', 'surecart') },
  { value: 'MT', label: defaultI18n.__('Malta', 'surecart') },
  { value: 'MH', label: defaultI18n.__('Marshall Islands', 'surecart') },
  { value: 'MQ', label: defaultI18n.__('Martinique', 'surecart') },
  { value: 'MR', label: defaultI18n.__('Mauritania', 'surecart') },
  { value: 'MU', label: defaultI18n.__('Mauritius', 'surecart') },
  { value: 'YT', label: defaultI18n.__('Mayotte', 'surecart') },
  { value: 'MX', label: defaultI18n.__('Mexico', 'surecart') },
  { value: 'FM', label: defaultI18n.__('Micronesia, Federated States of', 'surecart') },
  { value: 'MD', label: defaultI18n.__('Moldova', 'surecart') },
  { value: 'MC', label: defaultI18n.__('Monaco', 'surecart') },
  { value: 'MN', label: defaultI18n.__('Mongolia', 'surecart') },
  { value: 'ME', label: defaultI18n.__('Montenegro', 'surecart') },
  { value: 'MS', label: defaultI18n.__('Montserrat', 'surecart') },
  { value: 'MA', label: defaultI18n.__('Morocco', 'surecart') },
  { value: 'MZ', label: defaultI18n.__('Mozambique', 'surecart') },
  { value: 'MM', label: defaultI18n.__('Myanmar', 'surecart') },
  { value: 'NA', label: defaultI18n.__('Namibia', 'surecart') },
  { value: 'NR', label: defaultI18n.__('Nauru', 'surecart') },
  { value: 'NP', label: defaultI18n.__('Nepal', 'surecart') },
  { value: 'NL', label: defaultI18n.__('Netherlands', 'surecart') },
  { value: 'NC', label: defaultI18n.__('New Caledonia', 'surecart') },
  { value: 'NZ', label: defaultI18n.__('New Zealand', 'surecart') },
  { value: 'NI', label: defaultI18n.__('Nicaragua', 'surecart') },
  { value: 'NE', label: defaultI18n.__('Niger', 'surecart') },
  { value: 'NG', label: defaultI18n.__('Nigeria', 'surecart') },
  { value: 'NU', label: defaultI18n.__('Niue', 'surecart') },
  { value: 'NF', label: defaultI18n.__('Norfolk Island', 'surecart') },
  { value: 'KP', label: defaultI18n.__('North Korea', 'surecart') },
  { value: 'MK', label: defaultI18n.__('North Macedonia', 'surecart') },
  { value: 'MP', label: defaultI18n.__('Northern Mariana Islands', 'surecart') },
  { value: 'NO', label: defaultI18n.__('Norway', 'surecart') },
  { value: 'OM', label: defaultI18n.__('Oman', 'surecart') },
  { value: 'PK', label: defaultI18n.__('Pakistan', 'surecart') },
  { value: 'PW', label: defaultI18n.__('Palau', 'surecart') },
  { value: 'PS', label: defaultI18n.__('Palestine, State of', 'surecart') },
  { value: 'PA', label: defaultI18n.__('Panama', 'surecart') },
  { value: 'PG', label: defaultI18n.__('Papua New Guinea', 'surecart') },
  { value: 'PY', label: defaultI18n.__('Paraguay', 'surecart') },
  { value: 'PE', label: defaultI18n.__('Peru', 'surecart') },
  { value: 'PH', label: defaultI18n.__('Philippines', 'surecart') },
  { value: 'PN', label: defaultI18n.__('Pitcairn', 'surecart') },
  { value: 'PL', label: defaultI18n.__('Poland', 'surecart') },
  { value: 'PT', label: defaultI18n.__('Portugal', 'surecart') },
  { value: 'QA', label: defaultI18n.__('Qatar', 'surecart') },
  { value: 'RO', label: defaultI18n.__('Romania', 'surecart') },
  { value: 'RU', label: defaultI18n.__('Russian Federation', 'surecart') },
  { value: 'RW', label: defaultI18n.__('Rwanda', 'surecart') },
  { value: 'RE', label: defaultI18n.__('Réunion', 'surecart') },
  { value: 'BL', label: defaultI18n.__('Saint Barthélemy', 'surecart') },
  { value: 'SH', label: defaultI18n.__('Saint Helena, Ascension and Tristan da Cunha', 'surecart') },
  { value: 'KN', label: defaultI18n.__('Saint Kitts and Nevis', 'surecart') },
  { value: 'LC', label: defaultI18n.__('Saint Lucia', 'surecart') },
  { value: 'MF', label: defaultI18n.__('Saint Martin (French part)', 'surecart') },
  { value: 'PM', label: defaultI18n.__('Saint Pierre and Miquelon', 'surecart') },
  { value: 'VC', label: defaultI18n.__('Saint Vincent and the Grenadines', 'surecart') },
  { value: 'WS', label: defaultI18n.__('Samoa', 'surecart') },
  { value: 'SM', label: defaultI18n.__('San Marino', 'surecart') },
  { value: 'ST', label: defaultI18n.__('Sao Tome and Principe', 'surecart') },
  { value: 'SA', label: defaultI18n.__('Saudi Arabia', 'surecart') },
  { value: 'SN', label: defaultI18n.__('Senegal', 'surecart') },
  { value: 'RS', label: defaultI18n.__('Serbia', 'surecart') },
  { value: 'SC', label: defaultI18n.__('Seychelles', 'surecart') },
  { value: 'SL', label: defaultI18n.__('Sierra Leone', 'surecart') },
  { value: 'SG', label: defaultI18n.__('Singapore', 'surecart') },
  { value: 'SX', label: defaultI18n.__('Sint Maarten (Dutch part)', 'surecart') },
  { value: 'SK', label: defaultI18n.__('Slovakia', 'surecart') },
  { value: 'SI', label: defaultI18n.__('Slovenia', 'surecart') },
  { value: 'SB', label: defaultI18n.__('Solomon Islands', 'surecart') },
  { value: 'SO', label: defaultI18n.__('Somalia', 'surecart') },
  { value: 'ZA', label: defaultI18n.__('South Africa', 'surecart') },
  { value: 'GS', label: defaultI18n.__('South Georgia and the South Sandwich Islands', 'surecart') },
  { value: 'KR', label: defaultI18n.__('South Korea', 'surecart') },
  { value: 'SS', label: defaultI18n.__('South Sudan', 'surecart') },
  { value: 'ES', label: defaultI18n.__('Spain', 'surecart') },
  { value: 'LK', label: defaultI18n.__('Sri Lanka', 'surecart') },
  { value: 'SD', label: defaultI18n.__('Sudan', 'surecart') },
  { value: 'SR', label: defaultI18n.__('Suriname', 'surecart') },
  { value: 'SJ', label: defaultI18n.__('Svalbard and Jan Mayen', 'surecart') },
  { value: 'SE', label: defaultI18n.__('Sweden', 'surecart') },
  { value: 'CH', label: defaultI18n.__('Switzerland', 'surecart') },
  { value: 'SY', label: defaultI18n.__('Syrian Arab Republic', 'surecart') },
  { value: 'TW', label: defaultI18n.__('Taiwan', 'surecart') },
  { value: 'TJ', label: defaultI18n.__('Tajikistan', 'surecart') },
  { value: 'TZ', label: defaultI18n.__('Tanzania', 'surecart') },
  { value: 'TH', label: defaultI18n.__('Thailand', 'surecart') },
  { value: 'TL', label: defaultI18n.__('Timor-Leste', 'surecart') },
  { value: 'TG', label: defaultI18n.__('Togo', 'surecart') },
  { value: 'TK', label: defaultI18n.__('Tokelau', 'surecart') },
  { value: 'TO', label: defaultI18n.__('Tonga', 'surecart') },
  { value: 'TT', label: defaultI18n.__('Trinidad and Tobago', 'surecart') },
  { value: 'TN', label: defaultI18n.__('Tunisia', 'surecart') },
  { value: 'TR', label: defaultI18n.__('Turkey', 'surecart') },
  { value: 'TM', label: defaultI18n.__('Turkmenistan', 'surecart') },
  { value: 'TC', label: defaultI18n.__('Turks and Caicos Islands', 'surecart') },
  { value: 'TV', label: defaultI18n.__('Tuvalu', 'surecart') },
  { value: 'UG', label: defaultI18n.__('Uganda', 'surecart') },
  { value: 'UA', label: defaultI18n.__('Ukraine', 'surecart') },
  { value: 'AE', label: defaultI18n.__('United Arab Emirates', 'surecart') },
  { value: 'GB', label: defaultI18n.__('United Kingdom', 'surecart') },
  { value: 'US', label: defaultI18n.__('United States', 'surecart') },
  { value: 'UM', label: defaultI18n.__('United States Minor Outlying Islands', 'surecart') },
  { value: 'UY', label: defaultI18n.__('Uruguay', 'surecart') },
  { value: 'UZ', label: defaultI18n.__('Uzbekistan', 'surecart') },
  { value: 'VU', label: defaultI18n.__('Vanuatu', 'surecart') },
  { value: 'VE', label: defaultI18n.__('Venezuela', 'surecart') },
  { value: 'VN', label: defaultI18n.__('Vietnam', 'surecart') },
  { value: 'VG', label: defaultI18n.__('Virgin Islands, British', 'surecart') },
  { value: 'VI', label: defaultI18n.__('Virgin Islands, U.S.', 'surecart') },
  { value: 'WF', label: defaultI18n.__('Wallis and Futuna', 'surecart') },
  { value: 'EH', label: defaultI18n.__('Western Sahara', 'surecart') },
  { value: 'YE', label: defaultI18n.__('Yemen', 'surecart') },
  { value: 'ZM', label: defaultI18n.__('Zambia', 'surecart') },
  { value: 'ZW', label: defaultI18n.__('Zimbabwe', 'surecart') },
  { value: 'AX', label: defaultI18n.__('Åland Islands', 'surecart') },
];

exports.countryChoices = countryChoices;
exports.hasCity = hasCity;
exports.hasPostal = hasPostal;
exports.hasState = hasState;

//# sourceMappingURL=address-3931eea0.js.map