'use strict';

const mutations = require('./mutations-65ccc5d3.js');
const mutations$1 = require('./mutations-e2dd0da5.js');
const mutations$2 = require('./mutations-8b8d18a8.js');
const index = require('./index-3f9a5d45.js');

/**
 * Clear the current checkout.
 */
const clearCheckout = () => mutations.clearCheckout(mutations.state.formId, mutations.state.mode);
/**
 * Lock the checkout (disables input and submission)
 * Pass a lock name to prevent conflicts and allow multiple locks.
 */
const lockCheckout = lockName => (mutations.state.locks = [...mutations.state.locks, lockName]);
/**
 * Unlock the checkout.
 * Pass an optional lock name to only unlock a specific lock
 */
const unLockCheckout = (lockName = '') => (mutations.state.locks = !!lockName ? mutations.state.locks.filter(name => name !== lockName) : []);
/**
 * Update the checkout line item
 */
const updateCheckoutLineItem = async ({ id, data }) => {
  try {
    mutations$1.updateFormState('FETCH');
    mutations.state.checkout = await index.updateLineItem({
      id: id,
      data,
    });
    mutations$1.updateFormState('RESOLVE');
  }
  catch (e) {
    console.error(e);
    mutations$2.createErrorNotice(e);
    mutations$1.updateFormState('REJECT');
  }
};
/**
 * Remove the checkout line item.
 */
const removeCheckoutLineItem = async (id) => {
  try {
    mutations$1.updateFormState('FETCH');
    mutations.state.checkout = await index.removeLineItem({
      checkoutId: mutations.state.checkout.id,
      itemId: id,
    });
    mutations$1.updateFormState('RESOLVE');
  }
  catch (e) {
    console.error(e);
    mutations$2.createErrorNotice(e);
    mutations$1.updateFormState('REJECT');
  }
};
/**
 * Add the checkout line item.
 */
const addCheckoutLineItem = async (data) => {
  try {
    mutations$1.updateFormState('FETCH');
    mutations.state.checkout = await index.addLineItem({
      checkout: mutations.state.checkout,
      data,
      live_mode: (mutations.state === null || mutations.state === void 0 ? void 0 : mutations.state.mode) === 'live',
    });
    mutations$1.updateFormState('RESOLVE');
  }
  catch (e) {
    console.error(e);
    mutations$2.createErrorNotice(e);
    mutations$1.updateFormState('REJECT');
  }
};

exports.addCheckoutLineItem = addCheckoutLineItem;
exports.clearCheckout = clearCheckout;
exports.lockCheckout = lockCheckout;
exports.removeCheckoutLineItem = removeCheckoutLineItem;
exports.unLockCheckout = unLockCheckout;
exports.updateCheckoutLineItem = updateCheckoutLineItem;

//# sourceMappingURL=mutations-9a574243.js.map