'use strict';

const fetch = require('./fetch-d596d349.js');
const store = require('./store-1aade79c.js');
const watchers = require('./watchers-0dfdf839.js');
const mutations = require('./mutations-8b8d18a8.js');
const defaultI18n = require('./default-i18n-2d921004.js');
const addQueryArgs = require('./add-query-args-17c551b6.js');

/**
 * External dependencies.
 */
/**
 * Update the upsell.
 */
const trackOffer = () => {
  var _a;
  return fetch.apiFetch({
    path: `surecart/v1/checkouts/${store.state.checkout_id}/offer_upsell/${(_a = store.state.upsell) === null || _a === void 0 ? void 0 : _a.id}`,
    method: 'POST',
    keepalive: true, // Important: allow the request to outlive the page.
  });
};
/**
 * Update the upsell.
 */
const preview = async () => {
  try {
    if (!store.state.checkout_id || store.state.loading === 'busy') {
      return;
    }
    store.state.loading = 'busy';
    mutations.removeNotice();
    // Add Upsell to line item.
    const { checkout, ...lineItem } = await upsellRequest({ preview: true });
    store.state.checkout = checkout;
    store.state.line_item = lineItem;
  }
  catch (error) {
    console.error(error);
    if (((error === null || error === void 0 ? void 0 : error.additional_errors) || []).find(error => { var _a, _b, _c; return (_c = (_b = (_a = error === null || error === void 0 ? void 0 : error.data) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.purchasable_statuses) === null || _c === void 0 ? void 0 : _c.includes('out_of_stock'); })) {
      return mutations.createErrorNotice({ code: 'out_of_stock', message: defaultI18n.__('Apologies, this is currently out of stock.', 'surecart') });
    }
    if (((error === null || error === void 0 ? void 0 : error.additional_errors) || []).find(error => (error === null || error === void 0 ? void 0 : error.code) === 'line_item.upsell.expired')) {
      store.state.loading = 'idle';
      mutations.createErrorNotice({ code: 'expired', message: defaultI18n.__('This offer has expired.', 'surecart') });
      return decline();
    }
    mutations.createErrorNotice(error);
  }
  finally {
    store.state.loading = 'idle';
  }
};
const accept = async () => {
  try {
    if (!store.state.checkout_id || store.state.loading === 'busy') {
      return;
    }
    store.state.loading = 'busy';
    mutations.removeNotice();
    // Add Upsell to line item.
    const { checkout } = await upsellRequest({ preview: false });
    handleCompletion(checkout);
  }
  catch (error) {
    store.state.loading = 'idle';
    mutations.createErrorNotice(error);
  }
};
/**
 * Decline the upsell.
 */
const decline = async () => {
  var _a, _b, _c, _d, _e, _f;
  try {
    if (!store.state.checkout_id || store.state.loading === 'busy') {
      return;
    }
    store.state.loading = 'busy';
    mutations.removeNotice();
    // Add Upsell to line item.
    const checkout = (await fetch.apiFetch({
      path: addQueryArgs.addQueryArgs(`surecart/v1/checkouts/${store.state.checkout_id}/decline_upsell/${(_a = store.state.upsell) === null || _a === void 0 ? void 0 : _a.id}`, {
        expand: ['checkout', 'checkout.current_upsell', 'fees'],
      }),
      method: 'POST',
      data: {
        ...(_c = watchers.state[(_b = store.state.product) === null || _b === void 0 ? void 0 : _b.id]) === null || _c === void 0 ? void 0 : _c.line_item,
        price_id: (_e = (_d = store.state.upsell) === null || _d === void 0 ? void 0 : _d.price) === null || _e === void 0 ? void 0 : _e.id,
        upsell: (_f = store.state.upsell) === null || _f === void 0 ? void 0 : _f.id,
        checkout: store.state.checkout_id,
      },
    }));
    handleCompletion(checkout);
  }
  catch (error) {
    store.state.loading = 'idle';
    mutations.createErrorNotice(error);
  }
};
/**
 * Make the request to the upsell endpoing
 */
const upsellRequest = args => {
  var _a, _b, _c, _d, _e;
  return fetch.apiFetch({
    path: addQueryArgs.addQueryArgs('surecart/v1/line_items/upsell', {
      ...args,
      expand: ['checkout', 'checkout.current_upsell', 'fees'],
    }),
    method: 'POST',
    data: {
      ...(_b = watchers.state[(_a = store.state.product) === null || _a === void 0 ? void 0 : _a.id]) === null || _b === void 0 ? void 0 : _b.line_item,
      price_id: (_d = (_c = store.state.upsell) === null || _c === void 0 ? void 0 : _c.price) === null || _d === void 0 ? void 0 : _d.id,
      upsell: (_e = store.state.upsell) === null || _e === void 0 ? void 0 : _e.id,
      checkout: store.state.checkout_id,
    },
  });
};
/**
 * Handle what to do on completion.
 */
const handleCompletion = checkout => {
  var _a, _b, _c, _d, _e;
  // There is no more upsells, or the link is the same.
  if (!((_a = checkout.current_upsell) === null || _a === void 0 ? void 0 : _a.permalink) || ((_b = checkout === null || checkout === void 0 ? void 0 : checkout.current_upsell) === null || _b === void 0 ? void 0 : _b.permalink) === ((_c = store.state.upsell) === null || _c === void 0 ? void 0 : _c.permalink)) {
    return (store.state.loading = 'complete');
  }
  // redirect to next upsell.
  store.state.loading = 'redirecting';
  window.location.assign(addQueryArgs.addQueryArgs((_d = checkout.current_upsell) === null || _d === void 0 ? void 0 : _d.permalink, {
    sc_checkout_id: (_e = store.state.checkout) === null || _e === void 0 ? void 0 : _e.id,
    sc_form_id: store.state.form_id,
  }));
};

exports.accept = accept;
exports.decline = decline;
exports.preview = preview;
exports.trackOffer = trackOffer;

//# sourceMappingURL=mutations-bb2a08ae.js.map