'use strict';

const isObject = item => item && typeof item === 'object' && !Array.isArray(item);
const getSerializedState = () => {
  const storeTag = document.querySelector(`script[type="application/json"]#sc-store-data`);
  if (!storeTag)
    return {};
  try {
    const state = JSON.parse(storeTag.textContent);
    if (isObject(state))
      return state;
    throw Error('Parsed state is not an object');
  }
  catch (e) {
    // eslint-disable-next-line no-console
    console.log(e);
  }
  return {};
};
/**
 * Is this variant option sold out.
 */
const isProductVariantOptionSoldOut = (optionNumber, option, variantValues, product) => {
  var _a, _b, _c, _d, _e;
  // product stock is not enabled or out of stock purchases are allowed.
  if (!(product === null || product === void 0 ? void 0 : product.stock_enabled) || (product === null || product === void 0 ? void 0 : product.allow_out_of_stock_purchases))
    return false;
  // if this is option 1, check to see if there are any variants with this option.
  if (optionNumber === 1) {
    const items = (_c = (_b = (((_a = product.variants) === null || _a === void 0 ? void 0 : _a.data) || [])).filter) === null || _c === void 0 ? void 0 : _c.call(_b, variant => variant.option_1 === option);
    const highestStock = Math.max(...items.map(item => item.available_stock));
    return highestStock <= 0;
  }
  // if this is option 2, check to see if there are any variants with this option and option 1
  if (optionNumber === 2) {
    const items = (((_d = product.variants) === null || _d === void 0 ? void 0 : _d.data) || []).filter(variant => (variant === null || variant === void 0 ? void 0 : variant.option_1) === variantValues.option_1 && variant.option_2 === option);
    const highestStock = Math.max(...items.map(item => item.available_stock));
    return highestStock <= 0;
  }
  // if this is option 4, check to see if there are any variants with all the options.
  const items = (((_e = product.variants) === null || _e === void 0 ? void 0 : _e.data) || []).filter(variant => (variant === null || variant === void 0 ? void 0 : variant.option_1) === variantValues.option_1 && (variant === null || variant === void 0 ? void 0 : variant.option_2) === variantValues.option_2 && variant.option_3 === option);
  const highestStock = Math.max(...items.map(item => item.available_stock));
  return highestStock <= 0;
};
/**
 * Is this variant option missing/unavailable?
 */
const isProductVariantOptionMissing = (optionNumber, option, variantValues, product) => {
  var _a, _b, _c;
  // if this is option 1, check to see if there are any variants with this option.
  if (optionNumber === 1) {
    return !(((_a = product === null || product === void 0 ? void 0 : product.variants) === null || _a === void 0 ? void 0 : _a.data) || []).some(variant => variant.option_1 === option);
  }
  // if this is option 2, check to see if there are any variants with this option and option 1
  if (optionNumber === 2) {
    return !(((_b = product === null || product === void 0 ? void 0 : product.variants) === null || _b === void 0 ? void 0 : _b.data) || []).some(variant => (variant === null || variant === void 0 ? void 0 : variant.option_1) === variantValues.option_1 && variant.option_2 === option);
  }
  // if this is option 3, check to see if there are any variants with all the options.
  return !(((_c = product === null || product === void 0 ? void 0 : product.variants) === null || _c === void 0 ? void 0 : _c.data) || []).some(variant => (variant === null || variant === void 0 ? void 0 : variant.option_1) === variantValues.option_1 && (variant === null || variant === void 0 ? void 0 : variant.option_2) === variantValues.option_2 && variant.option_3 === option);
};

exports.getSerializedState = getSerializedState;
exports.isProductVariantOptionMissing = isProductVariantOptionMissing;
exports.isProductVariantOptionSoldOut = isProductVariantOptionSoldOut;

//# sourceMappingURL=utils-a086ed6e.js.map