'use strict';

const index = require('./index-00f0fc21.js');
require('./google-909eaf44.js');
const utils = require('./utils-a086ed6e.js');
const util = require('./util-efd68af1.js');
const index$1 = require('./index-8604ebe6.js');
const defaultI18n = require('./default-i18n-2d921004.js');

/**
 * Product viewed event.
 */
const productViewed = (product, selectedPrice, quantity = 1) => {
  var _a;
  const event = new CustomEvent('scProductViewed', {
    detail: {
      id: product === null || product === void 0 ? void 0 : product.id,
      name: product === null || product === void 0 ? void 0 : product.name,
      price: selectedPrice,
      permalink: product === null || product === void 0 ? void 0 : product.permalink,
      prices: product === null || product === void 0 ? void 0 : product.prices,
      variant_options: (_a = product === null || product === void 0 ? void 0 : product.variant_options) === null || _a === void 0 ? void 0 : _a.data,
      product_collections: product === null || product === void 0 ? void 0 : product.product_collections,
      quantity,
    },
    bubbles: true,
  });
  document.dispatchEvent(event);
};

/**
 * Internal dependencies.
 */
/**
 * Available product prices
 *
 * @param {string} productId - Product ID
 *
 * @returns {Price[]} - Returns an array of prices that are not archived
 */
const availablePrices = (productId) => { var _a; return (((_a = state[productId]) === null || _a === void 0 ? void 0 : _a.prices) || []).filter(price => !(price === null || price === void 0 ? void 0 : price.archived)).sort((a, b) => (a === null || a === void 0 ? void 0 : a.position) - (b === null || b === void 0 ? void 0 : b.position)); }; // sort by position
/**
 * Get Product
 */
const getProduct = (productId) => { var _a; return (_a = state[productId]) !== null && _a !== void 0 ? _a : null; };
/**
 * Check if product label stock is enabled and not out of stock purchases are allowed.
 *
 * @returns {boolean} - Returns stock needs to be checked or not
 */
const isStockNeedsToBeChecked = (productId) => { var _a, _b, _c, _d; return !!(((_b = (_a = state === null || state === void 0 ? void 0 : state[productId]) === null || _a === void 0 ? void 0 : _a.product) === null || _b === void 0 ? void 0 : _b.stock_enabled) && !((_d = (_c = state === null || state === void 0 ? void 0 : state[productId]) === null || _c === void 0 ? void 0 : _c.product) === null || _d === void 0 ? void 0 : _d.allow_out_of_stock_purchases)); };
/**
 * Check if this option is out of stock base on the selected variant.
 */
const isOptionSoldOut = (productId, optionNumber, option) => utils.isProductVariantOptionSoldOut(optionNumber, option, state[productId].variantValues, state[productId].product);
/**
 * Check if this option is out of stock base on the selected variant.
 */
const isOptionMissing = (productId, optionNumber, option) => utils.isProductVariantOptionMissing(optionNumber, option, state[productId].variantValues, state[productId].product);
/**
 * Is product out of stock.
 *
 * @returns {boolean} - Returns true if product is out of stock
 */
const isProductOutOfStock = (productId) => {
  var _a, _b, _c, _d;
  // If stock doesn't need to be checked, product is not out of stock.
  if (!isStockNeedsToBeChecked(productId)) {
    return false;
  }
  // If no variant is selected, check against product stock.
  if (!((_b = (_a = state === null || state === void 0 ? void 0 : state[productId]) === null || _a === void 0 ? void 0 : _a.selectedVariant) === null || _b === void 0 ? void 0 : _b.id))
    return ((_c = state[productId].product) === null || _c === void 0 ? void 0 : _c.available_stock) <= 0;
  // Check against selected variant's stock.
  return ((_d = state[productId].selectedVariant) === null || _d === void 0 ? void 0 : _d.available_stock) <= 0;
};
/**
 * Is the selected variant missing.
 */
const isSelectedVariantMissing = (productId) => { var _a, _b, _c; return !!((_b = (_a = state === null || state === void 0 ? void 0 : state[productId]) === null || _a === void 0 ? void 0 : _a.variants) === null || _b === void 0 ? void 0 : _b.length) && ((_c = util.getVariantFromValues({ variants: state[productId].variants, values: state[productId].variantValues })) === null || _c === void 0 ? void 0 : _c.id) === undefined; };
/**
 * Get product default state
 *
 * @returns {ProductState} - Returns the product state
 */
const getDefaultState = () => {
  const { product: serializedProductState = {} } = utils.getSerializedState();
  return (Object.values(serializedProductState).reduce((acc, productState) => {
    const { selectedPrice, product, selectedVariant } = productState || {};
    const current = {
      ...productState,
      quantity: 1,
      total: null,
      dialog: null,
      busy: false,
      error: null,
      adHocAmount: (selectedPrice === null || selectedPrice === void 0 ? void 0 : selectedPrice.amount) || null,
      disabled: (selectedPrice === null || selectedPrice === void 0 ? void 0 : selectedPrice.archived) || (product === null || product === void 0 ? void 0 : product.archived),
      line_item: {
        price_id: selectedPrice === null || selectedPrice === void 0 ? void 0 : selectedPrice.id,
        quantity: 1,
        ...((selectedPrice === null || selectedPrice === void 0 ? void 0 : selectedPrice.ad_hoc) ? { ad_hoc_amount: selectedPrice === null || selectedPrice === void 0 ? void 0 : selectedPrice.amount } : {}),
        ...((selectedVariant === null || selectedVariant === void 0 ? void 0 : selectedVariant.id) ? { variant_id: selectedVariant === null || selectedVariant === void 0 ? void 0 : selectedVariant.id } : {}),
      },
      variantValues: {
        ...((selectedVariant === null || selectedVariant === void 0 ? void 0 : selectedVariant.option_1) ? { option_1: selectedVariant === null || selectedVariant === void 0 ? void 0 : selectedVariant.option_1 } : {}),
        ...((selectedVariant === null || selectedVariant === void 0 ? void 0 : selectedVariant.option_2) ? { option_2: selectedVariant === null || selectedVariant === void 0 ? void 0 : selectedVariant.option_2 } : {}),
        ...((selectedVariant === null || selectedVariant === void 0 ? void 0 : selectedVariant.option_3) ? { option_3: selectedVariant === null || selectedVariant === void 0 ? void 0 : selectedVariant.option_3 } : {}),
      },
    };
    acc[product.id] = current;
    return acc;
  }, {}) || {});
};
const availableSubscriptionPrices = (productId) => (availablePrices(productId) || []).filter(price => price === null || price === void 0 ? void 0 : price.recurring_interval).sort((a, b) => (a === null || a === void 0 ? void 0 : a.position) - (b === null || b === void 0 ? void 0 : b.position));
const availableNonSubscriptionPrices = (productId) => (availablePrices(productId) || []).filter(price => !(price === null || price === void 0 ? void 0 : price.recurring_interval)).sort((a, b) => (a === null || a === void 0 ? void 0 : a.position) - (b === null || b === void 0 ? void 0 : b.position));

const getters = /*#__PURE__*/Object.freeze({
  __proto__: null,
  availablePrices: availablePrices,
  getProduct: getProduct,
  isStockNeedsToBeChecked: isStockNeedsToBeChecked,
  isOptionSoldOut: isOptionSoldOut,
  isOptionMissing: isOptionMissing,
  isProductOutOfStock: isProductOutOfStock,
  isSelectedVariantMissing: isSelectedVariantMissing,
  getDefaultState: getDefaultState,
  availableSubscriptionPrices: availableSubscriptionPrices,
  availableNonSubscriptionPrices: availableNonSubscriptionPrices
});

const defaultState = getDefaultState();
Object.values(defaultState)
  .filter((stateProduct) => stateProduct === null || stateProduct === void 0 ? void 0 : stateProduct.isProductPage)
  .forEach((stateProduct) => {
  var _a;
  if ((_a = stateProduct === null || stateProduct === void 0 ? void 0 : stateProduct.product) === null || _a === void 0 ? void 0 : _a.id) {
    productViewed(stateProduct === null || stateProduct === void 0 ? void 0 : stateProduct.product, stateProduct === null || stateProduct === void 0 ? void 0 : stateProduct.selectedPrice, stateProduct === null || stateProduct === void 0 ? void 0 : stateProduct.quantity);
  }
});
const store = index.createStore(defaultState, (newValue, oldValue) => {
  return JSON.stringify(newValue) !== JSON.stringify(oldValue);
});
const { state, onChange, on, dispose, forceUpdate } = store;

/**
 * Set the product
 *
 * @param {string} productId - Product ID
 * @param {Partial<ProductState>} product - Product object
 *
 * @returns {void}
 */
const setProduct = (productId, product) => {
  if (!productId)
    return;
  state[productId] = {
    ...state[productId],
    ...product,
  };
};

/** Handle set event on products store. */
on('set', (productId, newValue, oldValue) => {
  var _a, _b, _c, _d;
  if (((_a = newValue === null || newValue === void 0 ? void 0 : newValue.selectedPrice) === null || _a === void 0 ? void 0 : _a.id) !== ((_b = oldValue === null || oldValue === void 0 ? void 0 : oldValue.selectedPrice) === null || _b === void 0 ? void 0 : _b.id)) {
    updateSelectedPrice(productId, newValue);
  }
  // if variants change, check the stock.
  if (((_c = newValue === null || newValue === void 0 ? void 0 : newValue.selectedVariant) === null || _c === void 0 ? void 0 : _c.id) !== ((_d = oldValue === null || oldValue === void 0 ? void 0 : oldValue.selectedVariant) === null || _d === void 0 ? void 0 : _d.id)) {
    handleStockWithSelectedVariant(productId);
  }
  const shouldUpdateLineItem = !oldValue || ['selectedPrice', 'adHocAmount', 'quantity', 'selectedVariant'].some(key => JSON.stringify(newValue[key]) !== JSON.stringify(oldValue[key]));
  if (shouldUpdateLineItem) {
    setLineItem(productId);
  }
  const shouldUpdateVariants = !oldValue || JSON.stringify(newValue === null || newValue === void 0 ? void 0 : newValue.variantValues) !== JSON.stringify(oldValue === null || oldValue === void 0 ? void 0 : oldValue.variantValues);
  if (shouldUpdateVariants) {
    updateSelectedVariant(productId, newValue);
  }
});
/**
 * Update the selected variant based on chosen values.
 */
const updateSelectedVariant = (productId, newValue) => {
  const matchedVariant = util.getVariantFromValues({ variants: state[productId].variants, values: newValue === null || newValue === void 0 ? void 0 : newValue.variantValues });
  if (matchedVariant) {
    setProduct(productId, { selectedVariant: matchedVariant });
  }
};
/**
 * Handle when the selected variant changes.
 */
const handleStockWithSelectedVariant = (productId) => {
  var _a, _b, _c;
  // make sure we have a selected variant and stock needs to be checked.
  if (!state[productId].selectedVariant || !isStockNeedsToBeChecked) {
    return;
  }
  // if available stock is less than the quantity, adjust the quantity to the max available.
  if (((_a = state[productId]) === null || _a === void 0 ? void 0 : _a.selectedVariant.available_stock) < ((_b = state[productId]) === null || _b === void 0 ? void 0 : _b.quantity)) {
    state[productId].quantity = ((_c = state[productId]) === null || _c === void 0 ? void 0 : _c.selectedVariant.available_stock) || 1;
    index$1.speak(defaultI18n.sprintf(defaultI18n.__('There are just %d items left in stock, and the quantity has been adjusted to %d.', 'surecart'), state[productId].quantity, state[productId].quantity), 'assertive');
  }
};
const updateSelectedPrice = (productId, newValue) => {
  var _a, _b, _c, _d;
  setProduct(productId, {
    // update the total when the selected price changes.
    total: state[productId].adHocAmount || ((_a = newValue === null || newValue === void 0 ? void 0 : newValue.selectedPrice) === null || _a === void 0 ? void 0 : _a.amount) || 0,
    // set the ad hoc amount to the selected product amount.
    adHocAmount: (_b = newValue === null || newValue === void 0 ? void 0 : newValue.selectedPrice) === null || _b === void 0 ? void 0 : _b.amount,
    // update disabled based on if price is archived or product is archived.
    disabled: ((_c = newValue === null || newValue === void 0 ? void 0 : newValue.selectedPrice) === null || _c === void 0 ? void 0 : _c.archived) || ((_d = state[productId].product) === null || _d === void 0 ? void 0 : _d.archived),
  });
};
const setLineItem = (productId) => {
  var _a, _b, _c, _d, _e, _f, _g, _h;
  setProduct(productId, {
    line_item: {
      price_id: (_b = (_a = state[productId]) === null || _a === void 0 ? void 0 : _a.selectedPrice) === null || _b === void 0 ? void 0 : _b.id,
      quantity: Math.max(((_d = (_c = state[productId]) === null || _c === void 0 ? void 0 : _c.selectedPrice) === null || _d === void 0 ? void 0 : _d.ad_hoc) ? 1 : state[productId].quantity, 1),
      ...(((_f = (_e = state[productId]) === null || _e === void 0 ? void 0 : _e.selectedPrice) === null || _f === void 0 ? void 0 : _f.ad_hoc) ? { ad_hoc_amount: (_g = state[productId]) === null || _g === void 0 ? void 0 : _g.adHocAmount } : {}),
      variant: (_h = state[productId].selectedVariant) === null || _h === void 0 ? void 0 : _h.id,
    },
  });
};

exports.availablePrices = availablePrices;
exports.dispose = dispose;
exports.forceUpdate = forceUpdate;
exports.getters = getters;
exports.isOptionMissing = isOptionMissing;
exports.isOptionSoldOut = isOptionSoldOut;
exports.isProductOutOfStock = isProductOutOfStock;
exports.isSelectedVariantMissing = isSelectedVariantMissing;
exports.on = on;
exports.onChange = onChange;
exports.setProduct = setProduct;
exports.state = state;

//# sourceMappingURL=watchers-0dfdf839.js.map