'use strict';

const mutations = require('./mutations-65ccc5d3.js');
const watchers = require('./watchers-d7bdd741.js');
const getters = require('./getters-a149dbcb.js');

/**
 * Internal dependencies.
 */
/**
 * Look through available processors and maybe switch if the processor has been removed.
 */
const maybeUpdateProcessor = () => {
  // get array of manual and regular processors ids.
  const ids = [...getters.availableProcessors().map(({ processor_type }) => processor_type), ...getters.availableManualPaymentMethods().map(({ id }) => id)];
  // selected processor is available.
  if (ids.includes(watchers.state.id))
    return;
  // set to first if we have one, otherwise unset.
  watchers.state.id = (ids === null || ids === void 0 ? void 0 : ids.length) ? ids === null || ids === void 0 ? void 0 : ids[0] : null;
};
/**
 * Look through available methods and maybe switch if the processor has been removed.
 */
const maybeUpdateMethod = () => {
  // get method ids.
  const ids = (getters.availableMethodTypes() || []).map(({ id }) => id);
  // selected method is available
  if (ids.includes(watchers.state.method))
    return;
  // if the current method is not available, set the first method.
  watchers.state.method = (ids === null || ids === void 0 ? void 0 : ids.length) ? ids === null || ids === void 0 ? void 0 : ids[0] : null;
};
// when the checkout changes, maybe update selection.
mutations.onChange('checkout', () => {
  maybeUpdateProcessor();
  maybeUpdateMethod();
});
watchers.onChange('id', () => maybeUpdateProcessor());
// when processors and methods are first loaded, select first one.
getters.onChange('processors', () => maybeUpdateProcessor());
getters.onChange('methods', () => maybeUpdateMethod());

//# sourceMappingURL=watchers-36866ca6.js.map