'use strict';

const watchers = require('./watchers-0dfdf839.js');
const getters = require('./getters-3a50490a.js');
const mutations = require('./mutations-bb2a08ae.js');
const store = require('./store-1aade79c.js');
const addQueryArgs = require('./add-query-args-17c551b6.js');

/**
 * Internal dependencies.
 */
/**
 * When line item changes, update totals.
 */
watchers.on('set', (_, newValue, oldValue) => {
  if (JSON.stringify(newValue === null || newValue === void 0 ? void 0 : newValue.line_item) !== JSON.stringify(oldValue === null || oldValue === void 0 ? void 0 : oldValue.line_item)) {
    mutations.preview();
  }
});
/**
 * Watch for upsell to expire every second.
 */
setInterval(() => {
  if (getters.isUpsellExpired()) {
    store.state.loading = 'complete';
  }
}, 1000);
/**
 * Dynamically update amount_due when line_item changes.
 */
store.onChange('line_item', () => {
  var _a, _b, _c;
  store.state.amount_due = ((_a = store.state === null || store.state === void 0 ? void 0 : store.state.line_item) === null || _a === void 0 ? void 0 : _a.total_amount) + ((_c = (_b = store.state === null || store.state === void 0 ? void 0 : store.state.line_item) === null || _b === void 0 ? void 0 : _b.trial_amount) !== null && _c !== void 0 ? _c : 0);
});
/**
 * When the upsell changes, complete or redirect.
 */
store.onChange('upsell', val => {
  var _a;
  // completed.
  if (!(val === null || val === void 0 ? void 0 : val.permalink)) {
    return (store.state.loading = 'complete');
  }
  // redirect to next upsell.
  store.state.loading = 'redirecting';
  window.location.assign(addQueryArgs.addQueryArgs(val === null || val === void 0 ? void 0 : val.permalink, {
    sc_checkout_id: (_a = store.state.checkout) === null || _a === void 0 ? void 0 : _a.id,
    sc_form_id: store.state.form_id,
  }));
});
/**
 * When the loading state changes, redirect if complete.
 */
store.onChange('loading', val => {
  if (val === 'complete') {
    const nextLink = getters.getExitUrl();
    if (!nextLink) {
      return (store.state.loading = 'complete');
    }
    store.state.loading = 'redirecting';
    window.location.assign(nextLink);
  }
});

//# sourceMappingURL=watchers-3b0f371e.js.map