'use strict';

const index = require('./index-00f0fc21.js');
const utils = require('./utils-a086ed6e.js');
const getters = require('./getters-32d40d5e.js');
const util = require('./util-efd68af1.js');
const mutations = require('./mutations-9a574243.js');
const mutations$1 = require('./mutations-65ccc5d3.js');

const { productDonation } = utils.getSerializedState();
// This gets initial checkout line items and updates the product donation store to match on load.
const productDonationData = Object.keys(productDonation || {}).reduce((acc, productId) => {
  var _a;
  const lineItem = getters.getLineItemByProductId(productId);
  if (lineItem === null || lineItem === void 0 ? void 0 : lineItem.id) {
    acc[productId] = {
      ...acc[productId],
      ...((lineItem === null || lineItem === void 0 ? void 0 : lineItem.ad_hoc_amount) ? { ad_hoc_amount: lineItem.ad_hoc_amount } : {}),
      ...((lineItem === null || lineItem === void 0 ? void 0 : lineItem.price) ? { selectedPrice: lineItem.price } : {}),
      custom_amount: ((_a = (acc[productId].amounts || [])) === null || _a === void 0 ? void 0 : _a.includes(lineItem.ad_hoc_amount)) ? null : lineItem.ad_hoc_amount,
    };
  }
  return acc;
}, productDonation);
const { state, onChange, on, set, get, dispose } = index.createStore({ ...productDonationData }, (newValue, oldValue) => {
  return JSON.stringify(newValue) !== JSON.stringify(oldValue);
});

/**
 * Get the valid ad hoc amount selected price on the product.
 */
const getValidAdHocAmount = productId => {
  const val = state[productId];
  const validAmounts = (val.amounts || []).filter(amount => util.isInRange(amount, val.selectedPrice));
  return validAmounts.includes(val === null || val === void 0 ? void 0 : val.ad_hoc_amount) ? val === null || val === void 0 ? void 0 : val.ad_hoc_amount : validAmounts[0];
};
/**
 * Get the valid ad hoc amount selected price on the product.
 */
const getInRangeAmounts = productId => {
  const val = state[productId];
  return (val.amounts || []).filter(amount => util.isInRange(amount, val.selectedPrice));
};

const updateDonationState = (productId, data) => {
  state[productId] = {
    ...state[productId],
    ...data,
  };
};
const updateLineItem = (productId, data) => {
  const lineItem = getters.getLineItemByProductId(productId);
  // we have a line item, update it
  return (lineItem === null || lineItem === void 0 ? void 0 : lineItem.id)
    ? mutations.updateCheckoutLineItem({
      id: lineItem.id,
      data: {
        ...{
          price: lineItem.price.id,
          ...((lineItem === null || lineItem === void 0 ? void 0 : lineItem.ad_hoc_amount) ? { ad_hoc_amount: lineItem === null || lineItem === void 0 ? void 0 : lineItem.ad_hoc_amount } : {}),
        },
        ...data,
      },
    })
    : mutations.addCheckoutLineItem(data);
};

// when the checkout changes, update the selected price and ad hoc amount
mutations$1.onChange('checkout', () => {
  Object.keys(state).forEach(productId => {
    var _a;
    const lineItem = getters.getLineItemByProductId(productId);
    // line item is updated, update the store
    if (lineItem) {
      return set(productId, {
        ...state[productId],
        selectedPrice: lineItem.price,
        ad_hoc_amount: lineItem.ad_hoc_amount,
        custom_amount: ((_a = (state[productId].amounts || [])) === null || _a === void 0 ? void 0 : _a.includes(lineItem.ad_hoc_amount)) ? null : lineItem.ad_hoc_amount,
      });
    }
    // line item is deleted, reset the store
    set(productId, {
      ...state[productId],
      selectedPrice: null,
      ad_hoc_amount: null,
      custom_amount: null,
    });
  });
});
// for each product
Object.keys(state).forEach(productId => {
  // when the product is updated
  on('set', (prop, val, prev) => {
    var _a, _b, _c, _d, _e, _f;
    // if the product is the one we're looking for
    if (prop !== productId)
      return;
    // It's been cleared.
    if (!(val === null || val === void 0 ? void 0 : val.selectedPrice) && !(val === null || val === void 0 ? void 0 : val.ad_hoc_amount) && !(val === null || val === void 0 ? void 0 : val.custom_amount))
      return;
    // and the selectedPrice has changed
    if (((_a = val === null || val === void 0 ? void 0 : val.selectedPrice) === null || _a === void 0 ? void 0 : _a.id) !== ((_b = prev === null || prev === void 0 ? void 0 : prev.selectedPrice) === null || _b === void 0 ? void 0 : _b.id) || (val === null || val === void 0 ? void 0 : val.ad_hoc_amount) !== (prev === null || prev === void 0 ? void 0 : prev.ad_hoc_amount) || (val === null || val === void 0 ? void 0 : val.custom_amount) !== (prev === null || prev === void 0 ? void 0 : prev.custom_amount)) {
      // use custom amount if it's in range, otherwise use the first valid amount
      const ad_hoc_amount = (val === null || val === void 0 ? void 0 : val.custom_amount) && util.isInRange(val === null || val === void 0 ? void 0 : val.custom_amount, val.selectedPrice) ? val === null || val === void 0 ? void 0 : val.custom_amount : getValidAdHocAmount(productId);
      const price = ((_c = val.selectedPrice) === null || _c === void 0 ? void 0 : _c.id) || ((_f = (_e = (_d = val.product) === null || _d === void 0 ? void 0 : _d.prices) === null || _e === void 0 ? void 0 : _e.data.find(price => price === null || price === void 0 ? void 0 : price.ad_hoc)) === null || _f === void 0 ? void 0 : _f.id);
      // if there's no price, return
      if (!price)
        return;
      // update the line item
      updateLineItem(productId, {
        price,
        quantity: 1,
        ad_hoc_amount,
      });
    }
  });
});

exports.dispose = dispose;
exports.get = get;
exports.getInRangeAmounts = getInRangeAmounts;
exports.on = on;
exports.onChange = onChange;
exports.set = set;
exports.state = state;
exports.updateDonationState = updateDonationState;

//# sourceMappingURL=watchers-3c053994.js.map