import { Fragment, h } from '@stencil/core';
import apiFetch from '../../../../functions/fetch';
import { addQueryArgs } from '@wordpress/url';
import { baseUrl } from '../../../../services/session';
import { getCheckout, setCheckout } from '@store/checkouts/mutations';
import { state as checkoutState } from '@store/checkout';
import uiStore from '@store/ui';
import { expand } from '../../../../services/session';
import { createErrorNotice } from '@store/notices/mutations';
import { updateFormState } from '@store/form/mutations';
import { formBusy } from '@store/form/getters';
export class ScCart {
  constructor() {
    this.open = null;
    this.formId = undefined;
    this.header = undefined;
    this.checkoutLink = undefined;
    this.cartTemplate = undefined;
    this.mode = 'live';
    this.checkoutUrl = undefined;
    this.alwaysShow = undefined;
    this.floatingIconEnabled = true;
    this.uiState = 'idle';
  }
  handleOpenChange() {
    var _a, _b, _c;
    uiStore.set('cart', { ...uiStore.state.cart, ...{ open: this.open } });
    if (this.open === true) {
      this.fetchOrder();
    }
    else {
      (_c = (_b = (_a = document === null || document === void 0 ? void 0 : document.querySelector('sc-cart-icon')) === null || _a === void 0 ? void 0 : _a.shadowRoot) === null || _b === void 0 ? void 0 : _b.querySelector('.cart')) === null || _c === void 0 ? void 0 : _c.focus();
    }
  }
  order() {
    return getCheckout(this.formId, this.mode);
  }
  setCheckout(data) {
    setCheckout(data, this.formId);
  }
  /**
   * Search for the sc-checkout component on a page to make sure
   * we don't show the cart on a checkout page.
   */
  pageHasForm() {
    return !!document.querySelector('sc-checkout');
  }
  /** Count the number of items in the cart. */
  getItemsCount() {
    var _a, _b;
    const items = (_b = (_a = checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.line_items) === null || _b === void 0 ? void 0 : _b.data;
    let count = 0;
    (items || []).forEach(item => {
      count = count + (item === null || item === void 0 ? void 0 : item.quantity);
    });
    return count;
  }
  handleSetState(e) {
    this.uiState = e.detail;
  }
  handleCloseCart() {
    this.open = false;
  }
  /** Fetch the order */
  async fetchOrder() {
    var _a;
    try {
      updateFormState('FETCH');
      checkoutState.checkout = (await apiFetch({
        method: 'GET',
        path: addQueryArgs(`${baseUrl}${(_a = checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.id}`, {
          expand,
        }),
      }));
      updateFormState('RESOLVE');
    }
    catch (e) {
      console.error(e);
      updateFormState('REJECT');
      createErrorNotice(e);
    }
  }
  componentWillLoad() {
    this.open = !!uiStore.state.cart.open;
    uiStore.onChange('cart', cart => {
      this.open = cart.open;
    });
  }
  state() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
    return {
      uiState: this.uiState,
      checkoutLink: this.checkoutLink,
      loading: this.uiState === 'loading',
      busy: this.uiState === 'busy',
      navigating: this.uiState === 'navigating',
      empty: !((_c = (_b = (_a = checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.line_items) === null || _b === void 0 ? void 0 : _b.pagination) === null || _c === void 0 ? void 0 : _c.count),
      order: checkoutState.checkout,
      lineItems: ((_e = (_d = checkoutState.checkout) === null || _d === void 0 ? void 0 : _d.line_items) === null || _e === void 0 ? void 0 : _e.data) || [],
      tax_status: (_f = checkoutState.checkout) === null || _f === void 0 ? void 0 : _f.tax_status,
      customerShippingAddress: typeof ((_g = checkoutState.checkout) === null || _g === void 0 ? void 0 : _g.customer) !== 'string' ? (_j = (_h = checkoutState.checkout) === null || _h === void 0 ? void 0 : _h.customer) === null || _j === void 0 ? void 0 : _j.shipping_address : {},
      shippingAddress: (_k = checkoutState.checkout) === null || _k === void 0 ? void 0 : _k.shipping_address,
      taxStatus: (_l = checkoutState.checkout) === null || _l === void 0 ? void 0 : _l.tax_status,
      formId: this.formId,
    };
  }
  render() {
    return (h("sc-cart-session-provider", null, h("sc-drawer", { open: this.open, onScAfterShow: () => (this.open = true), onScAfterHide: () => {
        this.open = false;
      } }, this.open === true && (h(Fragment, null, h("div", { class: "cart__header-suffix", slot: "header" }, h("slot", { name: "cart-header" }), h("sc-error", { style: { '--sc-alert-border-radius': '0' }, slot: "header" })), h("slot", null))), formBusy() && h("sc-block-ui", { "z-index": 9 }))));
  }
  static get is() { return "sc-cart"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-cart.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-cart.css"]
    };
  }
  static get properties() {
    return {
      "formId": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The form id to use for the cart."
        },
        "attribute": "form-id",
        "reflect": true
      },
      "header": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The header for the popout."
        },
        "attribute": "header",
        "reflect": false
      },
      "checkoutLink": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "checkout-link",
        "reflect": false
      },
      "cartTemplate": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The template for the cart to inject when opened."
        },
        "attribute": "cart-template",
        "reflect": false
      },
      "mode": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'test' | 'live'",
          "resolved": "\"live\" | \"test\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Are we in test or live mode."
        },
        "attribute": "mode",
        "reflect": false,
        "defaultValue": "'live'"
      },
      "checkoutUrl": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The checkout url for the button."
        },
        "attribute": "checkout-url",
        "reflect": false
      },
      "alwaysShow": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Should we force show the cart, even if there's a form on the page?"
        },
        "attribute": "always-show",
        "reflect": false
      },
      "floatingIconEnabled": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Whether the floating button should be visible"
        },
        "attribute": "floating-icon-enabled",
        "reflect": false,
        "defaultValue": "true"
      }
    };
  }
  static get states() {
    return {
      "open": {},
      "uiState": {}
    };
  }
  static get elementRef() { return "el"; }
  static get watchers() {
    return [{
        "propName": "open",
        "methodName": "handleOpenChange"
      }];
  }
  static get listeners() {
    return [{
        "name": "scSetState",
        "method": "handleSetState",
        "target": undefined,
        "capture": false,
        "passive": false
      }, {
        "name": "scCloseCart",
        "method": "handleCloseCart",
        "target": undefined,
        "capture": false,
        "passive": false
      }];
  }
}
//# sourceMappingURL=sc-cart.js.map
