/**
 * External dependencies.
 */
import { h, Host } from '@stencil/core';
/**
 * Internal dependencies.
 */
import { state as errorState } from '@store/notices';
import { getAdditionalErrorMessages } from '@store/notices/getters';
import { currentFormState } from '@store/form/getters';
import { onChange } from '@store/form';
import { removeNotice } from '@store/notices/mutations';
/**
 * This component listens for a confirmed event and redirects to the success url.
 */
export class ScCheckoutFormErrors {
  constructor() {
    this.removeStateListener = () => { };
  }
  /**
   * Get the alert type.
   * @returns string
   */
  getAlertType() {
    switch (errorState === null || errorState === void 0 ? void 0 : errorState.type) {
      case 'error':
        return 'danger';
      case 'default':
        return 'primary';
      default:
        return errorState === null || errorState === void 0 ? void 0 : errorState.type;
    }
  }
  componentWillLoad() {
    // remove notice if finalizing or updating.
    this.removeStateListener = onChange('formState', () => {
      if (['finalizing', 'updating'].includes(currentFormState())) {
        removeNotice();
      }
    });
  }
  disconnectedCallback() {
    this.removeStateListener();
  }
  getTopLevelError() {
    var _a;
    // checkout invalid is not friendly.
    if ((errorState === null || errorState === void 0 ? void 0 : errorState.code) === 'checkout.invalid' && ((_a = getAdditionalErrorMessages()) === null || _a === void 0 ? void 0 : _a.length)) {
      return '';
    }
    return errorState === null || errorState === void 0 ? void 0 : errorState.message;
  }
  render() {
    // don't show component if no error message or is finalizing or updating.
    if (!(errorState === null || errorState === void 0 ? void 0 : errorState.message) || ['finalizing', 'updating'].includes(currentFormState())) {
      return h(Host, { style: { display: 'none' } });
    }
    return (h(Host, null, h("sc-alert", { type: this.getAlertType(), scrollOnOpen: true, open: !!(errorState === null || errorState === void 0 ? void 0 : errorState.message), closable: !!(errorState === null || errorState === void 0 ? void 0 : errorState.dismissible) }, !!this.getTopLevelError() && h("span", { slot: "title", innerHTML: this.getTopLevelError() }), (getAdditionalErrorMessages() || []).map((message, index) => (h("div", { innerHTML: message, key: index })))), h("slot", null)));
  }
  static get is() { return "sc-checkout-form-errors"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-checkout-form-errors.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-checkout-form-errors.css"]
    };
  }
}
//# sourceMappingURL=sc-checkout-form-errors.js.map
