import { h } from '@stencil/core';
import { state as checkoutState } from '@store/checkout';
import { state as formState } from '@store/form';
import { state as userState } from '@store/user';
import { state as processorsState } from '@store/processors';
import { __ } from '@wordpress/i18n';
import { Universe } from 'stencil-wormhole';
export class ScCheckout {
  constructor() {
    this.prices = [];
    this.product = undefined;
    this.mode = 'live';
    this.formId = undefined;
    this.modified = undefined;
    this.currencyCode = 'usd';
    this.persistSession = true;
    this.successUrl = '';
    this.customer = undefined;
    this.alignment = undefined;
    this.taxProtocol = undefined;
    this.disableComponentsValidation = undefined;
    this.processors = undefined;
    this.manualPaymentMethods = undefined;
    this.editLineItems = true;
    this.removeLineItems = true;
    this.abandonedCheckoutEnabled = undefined;
    this.stripePaymentElement = false;
    this.pricesEntities = {};
    this.productsEntities = {};
    this.checkoutState = 'idle';
    this.error = undefined;
    this.processor = 'stripe';
    this.method = undefined;
    this.isManualProcessor = undefined;
    this.paymentIntents = {};
    this.isDuplicate = undefined;
  }
  handleOrderStateUpdate(e) {
    checkoutState.checkout = e.detail;
  }
  handleMethodChange(e) {
    this.method = e.detail;
  }
  handleAddEntities(e) {
    const { products, prices } = e.detail;
    // add products.
    if (Object.keys((products === null || products === void 0 ? void 0 : products.length) || {})) {
      this.productsEntities = {
        ...this.productsEntities,
        ...products,
      };
    }
    // add prices.
    if (Object.keys((prices === null || prices === void 0 ? void 0 : prices.length) || {})) {
      this.pricesEntities = {
        ...this.pricesEntities,
        ...prices,
      };
    }
  }
  /**
   * Submit the form
   */
  async submit({ skip_validation } = { skip_validation: false }) {
    if (!skip_validation) {
      await this.validate();
    }
    return await this.sessionProvider.finalize();
  }
  /**
   * Validate the form.
   */
  async validate() {
    const form = this.el.querySelector('sc-form');
    return await form.validate();
  }
  componentWillLoad() {
    const checkout = document.querySelector('sc-checkout');
    this.isDuplicate = !!checkout && checkout !== this.el;
    if (this.isDuplicate)
      return;
    Universe.create(this, this.state());
  }
  state() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x;
    return {
      processor: this.processor,
      method: this.method,
      selectedProcessorId: this.processor,
      manualPaymentMethods: this.manualPaymentMethods,
      processor_data: (_a = checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.processor_data,
      state: this.checkoutState,
      formState: formState.formState.value,
      paymentIntents: this.paymentIntents,
      successUrl: this.successUrl,
      bumps: (_c = (_b = checkoutState.checkout) === null || _b === void 0 ? void 0 : _b.recommended_bumps) === null || _c === void 0 ? void 0 : _c.data,
      order: checkoutState.checkout,
      abandonedCheckoutEnabled: (_d = checkoutState.checkout) === null || _d === void 0 ? void 0 : _d.abandoned_checkout_enabled,
      checkout: checkoutState.checkout,
      shippingEnabled: (_e = checkoutState.checkout) === null || _e === void 0 ? void 0 : _e.shipping_enabled,
      lineItems: ((_g = (_f = checkoutState.checkout) === null || _f === void 0 ? void 0 : _f.line_items) === null || _g === void 0 ? void 0 : _g.data) || [],
      editLineItems: this.editLineItems,
      removeLineItems: this.removeLineItems,
      // checkout states
      loading: formState.formState.value === 'loading',
      busy: ['updating', 'finalizing', 'paying', 'confirming'].includes(formState.formState.value),
      paying: ['finalizing', 'paying', 'confirming'].includes(formState.formState.value),
      empty: !['loading', 'updating'].includes(formState.formState.value) && !((_k = (_j = (_h = checkoutState.checkout) === null || _h === void 0 ? void 0 : _h.line_items) === null || _j === void 0 ? void 0 : _j.pagination) === null || _k === void 0 ? void 0 : _k.count),
      // checkout states
      // stripe.
      stripePaymentElement: processorsState.config.stripe.paymentElement,
      stripePaymentIntent: (((_m = (_l = checkoutState.checkout) === null || _l === void 0 ? void 0 : _l.staged_payment_intents) === null || _m === void 0 ? void 0 : _m.data) || []).find(intent => intent.processor_type === 'stripe'),
      error: this.error,
      customer: this.customer,
      tax_status: (_o = checkoutState.checkout) === null || _o === void 0 ? void 0 : _o.tax_status,
      taxEnabled: (_p = checkoutState.checkout) === null || _p === void 0 ? void 0 : _p.tax_enabled,
      customerShippingAddress: typeof ((_q = checkoutState.checkout) === null || _q === void 0 ? void 0 : _q.customer) !== 'string' ? (_s = (_r = checkoutState.checkout) === null || _r === void 0 ? void 0 : _r.customer) === null || _s === void 0 ? void 0 : _s.shipping_address : {},
      shippingAddress: (_t = checkoutState.checkout) === null || _t === void 0 ? void 0 : _t.shipping_address,
      taxStatus: (_u = checkoutState.checkout) === null || _u === void 0 ? void 0 : _u.tax_status,
      taxIdentifier: (_v = checkoutState.checkout) === null || _v === void 0 ? void 0 : _v.tax_identifier,
      totalAmount: (_w = checkoutState.checkout) === null || _w === void 0 ? void 0 : _w.total_amount,
      taxProtocol: this.taxProtocol,
      lockedChoices: this.prices,
      products: this.productsEntities,
      prices: this.pricesEntities,
      country: 'US',
      loggedIn: userState.loggedIn,
      emailExists: (_x = checkoutState.checkout) === null || _x === void 0 ? void 0 : _x.email_exists,
      formId: checkoutState.formId,
      mode: checkoutState.mode,
      currencyCode: checkoutState.currencyCode,
    };
  }
  render() {
    if (this.isDuplicate) {
      return h("sc-alert", { open: true }, __('Due to processor restrictions, only one checkout form is allowed on the page.', 'surecart'));
    }
    return (h("div", { class: {
        'sc-checkout-container': true,
        'sc-align-center': this.alignment === 'center',
        'sc-align-wide': this.alignment === 'wide',
        'sc-align-full': this.alignment === 'full',
      } }, h("sc-checkout-unsaved-changes-warning", { state: this.checkoutState }), checkoutState.validateStock && h("sc-checkout-stock-alert", null), h(Universe.Provider, { state: this.state() }, h("sc-login-provider", { loggedIn: userState.loggedIn, onScSetCustomer: e => (this.customer = e.detail), onScSetLoggedIn: e => (userState.loggedIn = e.detail), order: checkoutState.checkout }, h("sc-form-state-provider", { onScSetCheckoutFormState: e => (this.checkoutState = e.detail) }, h("sc-form-error-provider", null, h("sc-form-components-validator", { disabled: this.disableComponentsValidation, taxProtocol: checkoutState.taxProtocol }, h("sc-order-confirm-provider", { "checkout-status": formState.formState.value, "success-url": this.successUrl }, h("sc-session-provider", { ref: el => (this.sessionProvider = el), prices: this.prices, persist: this.persistSession }, h("slot", null))))))), this.state().busy && h("sc-block-ui", { class: "busy-block-ui", style: { 'z-index': '30' } }), ['finalizing', 'paying', 'confirming', 'confirmed', 'redirecting'].includes(formState.formState.value) && (h("sc-block-ui", { spinner: true, style: { '--sc-block-ui-opacity': '0.75', 'z-index': '30' } }, formState.text.loading[formState.formState.value] || __('Processing payment...', 'surecart'))))));
  }
  static get is() { return "sc-checkout"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-checkout.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-checkout.css"]
    };
  }
  static get properties() {
    return {
      "prices": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Array<PriceChoice>",
          "resolved": "PriceChoice[]",
          "references": {
            "Array": {
              "location": "global"
            },
            "PriceChoice": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "An array of prices to pre-fill in the form."
        },
        "defaultValue": "[]"
      },
      "product": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Product",
          "resolved": "Product",
          "references": {
            "Product": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "A product to pre-fill the form."
        }
      },
      "mode": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'test' | 'live'",
          "resolved": "\"live\" | \"test\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Are we in test or live mode."
        },
        "attribute": "mode",
        "reflect": false,
        "defaultValue": "'live'"
      },
      "formId": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The checkout form id"
        },
        "attribute": "form-id",
        "reflect": false
      },
      "modified": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "When the form was modified."
        },
        "attribute": "modified",
        "reflect": false
      },
      "currencyCode": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Currency to use for this checkout."
        },
        "attribute": "currency-code",
        "reflect": false,
        "defaultValue": "'usd'"
      },
      "persistSession": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Whether to persist the session in the browser between visits."
        },
        "attribute": "persist-session",
        "reflect": false,
        "defaultValue": "true"
      },
      "successUrl": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Where to go on success"
        },
        "attribute": "success-url",
        "reflect": false,
        "defaultValue": "''"
      },
      "customer": {
        "type": "unknown",
        "mutable": true,
        "complexType": {
          "original": "Customer",
          "resolved": "Customer",
          "references": {
            "Customer": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Stores the current customer"
        }
      },
      "alignment": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'center' | 'wide' | 'full'",
          "resolved": "\"center\" | \"full\" | \"wide\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Alignment"
        },
        "attribute": "alignment",
        "reflect": false
      },
      "taxProtocol": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "TaxProtocol",
          "resolved": "TaxProtocol",
          "references": {
            "TaxProtocol": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The account tax protocol"
        }
      },
      "disableComponentsValidation": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Should we disable components validation"
        },
        "attribute": "disable-components-validation",
        "reflect": false
      },
      "processors": {
        "type": "unknown",
        "mutable": true,
        "complexType": {
          "original": "Processor[]",
          "resolved": "Processor[]",
          "references": {
            "Processor": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Processors enabled for this form."
        }
      },
      "manualPaymentMethods": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "ManualPaymentMethod[]",
          "resolved": "ManualPaymentMethod[]",
          "references": {
            "ManualPaymentMethod": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Manual payment methods enabled for this form."
        }
      },
      "editLineItems": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Can we edit line items?"
        },
        "attribute": "edit-line-items",
        "reflect": false,
        "defaultValue": "true"
      },
      "removeLineItems": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Can we remove line items?"
        },
        "attribute": "remove-line-items",
        "reflect": false,
        "defaultValue": "true"
      },
      "abandonedCheckoutEnabled": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Is abandoned checkout enabled."
        },
        "attribute": "abandoned-checkout-enabled",
        "reflect": false
      },
      "stripePaymentElement": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Use the Stripe payment element."
        },
        "attribute": "stripe-payment-element",
        "reflect": false,
        "defaultValue": "false"
      }
    };
  }
  static get states() {
    return {
      "pricesEntities": {},
      "productsEntities": {},
      "checkoutState": {},
      "error": {},
      "processor": {},
      "method": {},
      "isManualProcessor": {},
      "paymentIntents": {},
      "isDuplicate": {}
    };
  }
  static get events() {
    return [{
        "method": "scOrderUpdated",
        "name": "scOrderUpdated",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Checkout has been updated."
        },
        "complexType": {
          "original": "Checkout",
          "resolved": "Checkout",
          "references": {
            "Checkout": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        }
      }, {
        "method": "scOrderFinalized",
        "name": "scOrderFinalized",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Checkout has been finalized."
        },
        "complexType": {
          "original": "Checkout",
          "resolved": "Checkout",
          "references": {
            "Checkout": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        }
      }, {
        "method": "scOrderError",
        "name": "scOrderError",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Checkout has an error."
        },
        "complexType": {
          "original": "ResponseError",
          "resolved": "ResponseError",
          "references": {
            "ResponseError": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        }
      }];
  }
  static get methods() {
    return {
      "submit": {
        "complexType": {
          "signature": "({ skip_validation }?: { skip_validation: boolean; }) => Promise<Checkout | NodeJS.Timeout | Error>",
          "parameters": [{
              "tags": [],
              "text": ""
            }],
          "references": {
            "Promise": {
              "location": "global"
            },
            "Checkout": {
              "location": "import",
              "path": "../../../../types"
            },
            "NodeJS": {
              "location": "global"
            },
            "Error": {
              "location": "global"
            }
          },
          "return": "Promise<Checkout | Timeout | Error>"
        },
        "docs": {
          "text": "Submit the form",
          "tags": []
        }
      },
      "validate": {
        "complexType": {
          "signature": "() => Promise<boolean>",
          "parameters": [],
          "references": {
            "Promise": {
              "location": "global"
            },
            "HTMLScFormElement": {
              "location": "global"
            }
          },
          "return": "Promise<boolean>"
        },
        "docs": {
          "text": "Validate the form.",
          "tags": []
        }
      }
    };
  }
  static get elementRef() { return "el"; }
  static get listeners() {
    return [{
        "name": "scUpdateOrderState",
        "method": "handleOrderStateUpdate",
        "target": undefined,
        "capture": false,
        "passive": false
      }, {
        "name": "scSetMethod",
        "method": "handleMethodChange",
        "target": undefined,
        "capture": false,
        "passive": false
      }, {
        "name": "scAddEntities",
        "method": "handleAddEntities",
        "target": undefined,
        "capture": false,
        "passive": false
      }];
  }
}
//# sourceMappingURL=sc-checkout.js.map
