import { Host, h } from '@stencil/core';
import { getProcessorByType } from '@store/processors/getters';
import { formBusy } from '@store/form/getters';
export class ScExpressPayment {
  constructor() {
    this.processor = undefined;
    this.dividerText = undefined;
    this.debug = undefined;
    this.hasPaymentOptions = undefined;
  }
  onPaymentRequestLoaded() {
    this.hasPaymentOptions = true;
  }
  renderStripePaymentRequest() {
    const { processor_data } = getProcessorByType('stripe') || {};
    return h("sc-stripe-payment-request", { debug: this.debug, stripeAccountId: processor_data === null || processor_data === void 0 ? void 0 : processor_data.account_id, publishableKey: processor_data === null || processor_data === void 0 ? void 0 : processor_data.publishable_key });
  }
  render() {
    return (h(Host, { class: { 'is-empty': !this.hasPaymentOptions && !this.debug } }, this.renderStripePaymentRequest(), (this.hasPaymentOptions || this.debug) && h("sc-divider", { style: { '--spacing': 'calc(var(--sc-form-row-spacing)/2)' } }, this.dividerText), !!formBusy() && h("sc-block-ui", null)));
  }
  static get is() { return "sc-express-payment"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-express-payment.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-express-payment.css"]
    };
  }
  static get properties() {
    return {
      "processor": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "ProcessorName",
          "resolved": "\"paypal\" | \"paypal-card\" | \"stripe\"",
          "references": {
            "ProcessorName": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "processor",
        "reflect": false
      },
      "dividerText": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "divider-text",
        "reflect": false
      },
      "debug": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "debug",
        "reflect": false
      },
      "hasPaymentOptions": {
        "type": "boolean",
        "mutable": true,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "has-payment-options",
        "reflect": false
      }
    };
  }
  static get listeners() {
    return [{
        "name": "scPaymentRequestLoaded",
        "method": "onPaymentRequestLoaded",
        "target": undefined,
        "capture": false,
        "passive": false
      }];
  }
}
//# sourceMappingURL=sc-express-payment.js.map
