import { Fragment, h } from '@stencil/core';
import { checkoutIsLocked } from '@store/checkout/getters';
import { availableProcessors } from '@store/processors/getters';
import { state as selectedProcessor } from '@store/selected-processor';
import { state as checkoutState } from '@store/checkout';
import { __ } from '@wordpress/i18n';
import { openWormhole } from 'stencil-wormhole';
import { getProcessorData } from '../../../../functions/processor';
import { formBusy } from '@store/form/getters';
export class ScOrderSubmit {
  constructor() {
    this.loading = undefined;
    this.paying = undefined;
    this.type = 'primary';
    this.size = 'medium';
    this.full = true;
    this.icon = undefined;
    this.showTotal = undefined;
    this.processors = undefined;
    this.order = undefined;
    this.currencyCode = 'usd';
    this.processor = undefined;
    this.secureNoticeText = undefined;
    this.secureNotice = true;
  }
  cannotShipToLocation() {
    var _a, _b;
    return ((_a = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.selected_shipping_choice_required) && !((_b = checkoutState.checkout) === null || _b === void 0 ? void 0 : _b.selected_shipping_choice);
  }
  renderPayPalButton(buttons) {
    const { client_id, account_id, merchant_initiated_enabled } = getProcessorData(availableProcessors(), 'paypal', checkoutState.mode);
    if (!client_id && !account_id)
      return null;
    return (h("sc-paypal-buttons", { buttons: buttons, busy: formBusy() || checkoutIsLocked(), mode: checkoutState.mode, order: checkoutState.checkout, merchantInitiated: merchant_initiated_enabled, "currency-code": checkoutState.currencyCode, "client-id": client_id, "merchant-id": account_id, label: "checkout", color: "blue" }));
  }
  render() {
    if (this.cannotShipToLocation() || checkoutIsLocked('OUT_OF_STOCK')) {
      return (h("sc-button", { type: this.type, size: this.size, full: this.full, loading: this.loading || this.paying, disabled: true }, !!this.icon && h("sc-icon", { name: this.icon, slot: "prefix", "aria-hidden": "true" }), h("slot", null, __('Purchase', 'surecart')), this.showTotal && (h("span", null, '\u00A0', h("sc-total", null))), h("sc-visually-hidden", null, " ", __('Press enter to purchase', 'surecart'))));
    }
    return (h(Fragment, null, selectedProcessor.id === 'paypal' && !(selectedProcessor === null || selectedProcessor === void 0 ? void 0 : selectedProcessor.method) && this.renderPayPalButton(['paypal']), selectedProcessor.id === 'paypal' && (selectedProcessor === null || selectedProcessor === void 0 ? void 0 : selectedProcessor.method) === 'card' && this.renderPayPalButton(['card']), h("sc-button", { hidden: ['paypal', 'paypal-card'].includes(selectedProcessor.id), submit: true, type: this.type, size: this.size, full: this.full, loading: this.loading || this.paying, disabled: this.loading || this.paying || formBusy() || checkoutIsLocked() || this.cannotShipToLocation() }, !!this.icon && h("sc-icon", { name: this.icon, slot: "prefix", "aria-hidden": "true" }), h("slot", null, __('Purchase', 'surecart')), this.showTotal && (h("span", null, '\u00A0', h("sc-total", null))), h("sc-visually-hidden", null, " ", __('Press enter to purchase', 'surecart'))), this.secureNotice && location.protocol === 'https:' && (h("div", { class: "sc-secure-notice" }, h("sc-secure-notice", null, this.secureNoticeText || __('This is a secure, encrypted payment.', 'surecart'))))));
  }
  static get is() { return "sc-order-submit"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-order-submit.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-order-submit.css"]
    };
  }
  static get properties() {
    return {
      "loading": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Is the order loading."
        },
        "attribute": "loading",
        "reflect": false
      },
      "paying": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Is the order paying."
        },
        "attribute": "paying",
        "reflect": false
      },
      "type": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'default' | 'primary' | 'success' | 'info' | 'warning' | 'danger' | 'text' | 'link'",
          "resolved": "\"danger\" | \"default\" | \"info\" | \"link\" | \"primary\" | \"success\" | \"text\" | \"warning\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The button type."
        },
        "attribute": "type",
        "reflect": true,
        "defaultValue": "'primary'"
      },
      "size": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'small' | 'medium' | 'large'",
          "resolved": "\"large\" | \"medium\" | \"small\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The button's size."
        },
        "attribute": "size",
        "reflect": true,
        "defaultValue": "'medium'"
      },
      "full": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Show a full-width button."
        },
        "attribute": "full",
        "reflect": false,
        "defaultValue": "true"
      },
      "icon": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Icon to show."
        },
        "attribute": "icon",
        "reflect": false
      },
      "showTotal": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Show the total."
        },
        "attribute": "show-total",
        "reflect": false
      },
      "processors": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Processor[]",
          "resolved": "Processor[]",
          "references": {
            "Processor": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Keys and secrets for processors."
        }
      },
      "order": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Checkout",
          "resolved": "Checkout",
          "references": {
            "Checkout": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The current order."
        }
      },
      "currencyCode": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Currency Code"
        },
        "attribute": "currency-code",
        "reflect": false,
        "defaultValue": "'usd'"
      },
      "processor": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "ProcessorName",
          "resolved": "\"paypal\" | \"paypal-card\" | \"stripe\"",
          "references": {
            "ProcessorName": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The selected processor."
        },
        "attribute": "processor",
        "reflect": false
      },
      "secureNoticeText": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Secure"
        },
        "attribute": "secure-notice-text",
        "reflect": false
      },
      "secureNotice": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Show the secure notice"
        },
        "attribute": "secure-notice",
        "reflect": false,
        "defaultValue": "true"
      }
    };
  }
}
openWormhole(ScOrderSubmit, ['loading', 'paying', 'processors', 'processor', 'currencyCode', 'order'], false);
//# sourceMappingURL=sc-order-submit.js.map
