/**
 * External dependencies.
 */
import PaystackPop from '@paystack/inline-js';
import { __, sprintf } from '@wordpress/i18n';
/**
 * Internal dependencies.
 */
import { state as checkoutState } from '@store/checkout';
import { state as selectedProcessor } from '@store/selected-processor';
import { onChange as onChangeFormState } from '@store/form';
import { currentFormState } from '@store/form/getters';
import { updateFormState } from '@store/form/mutations';
import { createErrorNotice } from '@store/notices/mutations';
export class ScCheckoutPaystackPaymentProvider {
  componentWillLoad() {
    // we need to listen to the form state and pay when the form state enters the paying state.
    this.unlistenToFormState = onChangeFormState('formState', () => {
      // are we paying?
      if ('paying' === currentFormState()) {
        this.confirm();
      }
    });
  }
  disconnectedCallback() {
    this.unlistenToFormState();
  }
  async confirm() {
    var _a, _b, _c, _d;
    // this processor is not selected.
    if ((selectedProcessor === null || selectedProcessor === void 0 ? void 0 : selectedProcessor.id) !== 'paystack')
      return;
    // Must be a paystack session
    if (!((_b = (_a = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.payment_intent) === null || _b === void 0 ? void 0 : _b.processor_data.paystack))
      return;
    // Prevent if already paid.
    if (((_c = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _c === void 0 ? void 0 : _c.status) === 'paid')
      return;
    try {
      // must have a public key and access code.
      const { public_key, access_code } = (_d = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _d === void 0 ? void 0 : _d.payment_intent.processor_data.paystack;
      if (!public_key || !access_code) {
        createErrorNotice({ message: sprintf(__('Payment gateway configuration incomplete. Please ensure Paystack is properly configured for transactions.', 'surecart')) });
        return;
      }
      const paystack = new PaystackPop();
      await paystack.newTransaction({
        key: public_key,
        accessCode: access_code,
        onSuccess: async (transaction) => {
          if ((transaction === null || transaction === void 0 ? void 0 : transaction.status) !== 'success') {
            throw { message: sprintf(__('Paystack transaction could not be finished. Status: %s', 'surecart'), transaction === null || transaction === void 0 ? void 0 : transaction.status) };
          }
          return updateFormState('PAID');
        },
        onClose: () => updateFormState('REJECT'),
      });
    }
    catch (err) {
      createErrorNotice(err);
      console.error(err);
      updateFormState('REJECT');
    }
  }
  static get is() { return "sc-checkout-paystack-payment-provider"; }
  static get encapsulation() { return "shadow"; }
}
//# sourceMappingURL=sc-checkout-paystack-payment-provider.js.map
