import { Fragment } from '@stencil/core';
import { h } from '@stencil/core';
import { __, sprintf } from '@wordpress/i18n';
import { getLineItemByProductId } from '@store/checkout/getters';
import { state as checkoutState, onChange } from '@store/checkout';
import { getVariantFromValues } from '../../../../functions/util';
import { addLineItem, updateLineItem } from '@services/session';
import { updateFormState } from '@store/form/mutations';
import { createErrorNotice } from '@store/notices/mutations';
import { isProductVariantOptionMissing, isProductVariantOptionSoldOut } from '@store/utils';
export class ScProductCheckoutSelectVariantOption {
  constructor() {
    this.product = undefined;
    this.label = undefined;
    this.selectorTitle = undefined;
    this.selectedVariant = undefined;
    this.selectedPrice = undefined;
    this.option1 = undefined;
    this.option2 = undefined;
    this.option3 = undefined;
  }
  /** When option values are selected, attempt to find a matching variant. */
  handleOptionChange() {
    var _a, _b;
    this.selectedVariant = getVariantFromValues({
      variants: (_b = (_a = this.product) === null || _a === void 0 ? void 0 : _a.variants) === null || _b === void 0 ? void 0 : _b.data,
      values: {
        ...(this.option1 ? { option_1: this.option1 } : {}),
        ...(this.option2 ? { option_2: this.option2 } : {}),
        ...(this.option3 ? { option_3: this.option3 } : {}),
      },
    });
  }
  /**
   * Is the selected variant out of stock?
   * @returns {boolean} Whether the selected variant is out of stock.
   */
  isSelectedVariantOutOfStock() {
    var _a, _b;
    return ((_a = this.product) === null || _a === void 0 ? void 0 : _a.stock_enabled) && this.hasVariants() && !((_b = this.product) === null || _b === void 0 ? void 0 : _b.allow_out_of_stock_purchases) && this.selectedVariant.available_stock < 1;
  }
  /**
   * Do we have the required selected variant?
   * @returns {boolean} Whether the product has a required variant and it is not selected.
   */
  hasRequiredSelectedVariant() {
    var _a;
    if (!this.hasVariants()) {
      return true;
    }
    return (_a = this.selectedVariant) === null || _a === void 0 ? void 0 : _a.id;
  }
  async reportValidity() {
    this.input.setCustomValidity('');
    if (!this.hasVariants()) {
      return this.input.reportValidity();
    }
    // We don't have a required selected variant.
    if (!this.hasRequiredSelectedVariant()) {
      this.input.setCustomValidity(__('Please choose an available option.', 'surecart'));
      return this.input.reportValidity();
    }
    // don't let the person checkout with an out of stock selection.
    if (this.isSelectedVariantOutOfStock()) {
      this.input.setCustomValidity(__('This selection is not available.', 'surecart'));
      return this.input.reportValidity();
    }
    return this.input.reportValidity();
  }
  getSelectedPrice() {
    var _a, _b, _c, _d, _e;
    if (((_c = (_b = (_a = this.product) === null || _a === void 0 ? void 0 : _a.prices) === null || _b === void 0 ? void 0 : _b.data) === null || _c === void 0 ? void 0 : _c.length) === 1) {
      return (_e = (_d = this.product) === null || _d === void 0 ? void 0 : _d.prices) === null || _e === void 0 ? void 0 : _e.data[0];
    }
    return this.selectedPrice;
  }
  /** When selected variant and selected price are set, we can update the checkout. */
  async updateLineItems() {
    var _a, _b, _c, _d, _e;
    const selectedPrice = this.getSelectedPrice();
    // We need a price.
    if (!(selectedPrice === null || selectedPrice === void 0 ? void 0 : selectedPrice.id))
      return;
    // get the existing line item.
    const lineItem = this.lineItem();
    // no changes.
    if (((_a = lineItem === null || lineItem === void 0 ? void 0 : lineItem.price) === null || _a === void 0 ? void 0 : _a.id) === (selectedPrice === null || selectedPrice === void 0 ? void 0 : selectedPrice.id) && ((_b = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _b === void 0 ? void 0 : _b.id) === ((_c = this.selectedVariant) === null || _c === void 0 ? void 0 : _c.id))
      return;
    // We need a selected variant if this product has variants.
    if (!this.hasRequiredSelectedVariant())
      return;
    // Don't let the person checkout with an out of stock selection.
    if (this.isSelectedVariantOutOfStock())
      return;
    // create or update the
    try {
      updateFormState('FETCH');
      if (lineItem === null || lineItem === void 0 ? void 0 : lineItem.id) {
        checkoutState.checkout = await updateLineItem({
          id: lineItem === null || lineItem === void 0 ? void 0 : lineItem.id,
          data: {
            variant: (_d = this.selectedVariant) === null || _d === void 0 ? void 0 : _d.id,
            price: selectedPrice === null || selectedPrice === void 0 ? void 0 : selectedPrice.id,
            quantity: 1,
          },
        });
      }
      else {
        checkoutState.checkout = await addLineItem({
          checkout: checkoutState.checkout,
          data: {
            variant: (_e = this.selectedVariant) === null || _e === void 0 ? void 0 : _e.id,
            price: selectedPrice === null || selectedPrice === void 0 ? void 0 : selectedPrice.id,
            quantity: 1,
          },
        });
      }
      updateFormState('RESOLVE');
    }
    catch (e) {
      console.error(e);
      createErrorNotice(e);
      updateFormState('REJECT');
    }
  }
  componentWillLoad() {
    // when checkout changes, update the selected variant and price.
    this.removeListener = onChange('checkout', () => {
      var _a, _b, _c;
      const lineItem = this.lineItem();
      this.selectedVariant = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant;
      this.selectedPrice = lineItem === null || lineItem === void 0 ? void 0 : lineItem.price;
      this.option1 = (_a = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _a === void 0 ? void 0 : _a.option_1;
      this.option2 = (_b = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _b === void 0 ? void 0 : _b.option_2;
      this.option3 = (_c = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _c === void 0 ? void 0 : _c.option_3;
    });
  }
  // remove listener to prevent leaks.
  disconnectedCallback() {
    this.removeListener();
  }
  // get the line item by product id.
  lineItem() {
    var _a;
    return getLineItemByProductId((_a = this.product) === null || _a === void 0 ? void 0 : _a.id);
  }
  hasVariants() {
    var _a, _b, _c;
    return ((_c = (_b = (_a = this.product) === null || _a === void 0 ? void 0 : _a.variants) === null || _b === void 0 ? void 0 : _b.data) === null || _c === void 0 ? void 0 : _c.length) > 0;
  }
  render() {
    var _a, _b, _c, _d, _e;
    return (h("sc-form-control", { class: "sc-checkout-product-price-variant-selector", label: this.selectorTitle }, (this.product.variant_options.data || []).map(({ name, values }, index) => (h("sc-form-control", { label: name }, h("div", { class: "sc-checkout-product-price-variant-selector__pills-wrapper" }, (values || []).map(value => {
      const args = [
        index + 1,
        value,
        {
          ...(this.option1 ? { option_1: this.option1 } : {}),
          ...(this.option2 ? { option_2: this.option2 } : {}),
          ...(this.option3 ? { option_3: this.option3 } : {}),
        },
        this.product,
      ];
      const isUnavailable = isProductVariantOptionSoldOut.apply(void 0, args) || isProductVariantOptionMissing.apply(void 0, args);
      return (h("sc-pill-option", { isUnavailable: isUnavailable, isSelected: this[`option${index + 1}`] === value, onClick: () => (this[`option${index + 1}`] = value) }, h("span", { "aria-hidden": "true" }, value), h("sc-visually-hidden", null, sprintf(__('Select %s: %s', 'surecart'), name, value), isUnavailable && h(Fragment, null, " ", __('(option unavailable)', 'surecart')))));
    }))))), ((_c = (_b = (_a = this.product) === null || _a === void 0 ? void 0 : _a.prices) === null || _b === void 0 ? void 0 : _b.data) === null || _c === void 0 ? void 0 : _c.length) > 1 && (h("sc-form-control", { label: !!((_d = this.product.variant_options.data) === null || _d === void 0 ? void 0 : _d.length) ? this.label : null }, h("sc-choices", null, (this.product.prices.data || [])
      .sort((a, b) => (a === null || a === void 0 ? void 0 : a.position) - (b === null || b === void 0 ? void 0 : b.position))
      .map(price => {
      var _a, _b, _c;
      return (h("sc-price-choice-container", { required: true, price: price, label: (price === null || price === void 0 ? void 0 : price.name) || ((_a = this.product) === null || _a === void 0 ? void 0 : _a.name), checked: ((_c = (_b = this.lineItem()) === null || _b === void 0 ? void 0 : _b.price) === null || _c === void 0 ? void 0 : _c.id) === (price === null || price === void 0 ? void 0 : price.id), onScChange: e => {
          if (e.target.checked) {
            this.selectedPrice = price;
          }
        } }));
    })))), h("input", { class: "sc-checkout-product-price-variant-selector__hidden-input", ref: el => (this.input = el), value: (_e = this.selectedVariant) === null || _e === void 0 ? void 0 : _e.id })));
  }
  static get is() { return "sc-checkout-product-price-variant-selector"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-checkout-product-price-variant-selector.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-checkout-product-price-variant-selector.css"]
    };
  }
  static get properties() {
    return {
      "product": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Product",
          "resolved": "Product",
          "references": {
            "Product": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The product."
        }
      },
      "label": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The label for the price."
        },
        "attribute": "label",
        "reflect": false
      },
      "selectorTitle": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The title for price and variant selections"
        },
        "attribute": "selector-title",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "selectedVariant": {},
      "selectedPrice": {},
      "option1": {},
      "option2": {},
      "option3": {}
    };
  }
  static get methods() {
    return {
      "reportValidity": {
        "complexType": {
          "signature": "() => Promise<boolean>",
          "parameters": [],
          "references": {
            "Promise": {
              "location": "global"
            }
          },
          "return": "Promise<boolean>"
        },
        "docs": {
          "text": "",
          "tags": []
        }
      }
    };
  }
  static get elementRef() { return "el"; }
  static get watchers() {
    return [{
        "propName": "option1",
        "methodName": "handleOptionChange"
      }, {
        "propName": "option2",
        "methodName": "handleOptionChange"
      }, {
        "propName": "option3",
        "methodName": "handleOptionChange"
      }, {
        "propName": "selectedVariant",
        "methodName": "updateLineItems"
      }, {
        "propName": "selectedPrice",
        "methodName": "updateLineItems"
      }];
  }
}
//# sourceMappingURL=sc-checkout-product-price-variant-selector.js.map
