import { h } from '@stencil/core';
import { sprintf, __ } from '@wordpress/i18n';
import { speak } from '@wordpress/a11y';
import { isBumpInOrder } from '../../../../functions/line-items';
import { getFormattedPrice, intervalString } from '../../../../functions/price';
import { getFeaturedProductMediaAttributes, sizeImage } from '../../../../functions/media';
import { state as checkoutState } from '@store/checkout';
export class ScOrderBump {
  constructor() {
    var _a;
    this.bump = undefined;
    this.showControl = undefined;
    this.cdnRoot = (_a = window.scData) === null || _a === void 0 ? void 0 : _a.cdn_root;
  }
  /** Update the line item. */
  updateLineItem(add) {
    var _a, _b, _c;
    const price_id = ((_a = this.bump.price) === null || _a === void 0 ? void 0 : _a.id) || ((_b = this.bump) === null || _b === void 0 ? void 0 : _b.price);
    if (add) {
      this.scAddLineItem.emit({
        bump: (_c = this.bump) === null || _c === void 0 ? void 0 : _c.id,
        price_id,
        quantity: 1,
      });
      speak(__('Order bump applied.', 'surecart'));
    }
    else {
      this.scRemoveLineItem.emit({
        price_id,
        quantity: 1,
      });
      speak(__('Order bump Removed.', 'surecart'));
    }
  }
  newPrice() {
    var _a, _b, _c, _d, _e, _f;
    let amount = null;
    let initialAmount = ((_b = (_a = this.bump) === null || _a === void 0 ? void 0 : _a.price) === null || _b === void 0 ? void 0 : _b.amount) || 0;
    if ((_c = this.bump) === null || _c === void 0 ? void 0 : _c.amount_off) {
      amount = Math.max(0, initialAmount - ((_d = this.bump) === null || _d === void 0 ? void 0 : _d.amount_off));
    }
    if ((_e = this.bump) === null || _e === void 0 ? void 0 : _e.percent_off) {
      const off = initialAmount * (((_f = this.bump) === null || _f === void 0 ? void 0 : _f.percent_off) / 100);
      amount = Math.max(0, initialAmount - off);
    }
    return amount;
  }
  renderInterval() {
    var _a;
    const interval = intervalString((_a = this.bump) === null || _a === void 0 ? void 0 : _a.price, { labels: { interval: '/', period: __('for', 'surecart') } });
    if (!interval.trim().length)
      return null;
    return h("span", { class: "bump__interval" }, interval);
  }
  renderPrice() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
    return (h("div", { slot: "description", class: { 'bump__price': true, 'bump__price--has-discount': !!((_a = this.bump) === null || _a === void 0 ? void 0 : _a.percent_off) || !!((_b = this.bump) === null || _b === void 0 ? void 0 : _b.amount_off) }, part: "price" }, h("span", { "aria-label": 
      /** translators: %s: old price */
      sprintf(__('Originally priced at %s.', 'surecart'), getFormattedPrice({
        amount: (_d = (_c = this.bump) === null || _c === void 0 ? void 0 : _c.price) === null || _d === void 0 ? void 0 : _d.amount,
        currency: (_f = (_e = this.bump) === null || _e === void 0 ? void 0 : _e.price) === null || _f === void 0 ? void 0 : _f.currency,
      })) }, h("sc-format-number", { type: "currency", class: "bump__original-price", value: (_h = (_g = this.bump) === null || _g === void 0 ? void 0 : _g.price) === null || _h === void 0 ? void 0 : _h.amount, currency: (_k = (_j = this.bump) === null || _j === void 0 ? void 0 : _j.price) === null || _k === void 0 ? void 0 : _k.currency }), ' '), h("span", null, h("span", { "aria-hidden": "true" }, this.newPrice() === 0 && __('Free', 'surecart'), this.newPrice() !== null && this.newPrice() > 0 && (h("sc-format-number", { type: "currency", class: "bump__new-price", value: this.newPrice(), currency: ((_l = this.bump) === null || _l === void 0 ? void 0 : _l.price).currency })), this.renderInterval()))));
  }
  renderDiscount() {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    if (!!((_a = this.bump) === null || _a === void 0 ? void 0 : _a.amount_off)) {
      return (h("div", { class: "bump__tag", "aria-label": 
        /** translators: %1$s: amount off, %2$s: currency */
        sprintf(__('You save %1$s%2$s.', 'surecart'), (_b = this.bump) === null || _b === void 0 ? void 0 : _b.amount_off, ((_c = this.bump) === null || _c === void 0 ? void 0 : _c.price).currency) }, h("span", { "aria-hidden": "true" }, __('Save', 'surecart'), " ", h("sc-format-number", { type: "currency", value: -((_d = this.bump) === null || _d === void 0 ? void 0 : _d.amount_off), currency: ((_e = this.bump) === null || _e === void 0 ? void 0 : _e.price).currency }))));
    }
    if (!!((_f = this.bump) === null || _f === void 0 ? void 0 : _f.percent_off)) {
      return (h("div", { class: "bump__tag", "aria-label": 
        /** translators: %s: amount percent off */
        sprintf(__('You save %s%%.', 'surecart'), (_g = this.bump) === null || _g === void 0 ? void 0 : _g.percent_off) }, h("span", { "aria-hidden": "true" }, sprintf(__('Save %s%%', 'surecart'), (_h = this.bump) === null || _h === void 0 ? void 0 : _h.percent_off))));
    }
  }
  render() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u;
    const product = (_b = (_a = this.bump) === null || _a === void 0 ? void 0 : _a.price) === null || _b === void 0 ? void 0 : _b.product;
    const media = getFeaturedProductMediaAttributes(product);
    return (h("sc-choice", { value: (_c = this.bump) === null || _c === void 0 ? void 0 : _c.id, type: "checkbox", showControl: this.showControl, checked: isBumpInOrder(this.bump, checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout), onScChange: e => this.updateLineItem(e.target.checked), onKeyDown: e => {
        if (e.key === 'Enter' || e.key === ' ') {
          e.preventDefault();
          e.stopImmediatePropagation();
          this.updateLineItem(!isBumpInOrder(this.bump, checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout));
        }
      }, exportparts: "base, control, checked-icon, title" }, h("div", { part: "base-content", class: "bump" }, h("div", { class: "bump__text" }, h("div", { class: "bump__title", "aria-label": sprintf(
      /* translators: %s: order bump name */
      __('Product: %s.', 'surecart'), ((_e = (_d = this.bump) === null || _d === void 0 ? void 0 : _d.metadata) === null || _e === void 0 ? void 0 : _e.cta) || ((_f = this.bump) === null || _f === void 0 ? void 0 : _f.name) || (product === null || product === void 0 ? void 0 : product.name)) }, h("span", { "aria-hidden": "true" }, ((_h = (_g = this.bump) === null || _g === void 0 ? void 0 : _g.metadata) === null || _h === void 0 ? void 0 : _h.cta) || ((_j = this.bump) === null || _j === void 0 ? void 0 : _j.name) || (product === null || product === void 0 ? void 0 : product.name))), h("div", { class: "bump__amount" }, h("span", null, this.renderPrice()), h("span", null, this.renderDiscount())))), ((_l = (_k = this.bump) === null || _k === void 0 ? void 0 : _k.metadata) === null || _l === void 0 ? void 0 : _l.description) && (h("div", { slot: "footer", class: "bump__product--wrapper" }, h("sc-divider", { style: { '--spacing': 'var(--sc-spacing-medium)' } }), h("div", { class: "bump__product" }, !!(media === null || media === void 0 ? void 0 : media.url) && h("img", { src: sizeImage(media === null || media === void 0 ? void 0 : media.url, 130), alt: media.alt, ...(media.title ? { title: media.title } : {}), class: "bump__image" }), h("div", { class: "bump__product-text" }, !!((_o = (_m = this.bump) === null || _m === void 0 ? void 0 : _m.metadata) === null || _o === void 0 ? void 0 : _o.cta) && (h("div", { class: "bump__product-title", "aria-hidden": "true" }, this.bump.name || (product === null || product === void 0 ? void 0 : product.name))), !!((_q = (_p = this.bump) === null || _p === void 0 ? void 0 : _p.metadata) === null || _q === void 0 ? void 0 : _q.description) && (h("div", { class: "bump__product-description", "aria-label": sprintf(
      /* translators: %s: Product description */
      __('Product description: %s.', 'surecart'), (_s = (_r = this.bump) === null || _r === void 0 ? void 0 : _r.metadata) === null || _s === void 0 ? void 0 : _s.description) }, h("span", { "aria-hidden": "true" }, (_u = (_t = this.bump) === null || _t === void 0 ? void 0 : _t.metadata) === null || _u === void 0 ? void 0 : _u.description)))))))));
  }
  static get is() { return "sc-order-bump"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-order-bump.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-order-bump.css"]
    };
  }
  static get properties() {
    return {
      "bump": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Bump",
          "resolved": "Bump",
          "references": {
            "Bump": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The bump"
        }
      },
      "showControl": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Should we show the controls"
        },
        "attribute": "show-control",
        "reflect": true
      },
      "cdnRoot": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "cdn-root",
        "reflect": false,
        "defaultValue": "window.scData?.cdn_root"
      }
    };
  }
  static get events() {
    return [{
        "method": "scAddLineItem",
        "name": "scAddLineItem",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Add line item event"
        },
        "complexType": {
          "original": "LineItemData",
          "resolved": "LineItemData",
          "references": {
            "LineItemData": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        }
      }, {
        "method": "scRemoveLineItem",
        "name": "scRemoveLineItem",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Remove line item event"
        },
        "complexType": {
          "original": "LineItemData",
          "resolved": "LineItemData",
          "references": {
            "LineItemData": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        }
      }];
  }
}
//# sourceMappingURL=sc-order-bump.js.map
