import { h } from '@stencil/core';
import { __, sprintf } from '@wordpress/i18n';
import { addQueryArgs } from '@wordpress/url';
import apiFetch from '../../../../functions/fetch';
import { intervalString } from '../../../../functions/price';
import { productNameWithPrice } from '../../../../functions/price';
import { formatTime } from '../../../../../../admin/util/time';
import { formatNumber } from '../../../../../../admin/util';
export class ScSubscriptionDetails {
  constructor() {
    this.subscription = undefined;
    this.pendingPrice = undefined;
    this.hideRenewalText = undefined;
    this.activationsModal = undefined;
    this.loading = undefined;
    this.hasPendingUpdate = undefined;
  }
  renderName() {
    var _a, _b, _c;
    if (typeof ((_b = (_a = this.subscription) === null || _a === void 0 ? void 0 : _a.price) === null || _b === void 0 ? void 0 : _b.product) !== 'string') {
      return productNameWithPrice((_c = this.subscription) === null || _c === void 0 ? void 0 : _c.price);
    }
    return __('Subscription', 'surecart');
  }
  async handleSubscriptionChange() {
    var _a, _b, _c, _d;
    this.hasPendingUpdate = !!((_b = Object.keys(((_a = this === null || this === void 0 ? void 0 : this.subscription) === null || _a === void 0 ? void 0 : _a.pending_update) || {})) === null || _b === void 0 ? void 0 : _b.length);
    if (((_d = (_c = this === null || this === void 0 ? void 0 : this.subscription) === null || _c === void 0 ? void 0 : _c.pending_update) === null || _d === void 0 ? void 0 : _d.price) && !(this === null || this === void 0 ? void 0 : this.pendingPrice) && !this.hideRenewalText) {
      this.pendingPrice = await this.fetchPrice(this.subscription.pending_update.price);
    }
  }
  componentWillLoad() {
    this.handleSubscriptionChange();
  }
  async fetchPrice(price_id) {
    try {
      this.loading = true;
      const price = await apiFetch({
        path: addQueryArgs(`surecart/v1/prices/${price_id}`, {
          expand: ['product'],
        }),
      });
      return price;
    }
    catch (e) {
      console.error(e);
    }
    finally {
      this.loading = false;
    }
  }
  renderRenewalText() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z;
    const tag = h("sc-subscription-status-badge", { subscription: this === null || this === void 0 ? void 0 : this.subscription });
    if (((_a = this === null || this === void 0 ? void 0 : this.subscription) === null || _a === void 0 ? void 0 : _a.cancel_at_period_end) && ((_b = this === null || this === void 0 ? void 0 : this.subscription) === null || _b === void 0 ? void 0 : _b.current_period_end_at)) {
      return (h("span", { "aria-label": sprintf(__('Renewal Update - Your plan will be canceled on %s', 'surecart'), formatTime(this.subscription.current_period_end_at)) }, tag, " ", sprintf(__('Your plan will be canceled on', 'surecart')), ' ', h("sc-format-date", { date: this.subscription.current_period_end_at * 1000, month: "long", day: "numeric", year: "numeric" })));
    }
    if (this.hasPendingUpdate) {
      if (!this.pendingPrice && !((_d = (_c = this.subscription) === null || _c === void 0 ? void 0 : _c.pending_update) === null || _d === void 0 ? void 0 : _d.ad_hoc_amount)) {
        return h("sc-skeleton", null);
      }
      if ((_f = (_e = this.subscription) === null || _e === void 0 ? void 0 : _e.pending_update) === null || _f === void 0 ? void 0 : _f.ad_hoc_amount) {
        return (h("span", { "aria-label": sprintf(__('Renewal Update - Your plan switches to %1s on %2s', 'surecart'), formatNumber((_h = (_g = this.subscription) === null || _g === void 0 ? void 0 : _g.pending_update) === null || _h === void 0 ? void 0 : _h.ad_hoc_amount, ((_j = this.pendingPrice) === null || _j === void 0 ? void 0 : _j.currency) || ((_l = (_k = this.subscription) === null || _k === void 0 ? void 0 : _k.price) === null || _l === void 0 ? void 0 : _l.currency)), formatTime(this.subscription.current_period_end_at)) }, __('Your plan switches to', 'surecart'), ' ', h("strong", null, h("sc-format-number", { type: "currency", currency: ((_m = this.pendingPrice) === null || _m === void 0 ? void 0 : _m.currency) || ((_p = (_o = this.subscription) === null || _o === void 0 ? void 0 : _o.price) === null || _p === void 0 ? void 0 : _p.currency), value: (_r = (_q = this.subscription) === null || _q === void 0 ? void 0 : _q.pending_update) === null || _r === void 0 ? void 0 : _r.ad_hoc_amount }), ' ', intervalString(this.pendingPrice || ((_s = this.subscription) === null || _s === void 0 ? void 0 : _s.price))), ' ', __('on', 'surecart'), ' ', h("sc-format-date", { date: this.subscription.current_period_end_at, type: "timestamp", month: "long", day: "numeric", year: "numeric" })));
      }
      return (h("span", { "aria-label": sprintf(__('Renewal Update - Your plan switches to %1s on %2s', 'surecart'), this.pendingPrice.product.name, formatTime(this.subscription.current_period_end_at)) }, __('Your plan switches to', 'surecart'), " ", h("strong", null, this.pendingPrice.product.name), " ", __('on', 'surecart'), ' ', h("sc-format-date", { date: this.subscription.current_period_end_at, type: "timestamp", month: "long", day: "numeric", year: "numeric" })));
    }
    if (((_t = this === null || this === void 0 ? void 0 : this.subscription) === null || _t === void 0 ? void 0 : _t.status) === 'trialing' && ((_u = this === null || this === void 0 ? void 0 : this.subscription) === null || _u === void 0 ? void 0 : _u.trial_end_at)) {
      return (h("span", { "aria-label": sprintf(__('Renewal Update - Your plan begins on %s.', 'surecart'), formatTime(this.subscription.trial_end_at)) }, tag, " ", sprintf(__('Your plan begins on', 'surecart')), ' ', h("sc-format-date", { date: (_v = this === null || this === void 0 ? void 0 : this.subscription) === null || _v === void 0 ? void 0 : _v.trial_end_at, type: "timestamp", month: "long", day: "numeric", year: "numeric" })));
    }
    if (((_w = this.subscription) === null || _w === void 0 ? void 0 : _w.status) === 'active' && ((_x = this.subscription) === null || _x === void 0 ? void 0 : _x.current_period_end_at)) {
      return (h("span", { "aria-label": sprintf(__('Renewal Update - Your next payment is on %s', 'surecart'), formatTime(this.subscription.current_period_end_at)) }, tag, " ", ((_y = this.subscription) === null || _y === void 0 ? void 0 : _y.remaining_period_count) === null ? __('Your plan renews on', 'surecart') : __('Your next payment is on', 'surecart'), ' ', h("sc-format-date", { date: (_z = this === null || this === void 0 ? void 0 : this.subscription) === null || _z === void 0 ? void 0 : _z.current_period_end_at, type: "timestamp", month: "long", day: "numeric", year: "numeric" })));
    }
    return tag;
  }
  getActivations() {
    var _a, _b, _c, _d;
    return (((_d = (_c = (_b = (_a = this.subscription) === null || _a === void 0 ? void 0 : _a.purchase) === null || _b === void 0 ? void 0 : _b.license) === null || _c === void 0 ? void 0 : _c.activations) === null || _d === void 0 ? void 0 : _d.data) || []).filter(activation => {
      return activation === null || activation === void 0 ? void 0 : activation.counted;
    });
  }
  renderActivations() {
    var _a;
    const activations = this.getActivations();
    if (!(activations === null || activations === void 0 ? void 0 : activations.length))
      return null;
    return (h("sc-flex", { justifyContent: "flex-start", alignItems: "center" }, h("sc-tag", { size: "small" }, (_a = activations === null || activations === void 0 ? void 0 : activations[0]) === null || _a === void 0 ? void 0 : _a.name), (activations === null || activations === void 0 ? void 0 : activations.length) > 1 && (h("sc-text", { style: { '--font-size': 'var(--sc-font-size-small)', 'cursor': 'pointer' }, onClick: e => {
        e.preventDefault();
        e.stopImmediatePropagation();
        this.activationsModal = true;
      } }, "+ ", (activations === null || activations === void 0 ? void 0 : activations.length) - 1, " More"))));
  }
  showWarning() {
    var _a, _b, _c, _d, _e, _f, _g;
    // no payment method.
    if ((_a = this.subscription) === null || _a === void 0 ? void 0 : _a.payment_method) {
      return false;
    }
    // don't show if not looking for payment.
    if (!['active', 'past_due', 'unpaid', 'incomplete'].includes((_b = this.subscription) === null || _b === void 0 ? void 0 : _b.status)) {
      return false;
    }
    // handle ad_hoc.
    if ((_d = (_c = this.subscription) === null || _c === void 0 ? void 0 : _c.price) === null || _d === void 0 ? void 0 : _d.ad_hoc) {
      return ((_e = this.subscription) === null || _e === void 0 ? void 0 : _e.ad_hoc_amount) !== 0;
    }
    // show the warning if the subscription is not free.
    return ((_g = (_f = this.subscription) === null || _f === void 0 ? void 0 : _f.price) === null || _g === void 0 ? void 0 : _g.amount) !== 0;
  }
  render() {
    return (h("div", { class: "subscription-details" }, this.hasPendingUpdate && (h("div", null, h("sc-tag", { size: "small", type: "warning" }, __('Update Scheduled', 'surecart')))), h("sc-flex", { alignItems: "center", justifyContent: "flex-start" }, h("sc-text", { "aria-label": sprintf(__('Plan name - %s', 'surecart'), this.renderName()), style: { '--font-weight': 'var(--sc-font-weight-bold)' } }, this.renderName()), this.renderActivations()), !this.hideRenewalText && h("div", null, this.renderRenewalText(), " "), h("slot", null), h("sc-dialog", { label: __('Activations', 'surecart'), onScRequestClose: () => (this.activationsModal = false), open: !!this.activationsModal }, h("sc-card", { "no-padding": true, style: { '--overflow': 'hidden' } }, h("sc-stacked-list", null, (this.getActivations() || []).map(activation => {
      return (h("sc-stacked-list-row", { style: { '--columns': '2' }, mobileSize: 0 }, h("sc-text", { style: { '--line-height': 'var(--sc-line-height-dense)' } }, h("strong", null, activation === null || activation === void 0 ? void 0 : activation.name), h("div", null, h("sc-text", { style: { '--color': 'var(--sc-color-gray-500)' } }, activation === null || activation === void 0 ? void 0 : activation.fingerprint))), h("sc-text", { style: { '--color': 'var(--sc-color-gray-500)' } }, h("sc-format-date", { type: "timestamp", month: "short", day: "numeric", year: "numeric", date: activation === null || activation === void 0 ? void 0 : activation.created_at }))));
    })))), this.showWarning() && (h("div", null, h("sc-tag", { type: "warning" }, h("div", { class: "subscription-details__missing-method" }, h("sc-icon", { name: "alert-triangle" }), __('Payment Method Missing', 'surecart')))))));
  }
  static get is() { return "sc-subscription-details"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-subscription-details.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-subscription-details.css"]
    };
  }
  static get properties() {
    return {
      "subscription": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Subscription",
          "resolved": "Subscription",
          "references": {
            "Subscription": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        }
      },
      "pendingPrice": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Price",
          "resolved": "Price",
          "references": {
            "Price": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        }
      },
      "hideRenewalText": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "hide-renewal-text",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "activationsModal": {},
      "loading": {},
      "hasPendingUpdate": {}
    };
  }
  static get watchers() {
    return [{
        "propName": "subscription",
        "methodName": "handleSubscriptionChange"
      }];
  }
}
//# sourceMappingURL=sc-subscription-details.js.map
