import { Fragment, h } from '@stencil/core';
import { __ } from '@wordpress/i18n';
import apiFetch from '../../../../functions/fetch';
import { addQueryArgs } from '@wordpress/url';
export class ScSubscriptionReactivate {
  constructor() {
    this.open = undefined;
    this.subscription = undefined;
    this.busy = undefined;
    this.error = undefined;
    this.upcomingPeriod = undefined;
    this.loading = false;
  }
  openChanged() {
    if (this.open) {
      this.fetchUpcoming();
    }
  }
  async fetchUpcoming() {
    var _a;
    this.loading = true;
    try {
      this.upcomingPeriod = await apiFetch({
        method: 'PATCH',
        path: addQueryArgs(`surecart/v1/subscriptions/${(_a = this.subscription) === null || _a === void 0 ? void 0 : _a.id}/upcoming_period`, {
          skip_product_group_validation: true,
          expand: ['period.checkout'],
        }),
        data: {
          purge_pending_update: false,
        },
      });
    }
    catch (e) {
      this.error = (e === null || e === void 0 ? void 0 : e.message) || __('Something went wrong', 'surecart');
    }
    finally {
      this.loading = false;
    }
  }
  async reactivateSubscription() {
    var _a;
    try {
      this.error = '';
      this.busy = true;
      await apiFetch({
        path: `surecart/v1/subscriptions/${(_a = this.subscription) === null || _a === void 0 ? void 0 : _a.id}/restore`,
        method: 'PATCH',
      });
      this.scRefresh.emit();
      this.scRequestClose.emit('close-button');
    }
    catch (e) {
      this.error = (e === null || e === void 0 ? void 0 : e.message) || __('Something went wrong', 'surecart');
    }
    finally {
      this.busy = false;
    }
  }
  renderLoading() {
    return (h("sc-flex", { flexDirection: "column", style: { gap: '1em' } }, h("sc-skeleton", { style: { width: '20%', display: 'inline-block' } }), h("sc-skeleton", { style: { width: '60%', display: 'inline-block' } }), h("sc-skeleton", { style: { width: '40%', display: 'inline-block' } })));
  }
  render() {
    var _a, _b, _c, _d;
    return (h("sc-dialog", { noHeader: true, open: this.open, style: { '--width': '600px', '--body-spacing': 'var(--sc-spacing-xxx-large)' } }, h("sc-dashboard-module", { loading: this.loading, heading: __('Resubscribe', 'surecart'), class: "subscription-reactivate", error: this.error, style: { '--sc-dashboard-module-spacing': '1em' } }, this.loading ? (this.renderLoading()) : (h(Fragment, null, h("div", { slot: "description" }, h("sc-alert", { open: true, type: "warning", title: __('Confirm Charge', 'surecart') }, __('You will be charged', 'surecart'), ' ', h("sc-format-number", { type: "currency", value: (_b = (_a = this.upcomingPeriod) === null || _a === void 0 ? void 0 : _a.checkout) === null || _b === void 0 ? void 0 : _b.amount_due, currency: (_c = this.subscription) === null || _c === void 0 ? void 0 : _c.currency }), ' ', __('immediately for your subscription.', 'surecart')), h("sc-text", { style: {
        '--font-size': 'var(--sc-font-size-medium)',
        '--color': 'var(--sc-input-label-color)',
        '--line-height': 'var(--sc-line-height-dense)',
        'margin-top': 'var(--sc-spacing-medium)',
      } }, __('Your subscription will be reactivated and will renew automatically on', 'surecart'), ' ', h("strong", null, h("sc-format-date", { type: "timestamp", date: (_d = this.upcomingPeriod) === null || _d === void 0 ? void 0 : _d.end_at, month: "long", day: "numeric", year: "numeric" })))), h("sc-flex", { justifyContent: "flex-start" }, h("sc-button", { type: "primary", loading: this.busy, disabled: this.busy, onClick: () => this.reactivateSubscription() }, __('Yes, Reactivate', 'surecart')), h("sc-button", { disabled: this.busy, style: { color: 'var(--sc-color-gray-500)' }, type: "text", onClick: () => this.scRequestClose.emit() }, __('No, Keep Inactive', 'surecart'))))), this.busy && h("sc-block-ui", null))));
  }
  static get is() { return "sc-subscription-reactivate"; }
  static get encapsulation() { return "shadow"; }
  static get properties() {
    return {
      "open": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Whether it is open"
        },
        "attribute": "open",
        "reflect": false
      },
      "subscription": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Subscription",
          "resolved": "Subscription",
          "references": {
            "Subscription": {
              "location": "import",
              "path": "src/types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The subscription to reactivate"
        }
      }
    };
  }
  static get states() {
    return {
      "busy": {},
      "error": {},
      "upcomingPeriod": {},
      "loading": {}
    };
  }
  static get events() {
    return [{
        "method": "scRequestClose",
        "name": "scRequestClose",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Reactivate modal closed"
        },
        "complexType": {
          "original": "'close-button' | 'keyboard' | 'overlay'",
          "resolved": "\"close-button\" | \"keyboard\" | \"overlay\"",
          "references": {}
        }
      }, {
        "method": "scRefresh",
        "name": "scRefresh",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Refresh subscriptions"
        },
        "complexType": {
          "original": "void",
          "resolved": "void",
          "references": {}
        }
      }];
  }
  static get watchers() {
    return [{
        "propName": "open",
        "methodName": "openChanged"
      }];
  }
}
//# sourceMappingURL=sc-subscription-reactivate.js.map
