import { h, Host } from '@stencil/core';
import { getProductBuyLink, submitCartForm } from '@store/product/mutations';
import { state } from '@store/product';
import { setProduct } from '@store/product/setters';
import { onChange } from '@store/product';
import { isProductOutOfStock, isSelectedVariantMissing } from '@store/product/getters';
import { getTopLevelError, getAdditionalErrorMessages } from '../../../../functions/error';
export class ScProductBuyButton {
  constructor() {
    this.addToCart = undefined;
    this.productId = undefined;
    this.formId = undefined;
    this.mode = 'live';
    this.checkoutLink = undefined;
    this.error = undefined;
  }
  async handleCartClick(e) {
    var _a, _b, _c, _d, _e;
    e.preventDefault();
    console.log(e);
    // already busy, do nothing.
    if ((_a = state[this.productId]) === null || _a === void 0 ? void 0 : _a.busy)
      return;
    // ad hoc price, use the dialog.
    if ((_c = (_b = state[this.productId]) === null || _b === void 0 ? void 0 : _b.selectedPrice) === null || _c === void 0 ? void 0 : _c.ad_hoc) {
      setProduct(this.productId, { dialog: this.addToCart ? 'ad_hoc_cart' : 'ad_hoc_buy' });
      return;
    }
    // if add to cart is undefined/false navigate to buy url
    if (!this.addToCart) {
      const checkoutUrl = (_e = (_d = window === null || window === void 0 ? void 0 : window.scData) === null || _d === void 0 ? void 0 : _d.pages) === null || _e === void 0 ? void 0 : _e.checkout;
      if (!checkoutUrl)
        return;
      return window.location.assign(getProductBuyLink(this.productId, checkoutUrl, { no_cart: !this.addToCart }));
    }
    // submit the cart form.
    try {
      console.log('submit');
      await submitCartForm(this.productId);
    }
    catch (e) {
      console.error(e);
      this.error = e;
    }
  }
  componentDidLoad() {
    this.link = this.el.querySelector('a');
    this.updateProductLink();
    onChange(this.productId, () => this.updateProductLink());
  }
  updateProductLink() {
    var _a, _b;
    const checkoutUrl = (_b = (_a = window === null || window === void 0 ? void 0 : window.scData) === null || _a === void 0 ? void 0 : _a.pages) === null || _b === void 0 ? void 0 : _b.checkout;
    if (!checkoutUrl || !this.link)
      return;
    this.link.href = getProductBuyLink(this.productId, checkoutUrl, !this.addToCart ? { no_cart: true } : {});
  }
  render() {
    var _a, _b;
    return (h(Host, { class: {
        'is-busy': ((_a = state[this.productId]) === null || _a === void 0 ? void 0 : _a.busy) && !!this.addToCart,
        'is-disabled': (_b = state[this.productId]) === null || _b === void 0 ? void 0 : _b.disabled,
        'is-sold-out': isProductOutOfStock(this.productId) && !isSelectedVariantMissing(this.productId),
        'is-unavailable': isSelectedVariantMissing(this.productId),
      }, onClick: e => this.handleCartClick(e) }, !!this.error && (h("sc-alert", { onClick: event => {
        event.stopPropagation();
      }, type: "danger", scrollOnOpen: true, open: !!this.error, closable: false }, !!getTopLevelError(this.error) && h("span", { slot: "title", innerHTML: getTopLevelError(this.error) }), (getAdditionalErrorMessages(this.error) || []).map((message, index) => (h("div", { innerHTML: message, key: index }))))), h("slot", null)));
  }
  static get is() { return "sc-product-buy-button"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-product-buy-button.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-product-buy-button.css"]
    };
  }
  static get properties() {
    return {
      "addToCart": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "add-to-cart",
        "reflect": false
      },
      "productId": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "product-id",
        "reflect": false
      },
      "formId": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "form-id",
        "reflect": false
      },
      "mode": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'live' | 'test'",
          "resolved": "\"live\" | \"test\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "mode",
        "reflect": false,
        "defaultValue": "'live'"
      },
      "checkoutLink": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "checkout-link",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "error": {}
    };
  }
  static get elementRef() { return "el"; }
}
//# sourceMappingURL=sc-product-buy-button.js.map
