import { Fragment, h } from '@stencil/core';
import { state } from '@store/product';
import { isOptionMissing, isOptionSoldOut } from '@store/product/getters';
import { __, sprintf } from '@wordpress/i18n';
import { setProduct } from '@store/product/setters';
export class ScProductPillsVariantOption {
  constructor() {
    this.label = undefined;
    this.optionNumber = 1;
    this.productId = undefined;
  }
  render() {
    return (h("sc-form-control", { label: this.label }, h("span", { slot: "label" }, this.label), h("div", { class: "sc-product-pills-variant-option__wrapper" }, (state[this.productId].variant_options[this.optionNumber - 1].values || []).map(value => {
      const isUnavailable = isOptionSoldOut(this.productId, this.optionNumber, value) || isOptionMissing(this.productId, this.optionNumber, value);
      return (h("sc-pill-option", { isUnavailable: isUnavailable, isSelected: state[this.productId].variantValues[`option_${this.optionNumber}`] === value, onClick: () => setProduct(this.productId, {
          variantValues: {
            ...state[this.productId].variantValues,
            [`option_${this.optionNumber}`]: value,
          },
        }) }, h("span", { "aria-hidden": "true" }, value), h("sc-visually-hidden", null, sprintf(__('Select %s: %s.', 'surecart'), this.label, value), isUnavailable && h(Fragment, null, " ", __('(option unavailable)', 'surecart')), state[this.productId].variantValues[`option_${this.optionNumber}`] === value && h(Fragment, null, " ", __('This option is currently selected.', 'surecart')))));
    }))));
  }
  static get is() { return "sc-product-pills-variant-option"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-product-pills-variant-option.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-product-pills-variant-option.css"]
    };
  }
  static get properties() {
    return {
      "label": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Label"
        },
        "attribute": "label",
        "reflect": false
      },
      "optionNumber": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "1 | 2 | 3",
          "resolved": "1 | 2 | 3",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Which option number?"
        },
        "attribute": "option-number",
        "reflect": false,
        "defaultValue": "1"
      },
      "productId": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The product id"
        },
        "attribute": "product-id",
        "reflect": false
      }
    };
  }
}
//# sourceMappingURL=sc-product-pills-variant-option.js.map
