import { h, Fragment, Host } from '@stencil/core';
import { __ } from '@wordpress/i18n';
import { intervalString } from '../../../../functions/price';
import { state } from '@store/product';
import { availablePrices } from '@store/product/getters';
import { setProduct } from '@store/product/setters';
export class ScProductPriceChoices {
  constructor() {
    this.label = undefined;
    this.showPrice = undefined;
    this.productId = undefined;
  }
  renderPrice(price) {
    return (h(Fragment, null, h("sc-format-number", { type: "currency", value: price.amount, currency: price.currency }), h("span", { slot: "per" }, intervalString(price, {
      labels: {
        interval: __('Every', 'surecart'),
        period: __('for', 'surecart'),
        once: __('Once', 'surecart'),
      },
      showOnce: true,
    }))));
  }
  render() {
    const prices = availablePrices(this.productId);
    if ((prices === null || prices === void 0 ? void 0 : prices.length) < 2)
      return h(Host, { style: { display: 'none' } });
    return (h("sc-choices", { label: this.label, required: true, style: { '--sc-input-required-indicator': ' ' } }, (prices || []).map(price => {
      var _a, _b, _c, _d;
      return (h("sc-price-choice-container", { label: (price === null || price === void 0 ? void 0 : price.name) || ((_b = (_a = state[this.productId]) === null || _a === void 0 ? void 0 : _a.product) === null || _b === void 0 ? void 0 : _b.name), showPrice: !!this.showPrice, price: price, checked: ((_d = (_c = state[this.productId]) === null || _c === void 0 ? void 0 : _c.selectedPrice) === null || _d === void 0 ? void 0 : _d.id) === (price === null || price === void 0 ? void 0 : price.id), onScChange: e => {
          if (e.target.checked) {
            setProduct(this.productId, { selectedPrice: price });
          }
        } }));
    })));
  }
  static get is() { return "sc-product-price-choices"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-product-price-choices.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-product-price-choices.css"]
    };
  }
  static get properties() {
    return {
      "label": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The product price choice label"
        },
        "attribute": "label",
        "reflect": false
      },
      "showPrice": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Whether to show the price"
        },
        "attribute": "show-price",
        "reflect": false
      },
      "productId": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The product id"
        },
        "attribute": "product-id",
        "reflect": false
      }
    };
  }
}
//# sourceMappingURL=sc-product-price-choices.js.map
