/**
 * External dependencies.
 */
import { h, Host } from '@stencil/core';
/**
 * Internal dependencies.
 */
import { state } from '@store/product';
import { getDiscountedAmount as getUpsellDiscountAmount, getScratchAmount as getUpsellScratchAmount } from '@store/upsell/getters';
export class ScProductPrice {
  constructor() {
    this.prices = undefined;
    this.saleText = undefined;
    this.productId = undefined;
  }
  renderRange() {
    var _a, _b, _c, _d;
    if (((_b = (_a = state[this.productId]) === null || _a === void 0 ? void 0 : _a.prices) === null || _b === void 0 ? void 0 : _b.length) === 1) {
      return this.renderPrice((_c = state[this.productId]) === null || _c === void 0 ? void 0 : _c.prices[0]);
    }
    return h("sc-price-range", { prices: (_d = state[this.productId]) === null || _d === void 0 ? void 0 : _d.prices });
  }
  renderVariantPrice(selectedVariant) {
    var _a, _b;
    const variant = (_b = (_a = state[this.productId]) === null || _a === void 0 ? void 0 : _a.variants) === null || _b === void 0 ? void 0 : _b.find(variant => (variant === null || variant === void 0 ? void 0 : variant.id) === (selectedVariant === null || selectedVariant === void 0 ? void 0 : selectedVariant.id));
    return this.renderPrice(state[this.productId].selectedPrice, variant === null || variant === void 0 ? void 0 : variant.amount);
  }
  renderPrice(price, variantAmount) {
    var _a;
    const originalAmount = (_a = variantAmount !== null && variantAmount !== void 0 ? variantAmount : price === null || price === void 0 ? void 0 : price.amount) !== null && _a !== void 0 ? _a : 0;
    const amount = getUpsellDiscountAmount(originalAmount);
    const scratch_amount = getUpsellScratchAmount(price === null || price === void 0 ? void 0 : price.scratch_amount);
    return (h("sc-price", { currency: price === null || price === void 0 ? void 0 : price.currency, amount: amount, scratchAmount: scratch_amount, saleText: this.saleText, adHoc: price === null || price === void 0 ? void 0 : price.ad_hoc, trialDurationDays: price === null || price === void 0 ? void 0 : price.trial_duration_days, setupFeeAmount: (price === null || price === void 0 ? void 0 : price.setup_fee_enabled) ? price === null || price === void 0 ? void 0 : price.setup_fee_amount : null, setupFeeName: (price === null || price === void 0 ? void 0 : price.setup_fee_enabled) ? price === null || price === void 0 ? void 0 : price.setup_fee_name : null, recurringPeriodCount: price === null || price === void 0 ? void 0 : price.recurring_period_count, recurringInterval: price === null || price === void 0 ? void 0 : price.recurring_interval, recurringIntervalCount: price === null || price === void 0 ? void 0 : price.recurring_interval_count }));
  }
  render() {
    return (h(Host, { role: "paragraph" }, (() => {
      var _a, _b, _c, _d, _e;
      if ((_a = state[this.productId]) === null || _a === void 0 ? void 0 : _a.selectedVariant) {
        return this.renderVariantPrice((_b = state[this.productId]) === null || _b === void 0 ? void 0 : _b.selectedVariant);
      }
      if ((_c = state[this.productId]) === null || _c === void 0 ? void 0 : _c.selectedPrice) {
        return this.renderPrice(state[this.productId].selectedPrice);
      }
      if ((_e = (_d = state[this.productId]) === null || _d === void 0 ? void 0 : _d.prices) === null || _e === void 0 ? void 0 : _e.length) {
        return this.renderRange();
      }
      return h("slot", null);
    })()));
  }
  static get is() { return "sc-product-price"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-product-price.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-product-price.css"]
    };
  }
  static get properties() {
    return {
      "prices": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Price[]",
          "resolved": "Price[]",
          "references": {
            "Price": {
              "location": "import",
              "path": "../../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The product's prices."
        }
      },
      "saleText": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The sale text"
        },
        "attribute": "sale-text",
        "reflect": false
      },
      "productId": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The product id"
        },
        "attribute": "product-id",
        "reflect": false
      }
    };
  }
}
//# sourceMappingURL=sc-product-price.js.map
