import { h } from '@stencil/core';
import { __ } from '@wordpress/i18n';
import { state as checkoutState, onChange as onCheckoutChange } from '@store/checkout';
import { shippingAddressRequired } from '@store/checkout/getters';
export class ScFormComponentsValidator {
  constructor() {
    this.disabled = undefined;
    this.taxProtocol = undefined;
    this.hasAddress = undefined;
    this.hasTaxIDField = undefined;
    this.hasBumpsField = undefined;
    this.hasTaxLine = undefined;
    this.hasBumpLine = undefined;
    this.hasShippingChoices = undefined;
    this.hasShippingAmount = undefined;
  }
  handleOrderChange() {
    var _a, _b, _c, _d, _e, _f, _g;
    // bail if we don't have address invalid error or disabled.
    if (this.disabled)
      return;
    // make sure to add the address field if it's not there.
    if (shippingAddressRequired()) {
      this.addAddressField();
    }
    // add order bumps.
    if ((_c = (_b = (_a = checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.recommended_bumps) === null || _b === void 0 ? void 0 : _b.data) === null || _c === void 0 ? void 0 : _c.length) {
      this.addBumps();
    }
    if (!!((_d = checkoutState.checkout) === null || _d === void 0 ? void 0 : _d.tax_amount)) {
      this.addTaxLine();
    }
    // add shipping choices.
    if (((_e = checkoutState.checkout) === null || _e === void 0 ? void 0 : _e.shipping_enabled) && ((_f = checkoutState.checkout) === null || _f === void 0 ? void 0 : _f.selected_shipping_choice_required)) {
      this.addShippingChoices();
    }
    if (!!((_g = checkoutState.checkout) === null || _g === void 0 ? void 0 : _g.shipping_amount)) {
      this.addShippingAmount();
    }
  }
  handleHasAddressChange() {
    if (!this.hasAddress)
      return;
    this.handleShippingAddressRequired();
  }
  componentWillLoad() {
    var _a, _b;
    this.hasAddress = !!this.el.querySelector('sc-order-shipping-address');
    this.hasTaxIDField = !!this.el.querySelector('sc-order-tax-id-input');
    this.hasBumpsField = !!this.el.querySelector('sc-order-bumps');
    this.hasTaxLine = !!this.el.querySelector('sc-line-item-tax');
    this.hasShippingChoices = !!this.el.querySelector('sc-shipping-choices');
    this.hasShippingAmount = !!this.el.querySelector('sc-line-item-shipping');
    // automatically add address field if tax is enabled.
    if ((_a = this.taxProtocol) === null || _a === void 0 ? void 0 : _a.tax_enabled) {
      this.addAddressField();
      // if eu vat is required, add the tax id field.
      if ((_b = this.taxProtocol) === null || _b === void 0 ? void 0 : _b.eu_vat_required) {
        this.addTaxIDField();
      }
    }
    this.removeCheckoutListener = onCheckoutChange('checkout', () => this.handleOrderChange());
  }
  disconnectedCallback() {
    this.removeCheckoutListener();
  }
  handleShippingAddressRequired() {
    var _a;
    if (!((_a = checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.shipping_address_required))
      return;
    // get the address
    const address = this.el.querySelector('sc-order-shipping-address');
    if (!address)
      return;
    // require the address.
    address.required = true;
    // if we have a customer name field, require that.
    const customerName = this.el.querySelector('sc-customer-name');
    if (!!customerName) {
      customerName.required = true;
      return;
    }
    // require the name and show the name input.
    address.requireName = true;
    address.showName = true;
  }
  addAddressField() {
    if (this.hasAddress) {
      return;
    }
    const payment = this.el.querySelector('sc-payment');
    const address = document.createElement('sc-order-shipping-address');
    address.label = __('Address', 'surecart');
    payment.parentNode.insertBefore(address, payment);
    this.hasAddress = true;
  }
  addTaxIDField() {
    if (this.hasTaxIDField)
      return;
    const payment = this.el.querySelector('sc-payment');
    const taxInput = document.createElement('sc-order-tax-id-input');
    payment.parentNode.insertBefore(taxInput, payment);
    this.hasTaxIDField = true;
  }
  addBumps() {
    if (this.hasBumpsField)
      return;
    const payment = this.el.querySelector('sc-payment');
    const bumps = document.createElement('sc-order-bumps');
    payment.parentNode.insertBefore(bumps, payment.nextSibling);
    this.hasBumpsField = true;
  }
  addTaxLine() {
    var _a;
    if (this.hasTaxLine)
      return;
    const total = this.el.querySelector('sc-line-item-total[total=total]');
    const tax = document.createElement('sc-line-item-tax');
    if (((_a = total === null || total === void 0 ? void 0 : total.previousElementSibling) === null || _a === void 0 ? void 0 : _a.tagName) === 'SC-DIVIDER') {
      total.parentNode.insertBefore(tax, total.previousElementSibling);
    }
    else {
      total.parentNode.insertBefore(tax, total);
    }
    this.hasTaxLine = true;
  }
  addShippingChoices() {
    if (this.hasShippingChoices)
      return;
    const payment = this.el.querySelector('sc-payment');
    const shippingChoices = document.createElement('sc-shipping-choices');
    payment.parentNode.insertBefore(shippingChoices, payment);
    this.hasShippingChoices = true;
  }
  addShippingAmount() {
    var _a;
    if (this.hasShippingAmount)
      return;
    let insertBeforeElement = this.el.querySelector('sc-line-item-tax');
    const total = this.el.querySelector('sc-line-item-total[total=total]');
    if (!insertBeforeElement) {
      insertBeforeElement = ((_a = total === null || total === void 0 ? void 0 : total.previousElementSibling) === null || _a === void 0 ? void 0 : _a.tagName) === 'SC-DIVIDER' ? total.previousElementSibling : total;
    }
    const shippingAmount = document.createElement('sc-line-item-shipping');
    insertBeforeElement.parentNode.insertBefore(shippingAmount, insertBeforeElement);
    this.hasShippingAmount = true;
  }
  render() {
    return h("slot", null);
  }
  static get is() { return "sc-form-components-validator"; }
  static get encapsulation() { return "shadow"; }
  static get properties() {
    return {
      "disabled": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Disable validation?"
        },
        "attribute": "disabled",
        "reflect": false
      },
      "taxProtocol": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "TaxProtocol",
          "resolved": "TaxProtocol",
          "references": {
            "TaxProtocol": {
              "location": "import",
              "path": "../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The tax protocol"
        }
      }
    };
  }
  static get states() {
    return {
      "hasAddress": {},
      "hasTaxIDField": {},
      "hasBumpsField": {},
      "hasTaxLine": {},
      "hasBumpLine": {},
      "hasShippingChoices": {},
      "hasShippingAmount": {}
    };
  }
  static get elementRef() { return "el"; }
  static get watchers() {
    return [{
        "propName": "hasAddress",
        "methodName": "handleHasAddressChange"
      }];
  }
}
//# sourceMappingURL=sc-form-components-validator.js.map
