import { h, Host } from '@stencil/core';
import { __ } from '@wordpress/i18n';
import { addQueryArgs } from '@wordpress/url';
import { speak } from '@wordpress/a11y';
import apiFetch from '../../../functions/fetch';
import { expand } from '../../../services/session';
import { state as checkoutState } from '@store/checkout';
import { state as formState } from '@store/form';
import { createErrorNotice } from '@store/notices/mutations';
import { clearCheckout } from '@store/checkout/mutations';
/**
 * This component listens to the order status
 * and confirms the order when payment is successful.
 */
export class ScOrderConfirmProvider {
  constructor() {
    this.showSuccessModal = false;
    this.checkoutStatus = undefined;
    this.successUrl = undefined;
  }
  /**
   * Watch for paid checkout machine state.
   * This is triggered by Stripe, Paypal or Paystack when payment succeeds.
   */
  handleConfirmOrderEvent() {
    if (this.checkoutStatus === 'confirming') {
      this.confirmOrder();
    }
    else if (this.checkoutStatus === 'confirmed') {
      speak(__('Order has been confirmed. Please select continue to go to the next step.', 'surecart'));
    }
  }
  /** Confirm the order. */
  async confirmOrder() {
    var _a, _b, _c, _d, _e;
    try {
      checkoutState.checkout = (await apiFetch({
        method: 'PATCH',
        path: addQueryArgs(`surecart/v1/checkouts/${(_a = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.id}/confirm`, { expand }),
      }));
      this.scSetState.emit('CONFIRMED');
    }
    catch (e) {
      console.error(e);
      createErrorNotice(e);
    }
    finally {
      // If there is an initial upsell redirect to it.
      if (!!((_c = (_b = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _b === void 0 ? void 0 : _b.current_upsell) === null || _c === void 0 ? void 0 : _c.permalink)) {
        setTimeout(() => {
          var _a, _b, _c;
          return window.location.assign(addQueryArgs((_b = (_a = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.current_upsell) === null || _b === void 0 ? void 0 : _b.permalink, {
            sc_checkout_id: (_c = checkoutState.checkout) === null || _c === void 0 ? void 0 : _c.id,
            sc_form_id: checkoutState.formId,
          }));
        }, 50);
        clearCheckout();
        return;
      }
      // get success url.
      const successUrl = ((_e = (_d = checkoutState.checkout) === null || _d === void 0 ? void 0 : _d.metadata) === null || _e === void 0 ? void 0 : _e.success_url) || this.successUrl;
      if (successUrl) {
        // set state to redirecting.
        this.scSetState.emit('REDIRECT');
        setTimeout(() => { var _a; return window.location.assign(addQueryArgs(successUrl, { sc_order: (_a = checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.id })); }, 50);
      }
      else {
        this.showSuccessModal = true;
      }
      clearCheckout();
    }
  }
  getSuccessUrl() {
    var _a, _b, _c, _d, _e;
    const url = ((_b = (_a = checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.metadata) === null || _b === void 0 ? void 0 : _b.success_url) || this.successUrl;
    return url ? addQueryArgs(url, { sc_order: (_c = checkoutState.checkout) === null || _c === void 0 ? void 0 : _c.id }) : (_e = (_d = window === null || window === void 0 ? void 0 : window.scData) === null || _d === void 0 ? void 0 : _d.pages) === null || _e === void 0 ? void 0 : _e.dashboard;
  }
  handleSuccessModal() {
    if (this.showSuccessModal) {
      setTimeout(() => {
        var _a;
        (_a = this.continueButton) === null || _a === void 0 ? void 0 : _a.focus();
      }, 50);
    }
  }
  render() {
    var _a, _b, _c, _d, _e, _f, _g;
    const manualPaymentMethod = (_a = checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.manual_payment_method;
    return (h(Host, null, h("slot", null), h("sc-dialog", { open: !!this.showSuccessModal, style: { '--body-spacing': 'var(--sc-spacing-xxx-large)' }, noHeader: true, onScRequestClose: e => e.preventDefault() }, h("div", { class: "confirm__icon" }, h("div", { class: "confirm__icon-container" }, h("sc-icon", { name: "check" }))), h("sc-dashboard-module", { heading: ((_c = (_b = formState === null || formState === void 0 ? void 0 : formState.text) === null || _b === void 0 ? void 0 : _b.success) === null || _c === void 0 ? void 0 : _c.title) || __('Thanks for your order!', 'surecart'), style: { '--sc-dashboard-module-spacing': 'var(--sc-spacing-x-large)', 'textAlign': 'center' } }, h("span", { slot: "description" }, ((_e = (_d = formState === null || formState === void 0 ? void 0 : formState.text) === null || _d === void 0 ? void 0 : _d.success) === null || _e === void 0 ? void 0 : _e.description) || __('Your payment was successful. A receipt is on its way to your inbox.', 'surecart')), !!(manualPaymentMethod === null || manualPaymentMethod === void 0 ? void 0 : manualPaymentMethod.name) && !!(manualPaymentMethod === null || manualPaymentMethod === void 0 ? void 0 : manualPaymentMethod.instructions) && (h("sc-alert", { type: "info", open: true, style: { 'text-align': 'left' } }, h("span", { slot: "title" }, manualPaymentMethod === null || manualPaymentMethod === void 0 ? void 0 : manualPaymentMethod.name), h("div", { innerHTML: manualPaymentMethod === null || manualPaymentMethod === void 0 ? void 0 : manualPaymentMethod.instructions }))), h("sc-button", { href: this.getSuccessUrl(), size: "large", type: "primary", ref: el => (this.continueButton = el) }, ((_g = (_f = formState === null || formState === void 0 ? void 0 : formState.text) === null || _f === void 0 ? void 0 : _f.success) === null || _g === void 0 ? void 0 : _g.button) || __('Continue', 'surecart'), h("sc-icon", { name: "arrow-right", slot: "suffix" }))))));
  }
  static get is() { return "sc-order-confirm-provider"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-order-confirm-provider.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-order-confirm-provider.css"]
    };
  }
  static get properties() {
    return {
      "checkoutStatus": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Checkout status to listen and do payment related stuff."
        },
        "attribute": "checkout-status",
        "reflect": false
      },
      "successUrl": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Success url."
        },
        "attribute": "success-url",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "showSuccessModal": {}
    };
  }
  static get events() {
    return [{
        "method": "scOrderPaid",
        "name": "scOrderPaid",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "The order is paid event."
        },
        "complexType": {
          "original": "Checkout",
          "resolved": "Checkout",
          "references": {
            "Checkout": {
              "location": "import",
              "path": "../../../types"
            }
          }
        }
      }, {
        "method": "scSetState",
        "name": "scSetState",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        }
      }];
  }
  static get elementRef() { return "el"; }
  static get watchers() {
    return [{
        "propName": "checkoutStatus",
        "methodName": "handleConfirmOrderEvent"
      }, {
        "propName": "showSuccessModal",
        "methodName": "handleSuccessModal"
      }];
  }
}
//# sourceMappingURL=sc-order-confirm-provider.js.map
