/**
 * External dependencies.
 */
import { h } from '@stencil/core';
/**
 * Internal dependencies.
 */
import { state as errorState } from '@store/notices';
import { getAdditionalErrorMessages } from '@store/notices/getters';
/**
 * @part base - The elements base wrapper.
 * @part icon - The alert icon.
 * @part text - The alert text.
 * @part title - The alert title.
 * @part message - The alert message.
 * @part close - The close icon.
 */
export class ScFormErrorProvider {
  constructor() {
    this.error = undefined;
  }
  /** Trigger the error event when an error happens  */
  handleErrorUpdate(val) {
    this.scUpdateError.emit(val);
  }
  render() {
    return !!(errorState === null || errorState === void 0 ? void 0 : errorState.message) ? (h("sc-alert", { exportparts: "base, icon, text, title, message, close", type: "danger", scrollOnOpen: true, open: !!(errorState === null || errorState === void 0 ? void 0 : errorState.message), closable: !!(errorState === null || errorState === void 0 ? void 0 : errorState.dismissible) }, (errorState === null || errorState === void 0 ? void 0 : errorState.message) && h("span", { slot: "title", innerHTML: errorState.message }), (getAdditionalErrorMessages() || []).map((message, index) => (h("div", { innerHTML: message, key: index }))))) : null;
  }
  static get is() { return "sc-error"; }
  static get encapsulation() { return "shadow"; }
  static get properties() {
    return {
      "error": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "ResponseError | null",
          "resolved": "ResponseError",
          "references": {
            "ResponseError": {
              "location": "import",
              "path": "../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Error to display."
        }
      }
    };
  }
  static get events() {
    return [{
        "method": "scUpdateError",
        "name": "scUpdateError",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Set the state."
        },
        "complexType": {
          "original": "ResponseError",
          "resolved": "ResponseError",
          "references": {
            "ResponseError": {
              "location": "import",
              "path": "../../../types"
            }
          }
        }
      }];
  }
  static get watchers() {
    return [{
        "propName": "error",
        "methodName": "handleErrorUpdate"
      }];
  }
}
//# sourceMappingURL=sc-error.js.map
