import { h, Host } from '@stencil/core';
import { __ } from '@wordpress/i18n';
const status = {
  unshipped: __('Not Shipped', 'surecart'),
  shipped: __('Shipped', 'surecart'),
  delivered: __('Delivered', 'surecart'),
};
const type = {
  unshipped: 'default',
  shipped: 'info',
  delivered: 'success',
};
export class ScOrderStatusBadge {
  constructor() {
    this.status = undefined;
    this.size = 'medium';
    this.pill = false;
    this.clearable = false;
  }
  render() {
    // don't render if not shippable.
    if (this.status === 'unshippable') {
      return h(Host, { style: { display: 'none' } });
    }
    return (h("sc-tag", { type: type === null || type === void 0 ? void 0 : type[this === null || this === void 0 ? void 0 : this.status], pill: this.pill }, (status === null || status === void 0 ? void 0 : status[this.status]) || this.status));
  }
  static get is() { return "sc-fulfillment-shipping-status-badge"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-fulfillment-shipping-status-badge.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-fulfillment-shipping-status-badge.css"]
    };
  }
  static get properties() {
    return {
      "status": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "FulfillmentStatus",
          "resolved": "\"delivered\" | \"shipped\" | \"unshippable\" | \"unshipped\"",
          "references": {
            "FulfillmentStatus": {
              "location": "import",
              "path": "../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The tag's statux type."
        },
        "attribute": "status",
        "reflect": false
      },
      "size": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'small' | 'medium' | 'large'",
          "resolved": "\"large\" | \"medium\" | \"small\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The tag's size."
        },
        "attribute": "size",
        "reflect": true,
        "defaultValue": "'medium'"
      },
      "pill": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Draws a pill-style tag with rounded edges."
        },
        "attribute": "pill",
        "reflect": true,
        "defaultValue": "false"
      },
      "clearable": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Makes the tag clearable."
        },
        "attribute": "clearable",
        "reflect": false,
        "defaultValue": "false"
      }
    };
  }
}
//# sourceMappingURL=sc-fulfillment-shipping-status-badge.js.map
