import { h } from '@stencil/core';
import { isRtl } from '../../../functions/page-align';
/**
 * @slot image - Line item image
 * @slot title - Line item title.
 * @slot description - Line item description (below the title)
 * @slot currency - Used for the 3 character currency code.
 * @slot price - Price amount, including currency sign.
 * @slot price-description - Description for the price (i.e. monthly)
 *
 * @part base - The elements base wrapper.
 * @part image - The image wrapper.
 * @part text - The text.
 * @part title - The title.
 * @part description - Line item description (below the title)
 * @part currency - Used for the 3 character currency code.
 * @part price - Price amount, including currency sign.
 * @part price-text - The price text.
 * @part price-description - Description for the price (i.e. monthly)
 */
export class ScLineItem {
  constructor() {
    this.price = undefined;
    this.currency = undefined;
    this.hasImageSlot = undefined;
    this.hasTitleSlot = undefined;
    this.hasDescriptionSlot = undefined;
    this.hasPriceSlot = undefined;
    this.hasPriceDescriptionSlot = undefined;
    this.hasCurrencySlot = undefined;
  }
  componentWillLoad() {
    this.hasImageSlot = !!this.hostElement.querySelector('[slot="image"]');
    this.hasTitleSlot = !!this.hostElement.querySelector('[slot="title"]');
    this.hasDescriptionSlot = !!this.hostElement.querySelector('[slot="description"]');
    this.hasPriceSlot = !!this.hostElement.querySelector('[slot="price"]');
    this.hasPriceDescriptionSlot = !!this.hostElement.querySelector('[slot="price-description"]');
    this.hasCurrencySlot = !!this.hostElement.querySelector('[slot="currency"]');
  }
  render() {
    return (h("div", { part: "base", class: {
        'item': true,
        'item--has-image': this.hasImageSlot,
        'item--has-title': this.hasTitleSlot,
        'item--has-description': this.hasDescriptionSlot,
        'item--has-price': this.hasPriceSlot,
        'item--has-price-description': this.hasPriceDescriptionSlot,
        'item--has-price-currency': this.hasCurrencySlot,
        'item--is-rtl': isRtl(),
      } }, h("div", { class: "item__image", part: "image" }, h("slot", { name: "image" })), h("div", { class: "item__text", part: "text" }, h("div", { class: "item__title", part: "title" }, h("slot", { name: "title" })), h("div", { class: "item__description", part: "description" }, h("slot", { name: "description" }))), h("div", { class: "item__end", part: "price" }, h("div", { class: "item__price-currency", part: "currency" }, h("slot", { name: "currency" })), h("div", { class: "item__price-text", part: "price-text" }, h("div", { class: "item__price", part: "price" }, h("slot", { name: "price" })), h("div", { class: "item__price-description", part: "price-description" }, h("slot", { name: "price-description" }))))));
  }
  static get is() { return "sc-line-item"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-line-item.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-line-item.css"]
    };
  }
  static get properties() {
    return {
      "price": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Price of the item"
        },
        "attribute": "price",
        "reflect": false
      },
      "currency": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Currency symbol"
        },
        "attribute": "currency",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "hasImageSlot": {},
      "hasTitleSlot": {},
      "hasDescriptionSlot": {},
      "hasPriceSlot": {},
      "hasPriceDescriptionSlot": {},
      "hasCurrencySlot": {}
    };
  }
  static get elementRef() { return "hostElement"; }
}
//# sourceMappingURL=sc-line-item.js.map
