/**
 * External dependencies.
 */
import { h, Fragment, Host } from '@stencil/core';
import { __, _n, sprintf } from '@wordpress/i18n';
import { intervalString } from 'src/functions/price';
/**
 * Internal dependencies.
 */
export class ScProductPrice {
  constructor() {
    this.currency = undefined;
    this.amount = undefined;
    this.scratchAmount = undefined;
    this.saleText = undefined;
    this.adHoc = undefined;
    this.recurringPeriodCount = undefined;
    this.recurringIntervalCount = undefined;
    this.recurringInterval = undefined;
    this.setupFeeAmount = undefined;
    this.trialDurationDays = undefined;
    this.setupFeeName = undefined;
  }
  render() {
    if (this.adHoc) {
      return h(Host, { role: "paragraph" }, __('Custom Amount', 'surecart'));
    }
    return (h(Host, { role: "paragraph" }, h("div", { class: "price", id: "price" }, h("div", { class: "price__amounts" }, !!this.scratchAmount && this.scratchAmount !== this.amount && (h(Fragment, null, this.scratchAmount === 0 ? (__('Free', 'surecart')) : (h(Fragment, null, h("sc-visually-hidden", null, __('The price was', 'surecart'), " "), h("sc-format-number", { class: "price__scratch", part: "price__scratch", type: "currency", currency: this.currency, value: this.scratchAmount }), h("sc-visually-hidden", null, " ", __('now discounted to', 'surecart')))))), this.amount === 0 ? __('Free', 'surecart') : h("sc-format-number", { class: "price__amount", type: "currency", value: this.amount, currency: this.currency }), h("div", { class: "price__interval" }, this.recurringPeriodCount && 1 < this.recurringPeriodCount && (h("sc-visually-hidden", null, ' ', __('This is a repeating price. Payment will happen', 'surecart'), ' ', intervalString({
      recurring_interval_count: this.recurringIntervalCount,
      recurring_interval: this.recurringInterval,
      recurring_period_count: this.recurringPeriodCount,
    }, {
      showOnce: true,
      abbreviate: false,
      labels: {
        interval: __('every', 'surecart'),
        period: 
        /** translators: used as in time period: "for 3 months" */
        __('for', 'surecart'),
      },
    }))), h("span", { "aria-hidden": "true" }, intervalString({
      recurring_interval_count: this.recurringIntervalCount,
      recurring_interval: this.recurringInterval,
      recurring_period_count: this.recurringPeriodCount,
    }, {
      showOnce: true,
      abbreviate: false,
      labels: {
        interval: '/',
        period: 
        /** translators: used as in time period: "for 3 months" */
        __('for', 'surecart'),
      },
    }))), !!this.scratchAmount && (h("sc-tag", { type: "primary", pill: true, class: "price__sale-badge" }, this.saleText || (h(Fragment, null, h("sc-visually-hidden", null, __('This product is available for sale.', 'surecart'), " "), h("span", { "aria-hidden": "true" }, __('Sale', 'surecart'))))))), (!!(this === null || this === void 0 ? void 0 : this.trialDurationDays) || !!(this === null || this === void 0 ? void 0 : this.setupFeeAmount)) && (h("div", { class: "price__details" }, !!(this === null || this === void 0 ? void 0 : this.trialDurationDays) && (h(Fragment, null, h("sc-visually-hidden", null, sprintf(__('You have a %d-day trial before payment becomes necessary.', 'surecart'), this === null || this === void 0 ? void 0 : this.trialDurationDays)), h("span", { class: "price__trial", "aria-hidden": "true" }, sprintf(_n('Starting in %s day.', 'Starting in %s days.', this === null || this === void 0 ? void 0 : this.trialDurationDays, 'surecart'), this === null || this === void 0 ? void 0 : this.trialDurationDays)))), !!(this === null || this === void 0 ? void 0 : this.setupFeeAmount) && (h("span", { class: "price__setup-fee" }, h("sc-visually-hidden", null, __('This product has', 'surecart'), " "), ' ', h("sc-format-number", { type: "currency", value: this === null || this === void 0 ? void 0 : this.setupFeeAmount, currency: this.currency }), " ", (this === null || this === void 0 ? void 0 : this.setupFeeName) || __('Setup Fee', 'surecart'), ".")))))));
  }
  static get is() { return "sc-price"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-price.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-price.css"]
    };
  }
  static get properties() {
    return {
      "currency": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The currency."
        },
        "attribute": "currency",
        "reflect": false
      },
      "amount": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The amount"
        },
        "attribute": "amount",
        "reflect": false
      },
      "scratchAmount": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The scratch amount"
        },
        "attribute": "scratch-amount",
        "reflect": false
      },
      "saleText": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The sale text"
        },
        "attribute": "sale-text",
        "reflect": false
      },
      "adHoc": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Is the product ad_hoc?"
        },
        "attribute": "ad-hoc",
        "reflect": false
      },
      "recurringPeriodCount": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The recurring period count"
        },
        "attribute": "recurring-period-count",
        "reflect": false
      },
      "recurringIntervalCount": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The recurring interval count"
        },
        "attribute": "recurring-interval-count",
        "reflect": false
      },
      "recurringInterval": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'week' | 'month' | 'year' | 'never'",
          "resolved": "\"month\" | \"never\" | \"week\" | \"year\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The recurring interval"
        },
        "attribute": "recurring-interval",
        "reflect": false
      },
      "setupFeeAmount": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The setup fee amount"
        },
        "attribute": "setup-fee-amount",
        "reflect": false
      },
      "trialDurationDays": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The trial duration days"
        },
        "attribute": "trial-duration-days",
        "reflect": false
      },
      "setupFeeName": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The setup fee name"
        },
        "attribute": "setup-fee-name",
        "reflect": false
      }
    };
  }
}
//# sourceMappingURL=sc-price.js.map
