import { h, Fragment } from '@stencil/core';
import { __, _n, sprintf } from '@wordpress/i18n';
import { isRtl } from '../../../functions/page-align';
import { sizeImage } from '../../../functions/media';
/**
 * @part base - The component base
 * @part product-line-item - The product line item
 * @part image - The product image
 * @part text - The product text
 * @part title - The product title
 * @part suffix - The product suffix
 * @part price - The product price
 * @part price__amount - The product price amount
 * @part price__description - The product price description
 * @part price__scratch - The product price scratch
 * @part static-quantity - The product static quantity
 * @part remove-icon__base - The product remove icon
 * @part quantity - The product quantity
 * @part quantity__minus - The product quantity minus
 * @part quantity__minus-icon - The product quantity minus icon
 * @part quantity__plus - The product quantity plus
 * @part quantity__plus-icon - The product quantity plus icon
 * @part quantity__input - The product quantity input
 * @part line-item__price-description - The line item price description
 */
export class ScProductLineItem {
  constructor() {
    this.imageUrl = undefined;
    this.imageTitle = undefined;
    this.imageAlt = undefined;
    this.name = undefined;
    this.priceName = undefined;
    this.variantLabel = '';
    this.quantity = undefined;
    this.amount = undefined;
    this.fees = undefined;
    this.setupFeeTrialEnabled = true;
    this.scratchAmount = undefined;
    this.currency = undefined;
    this.interval = undefined;
    this.trialDurationDays = undefined;
    this.removable = undefined;
    this.editable = true;
    this.max = 100;
    this.sku = '';
  }
  renderPriceAndInterval() {
    const setupFee = (this.fees || []).find(fee => fee.fee_type === 'setup');
    if (this.trialDurationDays) {
      return (h("div", { class: "item__price", part: "price" }, h("div", { class: "price", part: "price__amount" }, !!setupFee && !this.setupFeeTrialEnabled ? (h(Fragment, null, setupFee === null || setupFee === void 0 ? void 0 :
        setupFee.description, " ", h("sc-format-number", { part: "price__amount", type: "currency", currency: this.currency, value: setupFee.amount }))) : (sprintf(_n('%d day free', '%d days free', this.trialDurationDays, 'surecart'), this.trialDurationDays))), h("div", { class: "price__description", part: "price__description" }, 
      /** translators: 30 days free, Then $99 per month. */
      __('Then', 'surecart'), ' ', !!this.scratchAmount && this.scratchAmount > this.amount && (h(Fragment, null, h("sc-format-number", { class: "item__scratch-price", part: "price__scratch", type: "currency", currency: this.currency, value: this.scratchAmount }), ' ')), h("sc-format-number", { part: "price__amount", type: "currency", currency: this.currency, value: this.amount }), " ", !!this.interval && this.interval, !!setupFee && !this.setupFeeTrialEnabled && sprintf(_n('starting in %d day', 'starting in %d days', this.trialDurationDays, 'surecart'), this.trialDurationDays))));
    }
    return (h("div", { class: "item__price", part: "price" }, h("div", { class: "price", part: "price__amount" }, !!this.scratchAmount && this.scratchAmount !== this.amount && (h(Fragment, null, h("sc-format-number", { class: "item__scratch-price", type: "currency", currency: this.currency, value: this.scratchAmount }), ' ')), h("sc-format-number", { type: "currency", currency: this.currency, value: this.amount })), !!this.interval && (h("div", { class: "price__description", part: "price__description" }, this.interval))));
  }
  render() {
    return (h("div", { class: "base", part: "base" }, h("div", { part: "product-line-item", class: {
        'item': true,
        'item--has-image': !!this.imageUrl,
        'item--is-rtl': isRtl(),
        'product-line-item__editable': this.editable,
        'product-line-item__removable': this.removable,
      } }, !!this.imageUrl && (h("img", { part: "image", src: sizeImage(this.imageUrl, 130), class: "item__image", alt: this.imageAlt, ...(this.imageTitle ? { title: this.imageTitle } : {}) })), h("div", { class: "item__text", part: "text" }, h("div", { class: "item__text-details" }, h("div", { class: "item__title", part: "title" }, h("slot", { name: "title" }, this.name)), h("div", { class: "item__description item__price-variant", part: "description" }, h("div", null, this.variantLabel), h("div", null, this.priceName), !!this.sku && (h("div", null, __('SKU:', 'surecart'), " ", this.sku))), !this.editable && this.quantity > 1 && (h("span", { class: "item__description", part: "static-quantity" }, __('Qty:', 'surecart'), " ", this.quantity))), this.editable && (h("sc-quantity-select", { max: this.max || Infinity, exportparts: "base:quantity, minus:quantity__minus, minus-icon:quantity__minus-icon, plus:quantity__plus, plus-icon:quantity__plus-icon, input:quantity__input", clickEl: this.el, quantity: this.quantity, size: "small", onScChange: e => e.detail && this.scUpdateQuantity.emit(e.detail), "aria-label": sprintf(__('Change Quantity - %s %s', 'surecart'), this.name, this.priceName) }))), h("div", { class: "item__suffix", part: "suffix" }, this.removable ? (h("sc-icon", { exportparts: "base:remove-icon__base", class: "item__remove", name: "x", onClick: () => this.scRemove.emit(), onKeyDown: e => {
        if (e.key === 'Enter') {
          this.scRemove.emit();
        }
      }, tabindex: "0", "aria-label": sprintf(__('Remove Item - %s %s', 'surecart'), this.name, this.priceName) })) : (h("div", null)), this.renderPriceAndInterval())), (this.fees || []).map(fee => {
      if (this.trialDurationDays && !this.setupFeeTrialEnabled && fee.fee_type === 'setup')
        return null;
      return (h("sc-line-item", { exportparts: "price-description:line-item__price-description" }, h("sc-format-number", { slot: "price-description", type: "currency", value: fee === null || fee === void 0 ? void 0 : fee.amount, currency: this.currency || 'usd' }), h("span", { slot: "price-description", class: "fee__description" }, fee === null || fee === void 0 ? void 0 : fee.description)));
    })));
  }
  static get is() { return "sc-product-line-item"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-product-line-item.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-product-line-item.css"]
    };
  }
  static get properties() {
    return {
      "imageUrl": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Url for the product image"
        },
        "attribute": "image-url",
        "reflect": false
      },
      "imageTitle": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Title for the product image"
        },
        "attribute": "image-title",
        "reflect": false
      },
      "imageAlt": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Alternative description for the product image"
        },
        "attribute": "image-alt",
        "reflect": false
      },
      "name": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Product name"
        },
        "attribute": "name",
        "reflect": false
      },
      "priceName": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": true,
        "docs": {
          "tags": [],
          "text": "Price name"
        },
        "attribute": "price-name",
        "reflect": false
      },
      "variantLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Product variant label"
        },
        "attribute": "variant-label",
        "reflect": false,
        "defaultValue": "''"
      },
      "quantity": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Quantity"
        },
        "attribute": "quantity",
        "reflect": false
      },
      "amount": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Product monetary amount"
        },
        "attribute": "amount",
        "reflect": false
      },
      "fees": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Fee[]",
          "resolved": "Fee[]",
          "references": {
            "Fee": {
              "location": "import",
              "path": "../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Product line item fees."
        }
      },
      "setupFeeTrialEnabled": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Is the setup fee not included in the free trial?"
        },
        "attribute": "setup-fee-trial-enabled",
        "reflect": false,
        "defaultValue": "true"
      },
      "scratchAmount": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The line item scratch amount"
        },
        "attribute": "scratch-amount",
        "reflect": false
      },
      "currency": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Currency for the product"
        },
        "attribute": "currency",
        "reflect": false
      },
      "interval": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Recurring interval (i.e. monthly, once, etc.)"
        },
        "attribute": "interval",
        "reflect": false
      },
      "trialDurationDays": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Trial duration days"
        },
        "attribute": "trial-duration-days",
        "reflect": false
      },
      "removable": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Is the line item removable"
        },
        "attribute": "removable",
        "reflect": false
      },
      "editable": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Can we select the quantity"
        },
        "attribute": "editable",
        "reflect": false,
        "defaultValue": "true"
      },
      "max": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The max allowed."
        },
        "attribute": "max",
        "reflect": false,
        "defaultValue": "100"
      },
      "sku": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The SKU."
        },
        "attribute": "sku",
        "reflect": false,
        "defaultValue": "''"
      }
    };
  }
  static get events() {
    return [{
        "method": "scUpdateQuantity",
        "name": "scUpdateQuantity",
        "bubbles": false,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Emitted when the quantity changes."
        },
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        }
      }, {
        "method": "scRemove",
        "name": "scRemove",
        "bubbles": false,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Emitted when the quantity changes."
        },
        "complexType": {
          "original": "void",
          "resolved": "void",
          "references": {}
        }
      }];
  }
  static get elementRef() { return "el"; }
}
//# sourceMappingURL=sc-product-line-item.js.map
