import { h, Host } from '@stencil/core';
import uiStore from '@store/ui';
import { onChange } from '@store/checkouts';
import { state as checkoutState } from '@store/checkout';
import { __, sprintf } from '@wordpress/i18n';
/**
 * @part base - The elements base wrapper.
 * @part count - The icon base wrapper.
 */
export class ScCartButton {
  constructor() {
    this.open = null;
    this.count = 0;
    this.formId = undefined;
    this.mode = 'live';
    this.cartMenuAlwaysShown = true;
    this.showEmptyCount = false;
  }
  /** Count the number of items in the cart. */
  getItemsCount() {
    var _a, _b;
    const items = (_b = (_a = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.line_items) === null || _b === void 0 ? void 0 : _b.data;
    let count = 0;
    (items || []).forEach(item => {
      count = count + (item === null || item === void 0 ? void 0 : item.quantity);
    });
    return count;
  }
  componentDidLoad() {
    this.link = this.el.closest('a');
    // this is to keep the structure that WordPress expects for theme styling.
    this.link.addEventListener('click', e => {
      e.preventDefault();
      e.stopImmediatePropagation();
      uiStore.state.cart = { ...uiStore.state.cart, open: !uiStore.state.cart.open };
      return false;
    });
    // maybe hide the parent <a> if there are no items in the cart.
    this.handleParentLinkDisplay();
    onChange(this.mode, () => this.handleParentLinkDisplay());
  }
  handleParentLinkDisplay() {
    this.link.style.display = !this.cartMenuAlwaysShown && !this.getItemsCount() ? 'none' : null;
  }
  render() {
    return (h(Host, { tabindex: 0, role: "button", "aria-label": sprintf(__('Open Cart Menu Icon with %d items.', 'surecart'), this.getItemsCount()), onKeyDown: e => {
        if ('Enter' === (e === null || e === void 0 ? void 0 : e.code) || 'Space' === (e === null || e === void 0 ? void 0 : e.code)) {
          uiStore.state.cart = { ...uiStore.state.cart, open: !uiStore.state.cart.open };
          e.preventDefault();
        }
      } }, h("div", { class: "cart__button", part: "base" }, h("div", { class: "cart__content" }, (this.showEmptyCount || !!this.getItemsCount()) && (h("span", { class: "cart__count", part: "count" }, this.getItemsCount())), h("div", { class: "cart__icon" }, h("slot", null))))));
  }
  static get is() { return "sc-cart-button"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-cart-button.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-cart-button.css"]
    };
  }
  static get properties() {
    return {
      "formId": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The form id to use for the cart."
        },
        "attribute": "form-id",
        "reflect": true
      },
      "mode": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'test' | 'live'",
          "resolved": "\"live\" | \"test\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Are we in test or live mode."
        },
        "attribute": "mode",
        "reflect": false,
        "defaultValue": "'live'"
      },
      "cartMenuAlwaysShown": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Whether the cart icon is always shown when the cart is empty"
        },
        "attribute": "cart-menu-always-shown",
        "reflect": false,
        "defaultValue": "true"
      },
      "showEmptyCount": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Whether the cart count will be shown or not when the cart is empty"
        },
        "attribute": "show-empty-count",
        "reflect": false,
        "defaultValue": "false"
      }
    };
  }
  static get states() {
    return {
      "open": {},
      "count": {}
    };
  }
  static get elementRef() { return "el"; }
}
//# sourceMappingURL=sc-cart-button.js.map
