import { h } from '@stencil/core';
import { state as checkoutState } from '@store/checkout';
import uiStore from '@store/ui';
import { __, sprintf } from '@wordpress/i18n';
/**
 * @part base - The elements base wrapper.
 * @part container - The container.
 * @part icon__base - The icon base wrapper.
 */
export class ScCartIcon {
  constructor() {
    this.icon = 'shopping-bag';
  }
  /** Count the number of items in the cart. */
  getItemsCount() {
    var _a, _b;
    const items = (_b = (_a = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.line_items) === null || _b === void 0 ? void 0 : _b.data;
    let count = 0;
    (items || []).forEach(item => {
      count = count + (item === null || item === void 0 ? void 0 : item.quantity);
    });
    return count;
  }
  /** Toggle the cart in the ui. */
  toggleCart() {
    return uiStore.set('cart', { ...uiStore.state.cart, ...{ open: !uiStore.state.cart.open } });
  }
  render() {
    var _a, _b, _c;
    if (!(checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) || ((_c = (_b = (_a = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.line_items) === null || _b === void 0 ? void 0 : _b.data) === null || _c === void 0 ? void 0 : _c.length) === 0) {
      return null;
    }
    return (h("div", { class: {
        cart: true,
      }, part: "base", onClick: () => this.toggleCart(), onKeyDown: e => {
        if ('Enter' === (e === null || e === void 0 ? void 0 : e.code) || 'Space' === (e === null || e === void 0 ? void 0 : e.code)) {
          this.toggleCart();
          e.preventDefault();
        }
      }, tabIndex: 0, role: "button", "aria-label": !uiStore.state.cart.open ? sprintf(__('Open Cart Floating Icon with %s items', 'surecart'), this.getItemsCount()) : __('Close Cart Floating Icon', 'surecart') }, h("div", { class: "cart__container", part: "container" }, h("div", { class: { cart__counter: true } }, this.getItemsCount()), h("slot", null, h("sc-icon", { exportparts: "base:icon__base", name: this.icon })))));
  }
  static get is() { return "sc-cart-icon"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-cart-icon.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-cart-icon.css"]
    };
  }
  static get properties() {
    return {
      "icon": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The icon to show."
        },
        "attribute": "icon",
        "reflect": false,
        "defaultValue": "'shopping-bag'"
      }
    };
  }
}
//# sourceMappingURL=sc-cart-icon.js.map
