import { h } from '@stencil/core';
import { __, sprintf } from '@wordpress/i18n';
import Swiper, { Navigation } from 'swiper';
export class ScImageSlider {
  constructor() {
    this.images = undefined;
    this.thumbnails = [];
    this.hasThumbnails = undefined;
    this.thumbnailsPerPage = 5;
    this.autoHeight = undefined;
    this.currentSliderIndex = 0;
    this.imagesData = [];
    this.thumbnailsData = [];
  }
  handleThumbPaginate() {
    if (!this.thumbsSwiper)
      return;
    const slideInView = this.currentSliderIndex >= this.thumbsSwiper.activeIndex && this.currentSliderIndex < this.thumbsSwiper.activeIndex + this.thumbnailsPerPage;
    if (!slideInView) {
      this.thumbsSwiper.slideTo(this.currentSliderIndex);
    }
  }
  parseImages(newValue) {
    if (newValue)
      this.imagesData = typeof newValue == 'string' ? JSON.parse(newValue) : newValue;
  }
  parseThumnails(newValue) {
    if (newValue)
      this.thumbnailsData = typeof newValue == 'string' ? JSON.parse(newValue) : newValue;
  }
  componentWillLoad() {
    this.parseImages(this.images);
    this.parseThumnails(this.thumbnails);
  }
  componentDidUpdate() {
    this.swiper.update();
  }
  componentDidLoad() {
    if (this.swiperContainerRef) {
      this.swiper = new Swiper(this.swiperContainerRef, {
        direction: 'horizontal',
        loop: false,
        autoHeight: this.autoHeight,
        centeredSlides: true,
        on: {
          slideChange: swiper => {
            this.currentSliderIndex = swiper.activeIndex;
          },
        },
      });
    }
    if (this.swiperThumbsRef) {
      this.thumbsSwiper = new Swiper(this.swiperThumbsRef, {
        modules: [Navigation],
        direction: 'horizontal',
        loop: false,
        slidesPerView: this.thumbnailsPerPage,
        slidesPerGroup: this.thumbnailsPerPage,
        spaceBetween: 10,
        centerInsufficientSlides: true,
        slideToClickedSlide: true,
        navigation: {
          nextEl: this.next,
          prevEl: this.previous,
        },
      });
    }
  }
  disconnectedCallback() {
    this.swiper.destroy(true, true);
    if (this.thumbsSwiper) {
      this.thumbsSwiper.destroy(true, true);
    }
  }
  render() {
    var _a, _b, _c;
    const thumbnails = ((_a = this.thumbnailsData) === null || _a === void 0 ? void 0 : _a.length) ? this.thumbnailsData : this.imagesData;
    return (h("div", { class: { 'image-slider': true, 'image-slider--is-fixed-height': !this.autoHeight }, part: "base" }, h("div", { class: "swiper", ref: el => (this.swiperContainerRef = el) }, h("div", { class: "swiper-wrapper" }, (this.imagesData || []).map(({ src, alt, srcset, width, height, sizes, title }, index) => (h("div", { key: index, class: "swiper-slide image-slider__slider" }, h("div", { class: "swiper-slide-img" }, h("img", { src: src, alt: alt, srcset: srcset, width: width, height: height, sizes: sizes, loading: index > 0 ? 'lazy' : 'eager', ...(title ? { title } : {}) }))))))), this.hasThumbnails && (h("div", { class: { 'image-slider__thumbs': true, 'image-slider__thumbs--has-navigation': this.images.length > 5 } }, h("button", { disabled: (_b = this.thumbsSwiper) === null || _b === void 0 ? void 0 : _b.isBeginning, class: "image-slider__navigation image-slider--is-prev", ref: el => (this.previous = el) }, h("sc-visually-hidden", null, __('Go to previous product slide.', 'surecart')), h("sc-icon", { name: "chevron-left", "aria-hidden": "true", "tab-index": "0" })), h("div", { class: "swiper", ref: el => (this.swiperThumbsRef = el) }, h("div", { class: "swiper-wrapper", role: "radiogroup", "aria-label": sprintf(__('Products slide options section. There are %d options present.', 'surecart'), (thumbnails === null || thumbnails === void 0 ? void 0 : thumbnails.length) || 0) }, (thumbnails || []).map(({ src, alt, srcset, width, height, sizes, title }, index) => (h("button", { class: { 'swiper-slide': true, 'image-slider__thumb': true, 'image-slider__thumb--is-active': this.currentSliderIndex === index }, onClick: () => { var _a, _b; return (_b = (_a = this.swiper) === null || _a === void 0 ? void 0 : _a.slideTo) === null || _b === void 0 ? void 0 : _b.call(_a, index); }, role: "radio", "aria-checked": this.currentSliderIndex === index ? 'true' : 'false', tabindex: "0" }, h("img", { src: src, alt: sprintf(__('Product image number %d, %s', 'sc-image-slider'), index + 1, alt), ...(title ? { title } : {}), srcset: srcset, width: width, height: height, sizes: sizes, loading: index > this.thumbnailsPerPage - 1 ? 'lazy' : 'eager' })))))), h("button", { disabled: (_c = this.thumbsSwiper) === null || _c === void 0 ? void 0 : _c.isEnd, class: "image-slider__navigation image-slider--is-next", ref: el => (this.next = el) }, h("sc-visually-hidden", null, __('Go to next product slide.', 'surecart')), h("sc-icon", { name: "chevron-right", "aria-hidden": "true", "tab-index": "0" }))))));
  }
  static get is() { return "sc-image-slider"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-image-slider.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-image-slider.css"]
    };
  }
  static get properties() {
    return {
      "images": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string | { src: string; alt: string; srcset; width: number; height: number; sizes: string; title: string }[]",
          "resolved": "string | { src: string; alt: string; srcset: any; width: number; height: number; sizes: string; title: string; }[]",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Accept a string or an array of objects"
        },
        "attribute": "images",
        "reflect": false
      },
      "thumbnails": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string | { src: string; alt: string; srcset; width: number; height: number; sizes: string; title: string }[]",
          "resolved": "string | { src: string; alt: string; srcset: any; width: number; height: number; sizes: string; title: string; }[]",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "thumbnails",
        "reflect": false,
        "defaultValue": "[]"
      },
      "hasThumbnails": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "has-thumbnails",
        "reflect": false
      },
      "thumbnailsPerPage": {
        "type": "number",
        "mutable": false,
        "complexType": {
          "original": "number",
          "resolved": "number",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "thumbnails-per-page",
        "reflect": false,
        "defaultValue": "5"
      },
      "autoHeight": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "auto-height",
        "reflect": false
      }
    };
  }
  static get states() {
    return {
      "currentSliderIndex": {},
      "imagesData": {},
      "thumbnailsData": {}
    };
  }
  static get watchers() {
    return [{
        "propName": "currentSliderIndex",
        "methodName": "handleThumbPaginate"
      }, {
        "propName": "images",
        "methodName": "parseImages"
      }, {
        "propName": "thumbnails",
        "methodName": "parseThumnails"
      }];
  }
}
//# sourceMappingURL=sc-image-slider.js.map
