import { Fragment, h } from '@stencil/core';
import { __, sprintf, _n } from '@wordpress/i18n';
import { intervalString } from '../../../functions/price';
export class ScPriceChoiceContainer {
  constructor() {
    this.price = undefined;
    this.loading = false;
    this.label = undefined;
    this.showLabel = true;
    this.showPrice = true;
    this.showControl = false;
    this.description = undefined;
    this.type = undefined;
    this.required = false;
    this.checked = false;
    this.priceData = undefined;
  }
  handlePriceChange() {
    this.priceData = typeof this.price === 'string' ? JSON.parse(this.price) : this.price;
  }
  componentWillLoad() {
    this.handlePriceChange();
  }
  renderPrice() {
    var _a, _b;
    return (h(Fragment, null, h("sc-format-number", { type: "currency", value: (_a = this.priceData) === null || _a === void 0 ? void 0 : _a.amount, currency: (_b = this.priceData) === null || _b === void 0 ? void 0 : _b.currency }), intervalString(this.priceData, {
      showOnce: true,
      abbreviate: true,
      labels: {
        interval: '/',
        period: 
        /** translators: used as in time period: "for 3 months" */
        __('for', 'surecart'),
      },
    })));
  }
  render() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o;
    if (this.loading) {
      return (h("sc-choice-container", { showControl: this.showControl, name: "loading", disabled: true }, h("div", { class: "price-choice" }, h("sc-skeleton", { style: { width: '60px', display: 'inline-block' } }), h("sc-skeleton", { style: { width: '80px', display: 'inline-block' } }))));
    }
    return (h("sc-choice-container", { value: (_a = this.priceData) === null || _a === void 0 ? void 0 : _a.id, type: this.type, showControl: this.showControl, checked: this.checked, onScChange: () => this.scChange.emit(), required: this.required }, h("div", { class: "price-choice" }, this.showLabel && (h("div", { class: "price-choice__title" }, h("div", { class: "price-choice__name" }, this.label || this.priceData.name), !!this.description && h("div", { class: "price-choice__description" }, this.description))), this.showPrice && (h("div", { class: "price-choice__details" }, h("div", { class: "price-choice__price" }, ((_b = this.priceData) === null || _b === void 0 ? void 0 : _b.ad_hoc) ? (__('Custom Amount', 'surecart')) : (h(Fragment, null, h("sc-format-number", { type: "currency", value: (_c = this.priceData) === null || _c === void 0 ? void 0 : _c.amount, currency: (_d = this.priceData) === null || _d === void 0 ? void 0 : _d.currency }), ((_e = this.priceData) === null || _e === void 0 ? void 0 : _e.recurring_period_count) && 1 <= ((_f = this.priceData) === null || _f === void 0 ? void 0 : _f.recurring_period_count) && (h("sc-visually-hidden", null, ' ', __('This is a repeating price. Payment will happen', 'surecart'), ' ', intervalString(this.priceData, {
      showOnce: true,
      abbreviate: false,
      labels: {
        interval: __('every', 'surecart'),
        period: 
        /** translators: used as in time period: "for 3 months" */
        __('for', 'surecart'),
      },
    }))), h("span", { "aria-hidden": "true" }, intervalString(this.priceData, {
      showOnce: true,
      abbreviate: true,
      labels: {
        interval: '/',
        period: 
        /** translators: used as in time period: "for 3 months" */
        __('for', 'surecart'),
      },
    }))))), !!((_g = this.priceData) === null || _g === void 0 ? void 0 : _g.trial_duration_days) && (h(Fragment, null, h("sc-visually-hidden", null, sprintf(__('You have a %d-day trial before payment becomes necessary.', 'surecart'), (_h = this.priceData) === null || _h === void 0 ? void 0 : _h.trial_duration_days)), h("div", { class: "price-choice__trial", "aria-hidden": "true" }, sprintf(_n('Starting in %s day', 'Starting in %s days', this.priceData.trial_duration_days, 'surecart'), this.priceData.trial_duration_days)))), !!((_j = this.priceData) === null || _j === void 0 ? void 0 : _j.setup_fee_enabled) && ((_k = this.priceData) === null || _k === void 0 ? void 0 : _k.setup_fee_amount) && (h("div", { class: "price-choice__setup-fee" }, h("sc-visually-hidden", null, __('This payment plan has', 'surecart'), " "), h("sc-format-number", { type: "currency", value: Math.abs(this.priceData.setup_fee_amount), currency: (_l = this.priceData) === null || _l === void 0 ? void 0 : _l.currency }), ' ', ((_m = this.priceData) === null || _m === void 0 ? void 0 : _m.setup_fee_name) || (((_o = this.priceData) === null || _o === void 0 ? void 0 : _o.setup_fee_amount) < 0 ? __('Discount', 'surecart') : __('Setup Fee', 'surecart')))))))));
  }
  static get is() { return "sc-price-choice-container"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-price-choice-container.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-price-choice-container.css"]
    };
  }
  static get properties() {
    return {
      "price": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string | Price",
          "resolved": "Price | string",
          "references": {
            "Price": {
              "location": "import",
              "path": "src/types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Stores the price"
        },
        "attribute": "price",
        "reflect": false
      },
      "loading": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Is this loading"
        },
        "attribute": "loading",
        "reflect": false,
        "defaultValue": "false"
      },
      "label": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Label for the choice."
        },
        "attribute": "label",
        "reflect": false
      },
      "showLabel": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Show the label"
        },
        "attribute": "show-label",
        "reflect": false,
        "defaultValue": "true"
      },
      "showPrice": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Show the price amount"
        },
        "attribute": "show-price",
        "reflect": false,
        "defaultValue": "true"
      },
      "showControl": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Show the radio/checkbox control"
        },
        "attribute": "show-control",
        "reflect": false,
        "defaultValue": "false"
      },
      "description": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Label for the choice."
        },
        "attribute": "description",
        "reflect": false
      },
      "type": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'checkbox' | 'radio'",
          "resolved": "\"checkbox\" | \"radio\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Choice Type"
        },
        "attribute": "type",
        "reflect": false
      },
      "required": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": ""
        },
        "attribute": "required",
        "reflect": false,
        "defaultValue": "false"
      },
      "checked": {
        "type": "boolean",
        "mutable": true,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Is this checked by default"
        },
        "attribute": "checked",
        "reflect": true,
        "defaultValue": "false"
      }
    };
  }
  static get states() {
    return {
      "priceData": {}
    };
  }
  static get events() {
    return [{
        "method": "scChange",
        "name": "scChange",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": ""
        },
        "complexType": {
          "original": "void",
          "resolved": "void",
          "references": {}
        }
      }];
  }
  static get watchers() {
    return [{
        "propName": "price",
        "methodName": "handlePriceChange"
      }];
  }
}
//# sourceMappingURL=sc-price-choice-container.js.map
