import { Host, h } from '@stencil/core';
import { __ } from '@wordpress/i18n';
export class ScPriceRange {
  constructor() {
    this.prices = undefined;
    this.minPrice = undefined;
    this.maxPrice = undefined;
  }
  handlePricesChange() {
    let min, max;
    (this.prices || [])
      .filter(p => !(p === null || p === void 0 ? void 0 : p.archived))
      .forEach(price => {
      if (!max || price.amount > max.amount) {
        max = price;
      }
      if (!min || price.amount < min.amount) {
        min = price;
      }
    });
    this.minPrice = min;
    this.maxPrice = max;
  }
  componentWillLoad() {
    this.handlePricesChange();
  }
  render() {
    if (!this.maxPrice || !this.minPrice) {
      return h(Host, null);
    }
    return (h(Host, null, this.maxPrice.amount == this.minPrice.amount ? (h("span", null, h("sc-format-number", { type: "currency", currency: this.maxPrice.currency, value: this.maxPrice.amount }))) : (h("span", null, h("sc-visually-hidden", null, __('Price range from', 'surecart'), " "), h("sc-format-number", { type: "currency", currency: this.minPrice.currency, value: this.minPrice.amount }), h("span", { "aria-hidden": true }, ' — '), h("sc-visually-hidden", null, __('to', 'surecart')), h("sc-format-number", { type: "currency", currency: this.maxPrice.currency, value: this.maxPrice.amount })))));
  }
  static get is() { return "sc-price-range"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-price-range.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-price-range.css"]
    };
  }
  static get properties() {
    return {
      "prices": {
        "type": "unknown",
        "mutable": false,
        "complexType": {
          "original": "Price[]",
          "resolved": "Price[]",
          "references": {
            "Price": {
              "location": "import",
              "path": "../../../types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The array of price objects"
        }
      }
    };
  }
  static get states() {
    return {
      "minPrice": {},
      "maxPrice": {}
    };
  }
  static get watchers() {
    return [{
        "propName": "prices",
        "methodName": "handlePricesChange"
      }];
  }
}
//# sourceMappingURL=sc-price-range.js.map
