import { h, Host } from '@stencil/core';
import { __, sprintf } from '@wordpress/i18n';
import { state as checkoutState } from '@store/checkout';
import { lockCheckout, unLockCheckout } from '@store/checkout/mutations';
import { createOrUpdateCheckout } from '@services/session';
import { checkoutIsLocked } from '@store/checkout/getters';
import { createErrorNotice } from '@store/notices/mutations';
import { speak } from '@wordpress/a11y';
import { getFormattedPrice } from '../../../functions/price';
/**
 * @part base - The elements base wrapper.
 * @part empty - The empty message.
 * @part block-ui - The block ui loader.
 * @part radio__base - The radio base wrapper.
 * @part radio__label - The radio label.
 * @part radio__control - The radio control wrapper.
 * @part radio__checked-icon - The radio checked icon.
 */
export class ScShippingChoices {
  constructor() {
    this.label = undefined;
    this.showDescription = true;
  }
  /** Maybe update the order. */
  async updateCheckout(selectedShippingChoiceId) {
    if (!selectedShippingChoiceId)
      return;
    try {
      lockCheckout('selected_shipping_choice');
      checkoutState.checkout = (await createOrUpdateCheckout({
        id: checkoutState.checkout.id,
        data: {
          selected_shipping_choice_id: selectedShippingChoiceId,
        },
      }));
      speak(__('Shipping choice updated.', 'surecart'), 'assertive');
      const { total_amount, currency } = checkoutState.checkout;
      /** translators: %1$s: formatted amount */
      speak(sprintf(__('Your order total has changed to: %1$s.', 'surecart'), getFormattedPrice({ amount: total_amount, currency })), 'assertive');
    }
    catch (e) {
      console.error(e);
      createErrorNotice(e);
    }
    finally {
      unLockCheckout('selected_shipping_choice');
    }
  }
  render() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
    // shipping choice is not rewquired.
    if (!((_a = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.selected_shipping_choice_required)) {
      return h(Host, { style: { display: 'none' } });
    }
    // no shipping choices but no country either
    if (!((_d = (_c = (_b = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _b === void 0 ? void 0 : _b.shipping_choices) === null || _c === void 0 ? void 0 : _c.data) === null || _d === void 0 ? void 0 : _d.length) && !((_f = (_e = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _e === void 0 ? void 0 : _e.shipping_address) === null || _f === void 0 ? void 0 : _f.country)) {
      return (h("sc-form-control", { label: this.label || __('Shipping', 'surecart') }, h("div", { class: "shipping-choice__empty" }, __('To check available shipping choices, please provide your shipping country in the address section.', 'surecart'))));
    }
    // no shipping choices yet.
    if (!((_j = (_h = (_g = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _g === void 0 ? void 0 : _g.shipping_choices) === null || _h === void 0 ? void 0 : _h.data) === null || _j === void 0 ? void 0 : _j.length)) {
      return (h("sc-form-control", { part: "empty", label: this.label || __('Shipping', 'surecart') }, h("div", { class: "shipping-choice__empty" }, __('Sorry, we are not able to ship to your address.', 'surecart'))));
    }
    return (h(Host, null, h("sc-radio-group", { part: "base", label: this.label || __('Shipping', 'surecart'), class: "shipping-choices", onScChange: e => this.updateCheckout(e.detail) }, (((_l = (_k = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _k === void 0 ? void 0 : _k.shipping_choices) === null || _l === void 0 ? void 0 : _l.data) || []).map(({ id, amount, currency, shipping_method }) => {
      var _a;
      return (h("sc-radio", { key: id, checked: ((_a = checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.checkout) === null || _a === void 0 ? void 0 : _a.selected_shipping_choice) === id, exportparts: "base:radio__base,label:radio__label,control:radio__control,checked-icon:radio__checked-icon", class: "shipping-choice", value: id }, h("div", { class: "shipping-choice__text" }, h("div", { class: "shipping-choice__name" }, (shipping_method === null || shipping_method === void 0 ? void 0 : shipping_method.name) || __('Standard Shipping', 'surecart')), this.showDescription && !!(shipping_method === null || shipping_method === void 0 ? void 0 : shipping_method.description) && (h("div", { class: "shipping-choice__description" }, shipping_method === null || shipping_method === void 0 ? void 0 : shipping_method.description))), h("div", { class: "shipping-choice__price" }, !!amount ? h("sc-format-number", { type: "currency", value: amount, currency: currency }) : __('Free', 'surecart'))));
    })), checkoutIsLocked('selected_shipping_choice') && h("sc-block-ui", null)));
  }
  static get is() { return "sc-shipping-choices"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-shipping-choices.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-shipping-choices.css"]
    };
  }
  static get properties() {
    return {
      "label": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The shipping section label"
        },
        "attribute": "label",
        "reflect": false
      },
      "showDescription": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Whether to show the shipping choice description"
        },
        "attribute": "show-description",
        "reflect": false,
        "defaultValue": "true"
      }
    };
  }
}
//# sourceMappingURL=sc-shipping-choices.js.map
