import { h, Fragment } from '@stencil/core';
import { __, sprintf } from '@wordpress/i18n';
import { speak } from '@wordpress/a11y';
import { zones, getType } from '../../../functions/tax';
export class ScTaxIdInput {
  constructor() {
    this.country = undefined;
    this.show = false;
    this.type = 'other';
    this.number = null;
    this.status = 'unknown';
    this.loading = undefined;
    this.help = undefined;
    this.otherLabel = __('Tax ID', 'surecart');
    this.caGstLabel = __('GST Number', 'surecart');
    this.auAbnLabel = __('ABN Number', 'surecart');
    this.gbVatLabel = __('UK VAT', 'surecart');
    this.euVatLabel = __('EU VAT', 'surecart');
    this.required = false;
  }
  async reportValidity() {
    return this.input.reportValidity();
  }
  onLabelChange() {
    zones.ca_gst.label = this.caGstLabel || zones.ca_gst.label;
    zones.au_abn.label = this.auAbnLabel || zones.au_abn.label;
    zones.gb_vat.label = this.gbVatLabel || zones.gb_vat.label;
    zones.eu_vat.label = this.euVatLabel || zones.eu_vat.label;
    zones.other.label = this.otherLabel || zones.other.label;
  }
  componentWillLoad() {
    if (this.country && !this.type) {
      this.type = getType(this.country);
    }
    this.onLabelChange();
  }
  renderStatus() {
    if (this.status === 'valid') {
      return h("sc-icon", { name: "check", slot: "prefix", style: { color: 'var(--sc-color-success-500)' } });
    }
    if (this.status === 'invalid') {
      return h("sc-icon", { name: "x", slot: "prefix", style: { color: 'var(--sc-color-danger-500)' } });
    }
  }
  render() {
    var _a, _b;
    return (h(Fragment, null, h("sc-input", { name: "tax_identifier.number_type", required: this.required, value: this.type, style: { display: 'none' } }), h("sc-input", { ref: el => (this.input = el), label: (_a = zones === null || zones === void 0 ? void 0 : zones[(this === null || this === void 0 ? void 0 : this.type) || 'other']) === null || _a === void 0 ? void 0 : _a.label, "aria-label": __('Tax ID', 'surecart'), placeholder: __('Enter Tax ID', 'surecart'), name: "tax_identifier.number", value: this.number, onScInput: (e) => {
        e.stopImmediatePropagation();
        this.scInput.emit({
          number: e.target.value,
          number_type: this.type || 'other',
        });
      }, onScChange: (e) => {
        e.stopImmediatePropagation();
        this.scChange.emit({
          number: e.target.value,
          number_type: this.type || 'other',
        });
      }, required: this.required }, this.loading && this.type === 'eu_vat' ? h("sc-spinner", { slot: "prefix", style: { '--spinner-size': '10px' } }) : this.renderStatus(), h("sc-dropdown", { slot: "suffix", position: "bottom-right", role: "select", "aria-multiselectable": "false", "aria-label": __('Select number type', 'surecart') }, h("sc-button", { type: "text", slot: "trigger", caret: true, loading: false, style: { color: 'var(--sc-input-label-color)' }, tabindex: "0" }, (_b = zones === null || zones === void 0 ? void 0 : zones[(this === null || this === void 0 ? void 0 : this.type) || 'other']) === null || _b === void 0 ? void 0 : _b.label_small), h("sc-menu", null, Object.keys(zones || {}).map(name => (h("sc-menu-item", { role: "option", onClick: () => {
        this.scInput.emit({
          number: this.number,
          number_type: name,
        });
        this.scChange.emit({
          number: this.number,
          number_type: name,
        });
        this.type = name;
      }, onKeyDown: e => {
        var _a;
        if (e.key === 'Enter') {
          this.scInput.emit({
            number: this.number,
            number_type: name,
          });
          this.scChange.emit({
            number: this.number,
            number_type: name,
          });
          this.type = name;
          (_a = this.input) === null || _a === void 0 ? void 0 : _a.triggerFocus();
          speak(sprintf(__('%s selected', 'surecart'), zones[name].label_small, 'assertive'));
        }
      }, checked: this.type === name, "aria-selected": this.type === name ? 'true' : 'false', "aria-label": zones[name].label_small }, zones[name].label_small))))))));
  }
  static get is() { return "sc-tax-id-input"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["sc-tax-id-input.css"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["sc-tax-id-input.css"]
    };
  }
  static get properties() {
    return {
      "country": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The country code."
        },
        "attribute": "country",
        "reflect": false
      },
      "show": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Force show the field."
        },
        "attribute": "show",
        "reflect": false,
        "defaultValue": "false"
      },
      "type": {
        "type": "string",
        "mutable": true,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Type of tax id"
        },
        "attribute": "type",
        "reflect": false,
        "defaultValue": "'other'"
      },
      "number": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Tax ID Number"
        },
        "attribute": "number",
        "reflect": false,
        "defaultValue": "null"
      },
      "status": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "'valid' | 'invalid' | 'unknown'",
          "resolved": "\"invalid\" | \"unknown\" | \"valid\"",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The status"
        },
        "attribute": "status",
        "reflect": false,
        "defaultValue": "'unknown'"
      },
      "loading": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Is this loading?"
        },
        "attribute": "loading",
        "reflect": false
      },
      "help": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Help text."
        },
        "attribute": "help",
        "reflect": false
      },
      "otherLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Other zones label"
        },
        "attribute": "other-label",
        "reflect": false,
        "defaultValue": "__('Tax ID', 'surecart')"
      },
      "caGstLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "GST zone label"
        },
        "attribute": "ca-gst-label",
        "reflect": false,
        "defaultValue": "__('GST Number', 'surecart')"
      },
      "auAbnLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "AU zone label"
        },
        "attribute": "au-abn-label",
        "reflect": false,
        "defaultValue": "__('ABN Number', 'surecart')"
      },
      "gbVatLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "UK zone label"
        },
        "attribute": "gb-vat-label",
        "reflect": false,
        "defaultValue": "__('UK VAT', 'surecart')"
      },
      "euVatLabel": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "EU zone label"
        },
        "attribute": "eu-vat-label",
        "reflect": false,
        "defaultValue": "__('EU VAT', 'surecart')"
      },
      "required": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Whether tax input is required"
        },
        "attribute": "required",
        "reflect": true,
        "defaultValue": "false"
      }
    };
  }
  static get events() {
    return [{
        "method": "scChange",
        "name": "scChange",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Make a request to update the order."
        },
        "complexType": {
          "original": "{ number: string; number_type: string }",
          "resolved": "{ number: string; number_type: string; }",
          "references": {}
        }
      }, {
        "method": "scInput",
        "name": "scInput",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Make a request to update the order."
        },
        "complexType": {
          "original": "Partial<{ number: string; number_type: string }>",
          "resolved": "{ number?: string; number_type?: string; }",
          "references": {
            "Partial": {
              "location": "global"
            }
          }
        }
      }, {
        "method": "scInputType",
        "name": "scInputType",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Change the Type"
        },
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        }
      }, {
        "method": "scSetState",
        "name": "scSetState",
        "bubbles": true,
        "cancelable": true,
        "composed": true,
        "docs": {
          "tags": [],
          "text": "Set the checkout state."
        },
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        }
      }];
  }
  static get methods() {
    return {
      "reportValidity": {
        "complexType": {
          "signature": "() => Promise<boolean>",
          "parameters": [],
          "references": {
            "Promise": {
              "location": "global"
            }
          },
          "return": "Promise<boolean>"
        },
        "docs": {
          "text": "",
          "tags": []
        }
      }
    };
  }
  static get watchers() {
    return [{
        "propName": "otherLabel",
        "methodName": "onLabelChange"
      }, {
        "propName": "caGstLabel",
        "methodName": "onLabelChange"
      }, {
        "propName": "auAbnLabel",
        "methodName": "onLabelChange"
      }, {
        "propName": "gbVatLabel",
        "methodName": "onLabelChange"
      }, {
        "propName": "euVatLabel",
        "methodName": "onLabelChange"
      }];
  }
}
//# sourceMappingURL=sc-tax-id-input.js.map
