import { on } from './store';
import { on as onUIChange } from '@store/ui';
import { state as checkoutState } from '@store/checkout';
// Listen to all stored checkouts and handle line item changes.
on('set', (_, value, oldValue) => Object.keys(value || {}).forEach(key => handleCheckoutLineItemChange(value[key], oldValue === null || oldValue === void 0 ? void 0 : oldValue[key])));
/**
 * Add to cart/remove from cart, cart updated events.
 */
export const handleCheckoutLineItemChange = (checkout, oldCheckout) => {
  var _a, _b;
  // get new and old line items.
  const newLineItems = ((_a = checkout === null || checkout === void 0 ? void 0 : checkout.line_items) === null || _a === void 0 ? void 0 : _a.data) || [];
  const oldLineItems = ((_b = oldCheckout === null || oldCheckout === void 0 ? void 0 : oldCheckout.line_items) === null || _b === void 0 ? void 0 : _b.data) || [];
  // check for added items or quantity changed
  newLineItems.forEach(newItem => {
    const oldItem = oldLineItems.find(item => item.id === newItem.id);
    // an item was added, or the quantity changed.
    if (!oldItem || (oldItem === null || oldItem === void 0 ? void 0 : oldItem.quantity) < (newItem === null || newItem === void 0 ? void 0 : newItem.quantity)) {
      const event = new CustomEvent('scAddedToCart', {
        detail: {
          ...newItem,
          quantity: newItem.quantity - ((oldItem === null || oldItem === void 0 ? void 0 : oldItem.quantity) || 0),
        },
        bubbles: true,
      });
      document.dispatchEvent(event);
    }
  });
  // check for removed items or quantity changed
  oldLineItems.forEach(oldItem => {
    const newItem = newLineItems.find(item => item.id === oldItem.id);
    // an item was removed, or the quantity changed.
    if (!newItem || (oldItem === null || oldItem === void 0 ? void 0 : oldItem.quantity) > (newItem === null || newItem === void 0 ? void 0 : newItem.quantity)) {
      const event = new CustomEvent('scRemovedFromCart', {
        detail: {
          ...oldItem,
          quantity: oldItem.quantity - ((newItem === null || newItem === void 0 ? void 0 : newItem.quantity) || 0),
        },
        bubbles: true,
      });
      document.dispatchEvent(event);
    }
  });
  // check if line items have changed.
  if (!(checkoutState === null || checkoutState === void 0 ? void 0 : checkoutState.isCheckoutPage) && JSON.stringify(newLineItems) !== JSON.stringify(oldLineItems)) {
    // emit an event here with the checkout state updates.
    const event = new CustomEvent('scCartUpdated', {
      detail: {
        currentCart: checkout,
        previousCart: oldCheckout,
      },
      bubbles: true,
    });
    document.dispatchEvent(event);
  }
};
/**
 * Handle view cart event.
 */
onUIChange('set', (key, newValue, oldValue) => {
  if (key !== 'cart')
    return; // we only care about cart.
  if ((newValue === null || newValue === void 0 ? void 0 : newValue.open) === (oldValue === null || oldValue === void 0 ? void 0 : oldValue.open))
    return; // we only care about open state changes.
  if (newValue === null || newValue === void 0 ? void 0 : newValue.open) {
    const event = new CustomEvent('scViewedCart', {
      detail: checkoutState.checkout,
      bubbles: true,
    });
    document.dispatchEvent(event);
  }
});
//# sourceMappingURL=events.js.map
