import { getValidAdHocAmount } from './getters';
import { updateLineItem } from './mutations';
import state, { on, set } from './store';
import { onChange } from '../checkout/store';
import { isInRange } from '../../functions/util';
import { getLineItemByProductId } from '@store/checkout/getters';
// when the checkout changes, update the selected price and ad hoc amount
onChange('checkout', () => {
  Object.keys(state).forEach(productId => {
    var _a;
    const lineItem = getLineItemByProductId(productId);
    // line item is updated, update the store
    if (lineItem) {
      return set(productId, {
        ...state[productId],
        selectedPrice: lineItem.price,
        ad_hoc_amount: lineItem.ad_hoc_amount,
        custom_amount: ((_a = (state[productId].amounts || [])) === null || _a === void 0 ? void 0 : _a.includes(lineItem.ad_hoc_amount)) ? null : lineItem.ad_hoc_amount,
      });
    }
    // line item is deleted, reset the store
    set(productId, {
      ...state[productId],
      selectedPrice: null,
      ad_hoc_amount: null,
      custom_amount: null,
    });
  });
});
// for each product
Object.keys(state).forEach(productId => {
  // when the product is updated
  on('set', (prop, val, prev) => {
    var _a, _b, _c, _d, _e, _f;
    // if the product is the one we're looking for
    if (prop !== productId)
      return;
    // It's been cleared.
    if (!(val === null || val === void 0 ? void 0 : val.selectedPrice) && !(val === null || val === void 0 ? void 0 : val.ad_hoc_amount) && !(val === null || val === void 0 ? void 0 : val.custom_amount))
      return;
    // and the selectedPrice has changed
    if (((_a = val === null || val === void 0 ? void 0 : val.selectedPrice) === null || _a === void 0 ? void 0 : _a.id) !== ((_b = prev === null || prev === void 0 ? void 0 : prev.selectedPrice) === null || _b === void 0 ? void 0 : _b.id) || (val === null || val === void 0 ? void 0 : val.ad_hoc_amount) !== (prev === null || prev === void 0 ? void 0 : prev.ad_hoc_amount) || (val === null || val === void 0 ? void 0 : val.custom_amount) !== (prev === null || prev === void 0 ? void 0 : prev.custom_amount)) {
      // use custom amount if it's in range, otherwise use the first valid amount
      const ad_hoc_amount = (val === null || val === void 0 ? void 0 : val.custom_amount) && isInRange(val === null || val === void 0 ? void 0 : val.custom_amount, val.selectedPrice) ? val === null || val === void 0 ? void 0 : val.custom_amount : getValidAdHocAmount(productId);
      const price = ((_c = val.selectedPrice) === null || _c === void 0 ? void 0 : _c.id) || ((_f = (_e = (_d = val.product) === null || _d === void 0 ? void 0 : _d.prices) === null || _e === void 0 ? void 0 : _e.data.find(price => price === null || price === void 0 ? void 0 : price.ad_hoc)) === null || _f === void 0 ? void 0 : _f.id);
      // if there's no price, return
      if (!price)
        return;
      // update the line item
      updateLineItem(productId, {
        price,
        quantity: 1,
        ad_hoc_amount,
      });
    }
  });
});
//# sourceMappingURL=watchers.js.map
