import state, { on } from './store';
import { setProduct } from './setters';
import { getVariantFromValues } from '../../functions/util';
import { isStockNeedsToBeChecked } from './getters';
import { speak } from '@wordpress/a11y';
import { __, sprintf } from '@wordpress/i18n';
/** Handle set event on products store. */
on('set', (productId, newValue, oldValue) => {
  var _a, _b, _c, _d;
  if (((_a = newValue === null || newValue === void 0 ? void 0 : newValue.selectedPrice) === null || _a === void 0 ? void 0 : _a.id) !== ((_b = oldValue === null || oldValue === void 0 ? void 0 : oldValue.selectedPrice) === null || _b === void 0 ? void 0 : _b.id)) {
    updateSelectedPrice(productId, newValue);
  }
  // if variants change, check the stock.
  if (((_c = newValue === null || newValue === void 0 ? void 0 : newValue.selectedVariant) === null || _c === void 0 ? void 0 : _c.id) !== ((_d = oldValue === null || oldValue === void 0 ? void 0 : oldValue.selectedVariant) === null || _d === void 0 ? void 0 : _d.id)) {
    handleStockWithSelectedVariant(productId);
  }
  const shouldUpdateLineItem = !oldValue || ['selectedPrice', 'adHocAmount', 'quantity', 'selectedVariant'].some(key => JSON.stringify(newValue[key]) !== JSON.stringify(oldValue[key]));
  if (shouldUpdateLineItem) {
    setLineItem(productId);
  }
  const shouldUpdateVariants = !oldValue || JSON.stringify(newValue === null || newValue === void 0 ? void 0 : newValue.variantValues) !== JSON.stringify(oldValue === null || oldValue === void 0 ? void 0 : oldValue.variantValues);
  if (shouldUpdateVariants) {
    updateSelectedVariant(productId, newValue);
  }
});
/**
 * Update the selected variant based on chosen values.
 */
const updateSelectedVariant = (productId, newValue) => {
  const matchedVariant = getVariantFromValues({ variants: state[productId].variants, values: newValue === null || newValue === void 0 ? void 0 : newValue.variantValues });
  if (matchedVariant) {
    setProduct(productId, { selectedVariant: matchedVariant });
  }
};
/**
 * Handle when the selected variant changes.
 */
const handleStockWithSelectedVariant = (productId) => {
  var _a, _b, _c;
  // make sure we have a selected variant and stock needs to be checked.
  if (!state[productId].selectedVariant || !isStockNeedsToBeChecked) {
    return;
  }
  // if available stock is less than the quantity, adjust the quantity to the max available.
  if (((_a = state[productId]) === null || _a === void 0 ? void 0 : _a.selectedVariant.available_stock) < ((_b = state[productId]) === null || _b === void 0 ? void 0 : _b.quantity)) {
    state[productId].quantity = ((_c = state[productId]) === null || _c === void 0 ? void 0 : _c.selectedVariant.available_stock) || 1;
    speak(sprintf(__('There are just %d items left in stock, and the quantity has been adjusted to %d.', 'surecart'), state[productId].quantity, state[productId].quantity), 'assertive');
  }
};
const updateSelectedPrice = (productId, newValue) => {
  var _a, _b, _c, _d;
  setProduct(productId, {
    // update the total when the selected price changes.
    total: state[productId].adHocAmount || ((_a = newValue === null || newValue === void 0 ? void 0 : newValue.selectedPrice) === null || _a === void 0 ? void 0 : _a.amount) || 0,
    // set the ad hoc amount to the selected product amount.
    adHocAmount: (_b = newValue === null || newValue === void 0 ? void 0 : newValue.selectedPrice) === null || _b === void 0 ? void 0 : _b.amount,
    // update disabled based on if price is archived or product is archived.
    disabled: ((_c = newValue === null || newValue === void 0 ? void 0 : newValue.selectedPrice) === null || _c === void 0 ? void 0 : _c.archived) || ((_d = state[productId].product) === null || _d === void 0 ? void 0 : _d.archived),
  });
};
const setLineItem = (productId) => {
  var _a, _b, _c, _d, _e, _f, _g, _h;
  setProduct(productId, {
    line_item: {
      price_id: (_b = (_a = state[productId]) === null || _a === void 0 ? void 0 : _a.selectedPrice) === null || _b === void 0 ? void 0 : _b.id,
      quantity: Math.max(((_d = (_c = state[productId]) === null || _c === void 0 ? void 0 : _c.selectedPrice) === null || _d === void 0 ? void 0 : _d.ad_hoc) ? 1 : state[productId].quantity, 1),
      ...(((_f = (_e = state[productId]) === null || _e === void 0 ? void 0 : _e.selectedPrice) === null || _f === void 0 ? void 0 : _f.ad_hoc) ? { ad_hoc_amount: (_g = state[productId]) === null || _g === void 0 ? void 0 : _g.adHocAmount } : {}),
      variant: (_h = state[productId].selectedVariant) === null || _h === void 0 ? void 0 : _h.id,
    },
  });
};
//# sourceMappingURL=watchers.js.map
