/**
 * External dependencies.
 */
import { addQueryArgs } from '@wordpress/url';
import apiFetch from '../../functions/fetch';
import { state } from './store';
import { state as productState } from '../product';
import { createErrorNotice, removeNotice } from '@store/notices/mutations';
import { __ } from '@wordpress/i18n';
/**
 * Update the upsell.
 */
export const trackOffer = () => {
  var _a;
  return apiFetch({
    path: `surecart/v1/checkouts/${state.checkout_id}/offer_upsell/${(_a = state.upsell) === null || _a === void 0 ? void 0 : _a.id}`,
    method: 'POST',
    keepalive: true, // Important: allow the request to outlive the page.
  });
};
/**
 * Update the upsell.
 */
export const preview = async () => {
  try {
    if (!state.checkout_id || state.loading === 'busy') {
      return;
    }
    state.loading = 'busy';
    removeNotice();
    // Add Upsell to line item.
    const { checkout, ...lineItem } = await upsellRequest({ preview: true });
    state.checkout = checkout;
    state.line_item = lineItem;
  }
  catch (error) {
    console.error(error);
    if (((error === null || error === void 0 ? void 0 : error.additional_errors) || []).find(error => { var _a, _b, _c; return (_c = (_b = (_a = error === null || error === void 0 ? void 0 : error.data) === null || _a === void 0 ? void 0 : _a.options) === null || _b === void 0 ? void 0 : _b.purchasable_statuses) === null || _c === void 0 ? void 0 : _c.includes('out_of_stock'); })) {
      return createErrorNotice({ code: 'out_of_stock', message: __('Apologies, this is currently out of stock.', 'surecart') });
    }
    if (((error === null || error === void 0 ? void 0 : error.additional_errors) || []).find(error => (error === null || error === void 0 ? void 0 : error.code) === 'line_item.upsell.expired')) {
      state.loading = 'idle';
      createErrorNotice({ code: 'expired', message: __('This offer has expired.', 'surecart') });
      return decline();
    }
    createErrorNotice(error);
  }
  finally {
    state.loading = 'idle';
  }
};
export const accept = async () => {
  try {
    if (!state.checkout_id || state.loading === 'busy') {
      return;
    }
    state.loading = 'busy';
    removeNotice();
    // Add Upsell to line item.
    const { checkout } = await upsellRequest({ preview: false });
    handleCompletion(checkout);
  }
  catch (error) {
    state.loading = 'idle';
    createErrorNotice(error);
  }
};
/**
 * Decline the upsell.
 */
export const decline = async () => {
  var _a, _b, _c, _d, _e, _f;
  try {
    if (!state.checkout_id || state.loading === 'busy') {
      return;
    }
    state.loading = 'busy';
    removeNotice();
    // Add Upsell to line item.
    const checkout = (await apiFetch({
      path: addQueryArgs(`surecart/v1/checkouts/${state.checkout_id}/decline_upsell/${(_a = state.upsell) === null || _a === void 0 ? void 0 : _a.id}`, {
        expand: ['checkout', 'checkout.current_upsell', 'fees'],
      }),
      method: 'POST',
      data: {
        ...(_c = productState[(_b = state.product) === null || _b === void 0 ? void 0 : _b.id]) === null || _c === void 0 ? void 0 : _c.line_item,
        price_id: (_e = (_d = state.upsell) === null || _d === void 0 ? void 0 : _d.price) === null || _e === void 0 ? void 0 : _e.id,
        upsell: (_f = state.upsell) === null || _f === void 0 ? void 0 : _f.id,
        checkout: state.checkout_id,
      },
    }));
    handleCompletion(checkout);
  }
  catch (error) {
    state.loading = 'idle';
    createErrorNotice(error);
  }
};
/**
 * Make the request to the upsell endpoing
 */
export const upsellRequest = args => {
  var _a, _b, _c, _d, _e;
  return apiFetch({
    path: addQueryArgs('surecart/v1/line_items/upsell', {
      ...args,
      expand: ['checkout', 'checkout.current_upsell', 'fees'],
    }),
    method: 'POST',
    data: {
      ...(_b = productState[(_a = state.product) === null || _a === void 0 ? void 0 : _a.id]) === null || _b === void 0 ? void 0 : _b.line_item,
      price_id: (_d = (_c = state.upsell) === null || _c === void 0 ? void 0 : _c.price) === null || _d === void 0 ? void 0 : _d.id,
      upsell: (_e = state.upsell) === null || _e === void 0 ? void 0 : _e.id,
      checkout: state.checkout_id,
    },
  });
};
/**
 * Handle what to do on completion.
 */
export const handleCompletion = checkout => {
  var _a, _b, _c, _d, _e;
  // There is no more upsells, or the link is the same.
  if (!((_a = checkout.current_upsell) === null || _a === void 0 ? void 0 : _a.permalink) || ((_b = checkout === null || checkout === void 0 ? void 0 : checkout.current_upsell) === null || _b === void 0 ? void 0 : _b.permalink) === ((_c = state.upsell) === null || _c === void 0 ? void 0 : _c.permalink)) {
    return (state.loading = 'complete');
  }
  // redirect to next upsell.
  state.loading = 'redirecting';
  window.location.assign(addQueryArgs((_d = checkout.current_upsell) === null || _d === void 0 ? void 0 : _d.permalink, {
    sc_checkout_id: (_e = state.checkout) === null || _e === void 0 ? void 0 : _e.id,
    sc_form_id: state.form_id,
  }));
};
//# sourceMappingURL=mutations.js.map
