describe('Checkout Stripe', () => {
  beforeEach(() => {
    cy.intercept(
      {
        method: 'POST',
        path: '**/surecart/v1/checkouts/*',
      },
      {
        id: 'test',
        object: 'checkout',
        status: 'draft',
      },
    ).as('createUpdate');

    cy.intercept(
      {
        path: '**/surecart/v1/checkouts/test/finalize*',
      },
      {
        id: 'test',
        object: 'checkout',
        status: 'finalized',
        payment_intent: {
          processor_type: 'stripe',
          external_intent_id: 'test',
          processor_data: {
            stripe: {
              client_secret: 'test_client_secret',
              type: 'payment',
            },
          },
        },
      },
    ).as('finalize');

    cy.intercept(
      {
        method: 'POST',
        path: '**/surecart/v1/checkouts/test/confirm*',
      },
      {
        id: 'test',
        status: 'paid',
      },
    ).as('confirm');
  });

  it('Can checkout', () => {
    const confirmCardPayment = cy.stub().as('confirmCardPayment');
    cy.visit('/test/sc-checkout/stripe/', {
      onBeforeLoad: window => {
        window.mockStripeMethods = {
          confirmCardPayment,
        };
      },
    });

    cy.wait('@createUpdate');
    cy.get('sc-block-ui.busy-block-ui').should('not.exist');

    // fill stripe card element.
    cy.getStripeCardElement('number').type('4242424242424242', {
      force: true,
    });
    cy.getStripeCardElement('expiry').type('430', { force: true });
    cy.getStripeCardElement('cvc').type('123', { force: true });
    cy.getStripeCardElement('postalCode').type('12345', {
      force: true,
    });

    // submit.
    cy.get('sc-order-submit sc-button').shadow().find('.button').should('not.have.class', 'button--loading').click({ force: true, waitForAnimations: true, multiple: true });

    cy.wait('@finalize').its('request.url').should('include', 'form_id=1').should('include', 'processor_type=stripe');
    cy.wait('@confirm');
    cy.get('@confirmCardPayment').should('have.been.calledOnceWith', Cypress.sinon.match('test_client_secret'));
    cy.get('sc-dialog').find('sc-dashboard-module').should('be.visible');
    cy.get('sc-button').contains('Continue').should('be.visible').click();
    cy.get('sc-button[href]').should('have.attr', 'href').and('contain', '/success');
  });
});
