import { b as setProduct, s as state } from './watchers.js';
import { t as toggleCart } from './mutations2.js';
import { a as addCheckoutLineItem } from './mutations4.js';
import { a as addQueryArgs } from './add-query-args.js';

const submitCartForm = async (productId) => {
  var _a, _b, _c, _d, _e, _f;
  const productState = state[productId];
  if (!productState)
    return;
  if (!((_a = productState.selectedPrice) === null || _a === void 0 ? void 0 : _a.id))
    return;
  if (((_b = productState.selectedPrice) === null || _b === void 0 ? void 0 : _b.ad_hoc) && (null === productState.adHocAmount || undefined === productState.adHocAmount))
    return;
  try {
    setProduct(productId, { busy: true });
    await addCheckoutLineItem({
      price: (_c = productState.selectedPrice) === null || _c === void 0 ? void 0 : _c.id,
      quantity: Math.max(((_d = productState.selectedPrice) === null || _d === void 0 ? void 0 : _d.ad_hoc) ? 1 : productState.quantity, 1),
      ...(((_e = productState.selectedPrice) === null || _e === void 0 ? void 0 : _e.ad_hoc) ? { ad_hoc_amount: productState.adHocAmount } : {}),
      variant: (_f = productState.selectedVariant) === null || _f === void 0 ? void 0 : _f.id,
    });
    toggleCart(true);
    setProduct(productId, { dialog: null });
  }
  catch (e) {
    console.error(e);
    state.error = e;
    throw e; // Re-throw the caught error
  }
  finally {
    setProduct(productId, { busy: false });
  }
};
/**
 * Get the product buy link.
 */
const getProductBuyLink = (productId, url, query = {}) => {
  var _a, _b, _c, _d, _e, _f, _g;
  const productState = state[productId];
  if (!productState)
    return;
  if (!((_a = productState.selectedPrice) === null || _a === void 0 ? void 0 : _a.id))
    return;
  if (((_b = productState.selectedPrice) === null || _b === void 0 ? void 0 : _b.ad_hoc) && !productState.adHocAmount)
    return;
  return addQueryArgs(url, {
    line_items: [
      {
        price: (_c = productState.selectedPrice) === null || _c === void 0 ? void 0 : _c.id,
        quantity: Math.max(((_d = productState.selectedPrice) === null || _d === void 0 ? void 0 : _d.ad_hoc) ? 1 : productState.quantity, 1),
        ...(((_e = productState.selectedPrice) === null || _e === void 0 ? void 0 : _e.ad_hoc) ? { ad_hoc_amount: productState.adHocAmount } : {}),
        ...(((_f = productState.selectedVariant) === null || _f === void 0 ? void 0 : _f.id) ? { variant: (_g = productState.selectedVariant) === null || _g === void 0 ? void 0 : _g.id } : {}),
      },
    ],
    ...query,
  });
};

/**
 * Get any additional error messages.
 */
const getAdditionalErrorMessages = error => ((error === null || error === void 0 ? void 0 : error.additional_errors) || []).map(error => error.message);
/**
 * Get the top level error
 */
const getTopLevelError = (error) => {
  var _a;
  // checkout invalid is not friendly.
  if ((error === null || error === void 0 ? void 0 : error.code) === 'checkout.invalid' && ((_a = getAdditionalErrorMessages(error)) === null || _a === void 0 ? void 0 : _a.length)) {
    return '';
  }
  return error === null || error === void 0 ? void 0 : error.message;
};

export { getTopLevelError as a, getAdditionalErrorMessages as b, getProductBuyLink as g, submitCartForm as s };

//# sourceMappingURL=error.js.map