import { m as maybeConvertAmount } from './currency.js';
import { t as trackEvent } from './google2.js';

/**
 * Handle search event.
 */
window.addEventListener('scSearched', function (e) {
  var _a;
  if (!(window === null || window === void 0 ? void 0 : window.fbq))
    return;
  const eventDetail = e.detail;
  window.fbq('track', 'Search', {
    search_string: eventDetail.searchString,
    content_ids: eventDetail.searchResultIds,
    ...(!!((_a = eventDetail === null || eventDetail === void 0 ? void 0 : eventDetail.searchCollections) === null || _a === void 0 ? void 0 : _a.length) ? { content_category: eventDetail.searchCollections.join(',') } : {}),
  });
});
/**
 * Handle view content event.
 */
window.addEventListener('scProductViewed', function (e) {
  var _a, _b, _c, _d, _e, _f;
  if (!(window === null || window === void 0 ? void 0 : window.fbq))
    return;
  const product = e.detail;
  window.fbq('track', 'ViewContent', {
    content_ids: [product.id],
    content_category: (_b = (_a = product === null || product === void 0 ? void 0 : product.product_collections) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.map(collection => collection.name).join(', '),
    content_name: (product === null || product === void 0 ? void 0 : product.name) + (((_c = product === null || product === void 0 ? void 0 : product.variant_options) === null || _c === void 0 ? void 0 : _c.length) ? ` - ${product === null || product === void 0 ? void 0 : product.variant_options.join(' / ')}` : ''),
    content_type: 'product',
    contents: [
      {
        id: product.id,
        quantity: 1,
      },
    ],
    currency: (_d = product === null || product === void 0 ? void 0 : product.price) === null || _d === void 0 ? void 0 : _d.currency,
    value: maybeConvertAmount(((_e = product.price) === null || _e === void 0 ? void 0 : _e.amount) || 0, ((_f = product.price) === null || _f === void 0 ? void 0 : _f.currency) || 'USD'),
  });
});

/**
 * Handle the search event.
 */
window.addEventListener('scSearched', (e) => {
  var _a;
  trackEvent('search', {
    search_term: (_a = e.detail) === null || _a === void 0 ? void 0 : _a.searchString,
  });
});
/**
 * Handle view item event.
 */
window.addEventListener('scProductViewed', (e) => {
  var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
  const product = e.detail;
  trackEvent('view_item', {
    value: maybeConvertAmount(((_a = product.price) === null || _a === void 0 ? void 0 : _a.amount) || 0, ((_b = product.price) === null || _b === void 0 ? void 0 : _b.currency) || 'USD'),
    currency: (_c = product.price) === null || _c === void 0 ? void 0 : _c.currency,
    items: [
      {
        item_id: product === null || product === void 0 ? void 0 : product.id,
        item_name: product === null || product === void 0 ? void 0 : product.name,
        currency: (_d = product === null || product === void 0 ? void 0 : product.price) === null || _d === void 0 ? void 0 : _d.currency,
        discount: (product === null || product === void 0 ? void 0 : product.discount_amount) ? maybeConvertAmount(product === null || product === void 0 ? void 0 : product.discount_amount, (_e = product === null || product === void 0 ? void 0 : product.price) === null || _e === void 0 ? void 0 : _e.currency) : 0,
        price: maybeConvertAmount((_f = product === null || product === void 0 ? void 0 : product.price) === null || _f === void 0 ? void 0 : _f.amount, (_g = product === null || product === void 0 ? void 0 : product.price) === null || _g === void 0 ? void 0 : _g.currency),
        quantity: (product === null || product === void 0 ? void 0 : product.quantity) || 1,
        ...(((_h = product === null || product === void 0 ? void 0 : product.variant_options) === null || _h === void 0 ? void 0 : _h.length)
          ? {
            item_variant: product === null || product === void 0 ? void 0 : product.variant_options.map(option => option.name).join(' / '),
          }
          : {}),
        ...(((_k = (_j = product === null || product === void 0 ? void 0 : product.product_collections) === null || _j === void 0 ? void 0 : _j.data) === null || _k === void 0 ? void 0 : _k.length)
          ? {
            item_category: (_m = (_l = product === null || product === void 0 ? void 0 : product.product_collections) === null || _l === void 0 ? void 0 : _l.data) === null || _m === void 0 ? void 0 : _m.map(collection => collection.name).join(', '),
          }
          : {}),
      },
    ],
  });
});
/**
 * Handle view items event.
 */
window.addEventListener('scProductsViewed', (e) => {
  var _a;
  const eventDetail = e.detail;
  trackEvent('view_item_list', {
    ...((eventDetail === null || eventDetail === void 0 ? void 0 : eventDetail.collectionId) ? { item_list_id: eventDetail.collectionId } : {}),
    item_list_name: eventDetail.pageTitle,
    items: (_a = eventDetail === null || eventDetail === void 0 ? void 0 : eventDetail.products) === null || _a === void 0 ? void 0 : _a.map(product => {
      var _a, _b, _c, _d;
      return ({
        item_id: product === null || product === void 0 ? void 0 : product.id,
        item_name: product === null || product === void 0 ? void 0 : product.name,
        ...(((_b = (_a = product === null || product === void 0 ? void 0 : product.product_collections) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.length)
          ? {
            item_category: (_d = (_c = product === null || product === void 0 ? void 0 : product.product_collections) === null || _c === void 0 ? void 0 : _c.data) === null || _d === void 0 ? void 0 : _d.map(collection => collection.name).join(', '),
          }
          : {}),
        ...((eventDetail === null || eventDetail === void 0 ? void 0 : eventDetail.collectionId) ? { item_list_id: eventDetail.collectionId } : {}),
        item_list_name: eventDetail.pageTitle,
      });
    }),
  });
});

//# sourceMappingURL=google.js.map