import { s as state } from './mutations2.js';
import { a as apiFetch } from './fetch.js';
import { _ as __ } from './default-i18n.js';
import { a as addQueryArgs } from './add-query-args.js';
import { g as getQueryArg } from './get-query-arg.js';

/** The base url for this service. */
const baseUrl = 'surecart/v1/checkouts/';
/** Items to always expand. */
const expand = [
  'line_items',
  'line_item.price',
  'line_item.fees',
  'line_item.variant',
  'variant.image',
  'price.product',
  'product.featured_product_media',
  'product.product_collections',
  'product_media.media',
  'customer',
  'customer.shipping_address',
  'payment_intent',
  'discount',
  'discount.promotion',
  'recommended_bumps',
  'bump.price',
  'current_upsell',
  'product.variants',
  'discount.coupon',
  'shipping_address',
  'tax_identifier',
  'manual_payment_method',
  'shipping_choices',
  'shipping_choice.shipping_method',
];
/** Default data we send with every request. */
const withDefaultData = (data = {}) => {
  var _a, _b, _c, _d, _e, _f;
  return ({
    live_mode: state.mode !== 'test',
    group_key: state.groupId,
    abandoned_checkout_enabled: state.abandonedCheckoutEnabled,
    metadata: {
      ...((data === null || data === void 0 ? void 0 : data.metadata) || {}),
      ...(((_a = window === null || window === void 0 ? void 0 : window.scData) === null || _a === void 0 ? void 0 : _a.page_id) && { page_id: (_b = window === null || window === void 0 ? void 0 : window.scData) === null || _b === void 0 ? void 0 : _b.page_id }),
      ...(((_c = state === null || state === void 0 ? void 0 : state.product) === null || _c === void 0 ? void 0 : _c.id) && { buy_page_product_id: (_d = state === null || state === void 0 ? void 0 : state.product) === null || _d === void 0 ? void 0 : _d.id }),
      page_url: window.location.href,
    },
    ...(((_e = state === null || state === void 0 ? void 0 : state.checkout) === null || _e === void 0 ? void 0 : _e.email) && { email: (_f = state === null || state === void 0 ? void 0 : state.checkout) === null || _f === void 0 ? void 0 : _f.email }),
    ...data,
  });
};
/** Default query we send with every request. */
const withDefaultQuery = (query = {}) => {
  var _a, _b;
  return ({
    ...(!!(state === null || state === void 0 ? void 0 : state.formId) && { form_id: state === null || state === void 0 ? void 0 : state.formId }),
    ...(!!((_a = state === null || state === void 0 ? void 0 : state.product) === null || _a === void 0 ? void 0 : _a.id) && { product_id: (_b = state === null || state === void 0 ? void 0 : state.product) === null || _b === void 0 ? void 0 : _b.id }),
    ...query,
  });
};
/** Get the checkout id  */
const findInitialCheckoutId = () => {
  var _a, _b;
  // check url first.
  const checkoutId = getQueryArg(window.location.href, 'checkout_id');
  if (!!checkoutId) {
    return checkoutId;
  }
  // check existing order.
  if ((_a = state === null || state === void 0 ? void 0 : state.checkout) === null || _a === void 0 ? void 0 : _a.id) {
    return (_b = state === null || state === void 0 ? void 0 : state.checkout) === null || _b === void 0 ? void 0 : _b.id;
  }
  // we don't have and order id.
  return null;
};
/** Parse the path with expansions. */
const parsePath = (id, endpoint = '') => {
  let path = id ? `${baseUrl}${id}` : baseUrl;
  path = `${path}${endpoint}`;
  return addQueryArgs(path, {
    expand,
  });
};
/** Fethc a checkout by id */
const fetchCheckout = async ({ id, query = {} }) => {
  return (await apiFetch({
    path: addQueryArgs(parsePath(id), withDefaultQuery(query)),
  }));
};
/** Create or update the checkout. */
const createOrUpdateCheckout = async ({ id = null, data = {}, query = {} }) => {
  id = !id ? findInitialCheckoutId() : id;
  return await apiFetch({
    method: id ? 'PATCH' : 'POST',
    path: addQueryArgs(parsePath(id), withDefaultQuery(query)),
    data: withDefaultData(data),
  });
};
/** Update the checkout. */
const updateCheckout = async ({ id, data = {}, query = {} }) => {
  return await apiFetch({
    method: 'PATCH',
    path: addQueryArgs(parsePath(id), withDefaultQuery(query)),
    data: withDefaultData(data),
  });
};
/** Finalize a checkout */
const finalizeCheckout = async ({ id, data = {}, query = {}, processor }) => {
  return (await apiFetch({
    method: 'POST',
    path: addQueryArgs(parsePath(id, '/finalize'), withDefaultQuery({
      ...((processor === null || processor === void 0 ? void 0 : processor.manual) ? { manual_payment: true, manual_payment_method_id: processor === null || processor === void 0 ? void 0 : processor.id } : { processor_type: processor === null || processor === void 0 ? void 0 : processor.id }),
      ...query,
    })),
    data: withDefaultData(data),
  }));
};
/**
 * Add a line item.
 */
const addLineItem = async ({ checkout, data, live_mode = false }) => {
  var _a;
  const existingLineItem = (((_a = checkout === null || checkout === void 0 ? void 0 : checkout.line_items) === null || _a === void 0 ? void 0 : _a.data) || []).find(item => {
    var _a;
    if (!((_a = item === null || item === void 0 ? void 0 : item.variant) === null || _a === void 0 ? void 0 : _a.id)) {
      return item.price.id === data.price;
    }
    return item.variant.id === data.variant && item.price.id === data.price;
  });
  // create the checkout with the line item.
  if (!(checkout === null || checkout === void 0 ? void 0 : checkout.id)) {
    return (await apiFetch({
      method: 'POST',
      path: addQueryArgs(parsePath(null)),
      data: {
        line_items: [data],
        live_mode,
      },
    }));
  }
  // handle existing line item.
  if (!!existingLineItem) {
    return await updateLineItem({ id: existingLineItem === null || existingLineItem === void 0 ? void 0 : existingLineItem.id, data: { ...data, quantity: (existingLineItem === null || existingLineItem === void 0 ? void 0 : existingLineItem.quantity) + (data === null || data === void 0 ? void 0 : data.quantity) } });
  }
  const item = (await apiFetch({
    path: addQueryArgs(`surecart/v1/line_items/${(existingLineItem === null || existingLineItem === void 0 ? void 0 : existingLineItem.id) ? existingLineItem === null || existingLineItem === void 0 ? void 0 : existingLineItem.id : ''}`, {
      consolidate: true,
      expand: [
        ...(expand || []).map(item => {
          return item.includes('.') ? item : `checkout.${item}`;
        }),
        'checkout',
      ],
    }),
    method: 'POST',
    data: {
      ...data,
      checkout: checkout.id,
    },
  }));
  return item === null || item === void 0 ? void 0 : item.checkout;
};
/**
 * Remove a line item.
 */
const removeLineItem = async ({ checkoutId, itemId }) => {
  const { deleted } = (await apiFetch({
    path: `surecart/v1/line_items/${itemId}`,
    method: 'DELETE',
  }));
  if (!deleted) {
    throw { code: 'error', message: __('Failed to delete', 'surecart') };
  }
  return await fetchCheckout({ id: checkoutId });
};
/**
 * Update a line item.
 */
const updateLineItem = async ({ id, data }) => {
  const item = (await apiFetch({
    path: addQueryArgs(`surecart/v1/line_items/${id}`, {
      expand: [
        ...(expand || []).map(item => {
          return item.includes('.') ? item : `checkout.${item}`;
        }),
        'checkout',
      ],
    }),
    method: 'PATCH',
    data,
  }));
  return item === null || item === void 0 ? void 0 : item.checkout;
};

export { addLineItem as a, baseUrl as b, updateCheckout as c, createOrUpdateCheckout as d, expand as e, finalizeCheckout as f, fetchCheckout as g, removeLineItem as r, updateLineItem as u };

//# sourceMappingURL=index5.js.map