import { s as state, c as clearCheckout$1 } from './mutations2.js';
import { u as updateFormState } from './mutations5.js';
import { c as createErrorNotice } from './mutations3.js';
import { u as updateLineItem, a as addLineItem, r as removeLineItem } from './index5.js';

/**
 * Clear the current checkout.
 */
const clearCheckout = () => clearCheckout$1(state.formId, state.mode);
/**
 * Lock the checkout (disables input and submission)
 * Pass a lock name to prevent conflicts and allow multiple locks.
 */
const lockCheckout = lockName => (state.locks = [...state.locks, lockName]);
/**
 * Unlock the checkout.
 * Pass an optional lock name to only unlock a specific lock
 */
const unLockCheckout = (lockName = '') => (state.locks = !!lockName ? state.locks.filter(name => name !== lockName) : []);
/**
 * Update the checkout line item
 */
const updateCheckoutLineItem = async ({ id, data }) => {
  try {
    updateFormState('FETCH');
    state.checkout = await updateLineItem({
      id: id,
      data,
    });
    updateFormState('RESOLVE');
  }
  catch (e) {
    console.error(e);
    createErrorNotice(e);
    updateFormState('REJECT');
  }
};
/**
 * Remove the checkout line item.
 */
const removeCheckoutLineItem = async (id) => {
  try {
    updateFormState('FETCH');
    state.checkout = await removeLineItem({
      checkoutId: state.checkout.id,
      itemId: id,
    });
    updateFormState('RESOLVE');
  }
  catch (e) {
    console.error(e);
    createErrorNotice(e);
    updateFormState('REJECT');
  }
};
/**
 * Add the checkout line item.
 */
const addCheckoutLineItem = async (data) => {
  try {
    updateFormState('FETCH');
    state.checkout = await addLineItem({
      checkout: state.checkout,
      data,
      live_mode: (state === null || state === void 0 ? void 0 : state.mode) === 'live',
    });
    updateFormState('RESOLVE');
  }
  catch (e) {
    console.error(e);
    createErrorNotice(e);
    updateFormState('REJECT');
  }
};

export { addCheckoutLineItem as a, unLockCheckout as b, clearCheckout as c, lockCheckout as l, removeCheckoutLineItem as r, updateCheckoutLineItem as u };

//# sourceMappingURL=mutations4.js.map