import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { a as apiFetch } from './fetch.js';
import { g as getHumanDiscount } from './price.js';
import { _ as __ } from './default-i18n.js';
import { d as defineCustomElement$7 } from './sc-alert2.js';
import { d as defineCustomElement$6 } from './sc-block-ui2.js';
import { d as defineCustomElement$5 } from './sc-button2.js';
import { d as defineCustomElement$4 } from './sc-dashboard-module2.js';
import { d as defineCustomElement$3 } from './sc-flex2.js';
import { d as defineCustomElement$2 } from './sc-icon2.js';
import { d as defineCustomElement$1 } from './sc-spinner2.js';
import { a as addQueryArgs } from './add-query-args.js';

/**
 * Replace the {{ name }} in a string with a new value
 */
const replaceAmount = (string, replace, name = 'amount') => {
  return string.replaceAll('{{' + name + '}}', replace).replaceAll('{{ ' + name + ' }}', replace);
};
/**
 * Replace the amount in a string with discount.
 */
const replaceAmountFromString = (amountStr, protocol) => (protocol === null || protocol === void 0 ? void 0 : protocol.preservation_coupon) ? replaceAmount(amountStr, getHumanDiscount(protocol === null || protocol === void 0 ? void 0 : protocol.preservation_coupon)) : amountStr;
/**
 *
 */
const getCurrentBehaviourContent = (protocol, hasDiscount) => {
  const { preserve_title, preserve_description, preserve_button, cancel_link } = (protocol === null || protocol === void 0 ? void 0 : protocol.preservation_locales) || {};
  if (hasDiscount) {
    const discountLocales = {
      title: replaceAmountFromString(__('Your {{ amount }} discount is still active.', 'surecart'), protocol),
      description: replaceAmountFromString(__('You have a {{ amount }} discount active. Cancelling now will forfeit this discount forever. Are you sure you wish to cancel?', 'surecart'), protocol),
      button: __('Keep My Discount', 'surecart'),
      cancel_link: __('Cancel Anyway', 'surecart'),
    };
    return discountLocales;
  }
  const defaultLocales = {
    title: replaceAmountFromString(preserve_title, protocol),
    description: replaceAmountFromString(preserve_description, protocol),
    button: preserve_button,
    cancel_link: cancel_link,
  };
  return defaultLocales;
};

const scCancelDiscountCss = ".cancel-discount__abort-link{color:var(--sc-color-gray-500)}";

const ScCancelDiscount = /*@__PURE__*/ proxyCustomElement(class ScCancelDiscount extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.scCancel = createEvent(this, "scCancel", 7);
    this.scPreserved = createEvent(this, "scPreserved", 7);
    this.subscription = undefined;
    this.reason = undefined;
    this.comment = undefined;
    this.protocol = undefined;
    this.loading = undefined;
    this.error = undefined;
  }
  async addDiscount() {
    var _a, _b;
    try {
      this.loading = true;
      this.subscription = (await apiFetch({
        method: 'PATCH',
        path: addQueryArgs(`surecart/v1/subscriptions/${(_a = this.subscription) === null || _a === void 0 ? void 0 : _a.id}/preserve`, {
          cancellation_act: {
            ...(!!this.comment ? { comment: this.comment } : {}),
            cancellation_reason_id: (_b = this.reason) === null || _b === void 0 ? void 0 : _b.id,
          },
        }),
      }));
      this.scPreserved.emit();
    }
    catch (e) {
      console.error(e);
      this.error = e;
    }
    finally {
      this.loading = false;
    }
  }
  hasDiscount() {
    var _a, _b;
    return !!((_b = (_a = this.subscription) === null || _a === void 0 ? void 0 : _a.discount) === null || _b === void 0 ? void 0 : _b.id);
  }
  render() {
    var _a, _b;
    const { title, description, button, cancel_link } = getCurrentBehaviourContent(this.protocol, (_b = (_a = this.subscription) === null || _a === void 0 ? void 0 : _a.discount) === null || _b === void 0 ? void 0 : _b.id);
    return (h("div", { class: "cancel-discount" }, h("sc-dashboard-module", { heading: title, style: { '--sc-dashboard-module-spacing': '2em' } }, h("span", { slot: "description" }, description), h("sc-flex", { justifyContent: "flex-start" }, h("sc-button", { type: "primary", onClick: () => this.addDiscount() }, button), h("sc-button", { class: "cancel-discount__abort-link", type: "text", onClick: () => this.scCancel.emit() }, cancel_link)), !!this.loading && h("sc-block-ui", { spinner: true }))));
  }
  static get style() { return scCancelDiscountCss; }
}, [1, "sc-cancel-discount", {
    "subscription": [16],
    "reason": [16],
    "comment": [1],
    "protocol": [16],
    "loading": [32],
    "error": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-cancel-discount", "sc-alert", "sc-block-ui", "sc-button", "sc-dashboard-module", "sc-flex", "sc-icon", "sc-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-cancel-discount":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScCancelDiscount);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "sc-block-ui":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-dashboard-module":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-flex":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "sc-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ScCancelDiscount as S, defineCustomElement as d };

//# sourceMappingURL=sc-cancel-discount2.js.map