import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { _ as __ } from './default-i18n.js';
import { s as state } from './mutations2.js';
import { c as updateCheckout } from './index5.js';
import { r as removeNotice, c as createErrorNotice } from './mutations3.js';
import { u as updateFormState } from './mutations5.js';
import { c as clearCheckout } from './mutations4.js';
import { d as defineCustomElement$1 } from './sc-line-items-provider2.js';

const ScCartSessionProvider = /*@__PURE__*/ proxyCustomElement(class ScCartSessionProvider extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.scSetState = createEvent(this, "scSetState", 7);
  }
  handleUpdateSession(e) {
    const { data, options } = e.detail;
    if (options === null || options === void 0 ? void 0 : options.silent) {
      this.update(data);
    }
    else {
      this.loadUpdate(data);
    }
  }
  /** Handles coupon updates. */
  async handleCouponApply(e) {
    const promotion_code = e.detail;
    removeNotice();
    this.loadUpdate({
      discount: {
        ...(promotion_code ? { promotion_code } : {}),
      },
    });
  }
  /** Handle the error response. */
  handleErrorResponse(e) {
    var _a, _b;
    if ((e === null || e === void 0 ? void 0 : e.code) === 'readonly' || ((_b = (_a = e === null || e === void 0 ? void 0 : e.additional_errors) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.code) === 'checkout.customer.account_mismatch') {
      clearCheckout();
    }
    // expired
    if ((e === null || e === void 0 ? void 0 : e.code) === 'rest_cookie_invalid_nonce') {
      updateFormState('EXPIRE');
      return;
    }
    // something went wrong
    if (e === null || e === void 0 ? void 0 : e.message) {
      createErrorNotice(e);
    }
    // handle curl timeout errors.
    if ((e === null || e === void 0 ? void 0 : e.code) === 'http_request_failed') {
      createErrorNotice(__('Something went wrong. Please reload the page and try again.', 'surecart'));
    }
  }
  /** Fetch a session. */
  async fetch(args = {}) {
    this.loadUpdate({ status: 'draft', ...args });
  }
  /** Update a the order */
  async update(data = {}, query = {}) {
    var _a;
    try {
      state.checkout = (await updateCheckout({
        id: (_a = state.checkout) === null || _a === void 0 ? void 0 : _a.id,
        data: {
          ...data,
        },
        query: {
          ...query,
        },
      }));
    }
    catch (e) {
      console.error(e);
      throw e;
    }
  }
  /** Updates a session with loading status changes. */
  async loadUpdate(data = {}) {
    try {
      updateFormState('FETCH');
      await this.update(data);
      updateFormState('RESOLVE');
    }
    catch (e) {
      updateFormState('REJECT');
      this.handleErrorResponse(e);
    }
  }
  render() {
    return (h("sc-line-items-provider", { order: state.checkout, onScUpdateLineItems: e => this.loadUpdate({ line_items: e.detail }) }, h("slot", null)));
  }
  get el() { return this; }
}, [1, "sc-cart-session-provider", undefined, [[0, "scUpdateOrder", "handleUpdateSession"], [0, "scApplyCoupon", "handleCouponApply"]]]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-cart-session-provider", "sc-line-items-provider"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-cart-session-provider":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScCartSessionProvider);
      }
      break;
    case "sc-line-items-provider":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ScCartSessionProvider as S, defineCustomElement as d };

//# sourceMappingURL=sc-cart-session-provider2.js.map