import { proxyCustomElement, HTMLElement, h, Fragment } from '@stencil/core/internal/client';
import { a as apiFetch } from './fetch.js';
import { b as baseUrl, e as expand } from './index5.js';
import { a as store, g as getCheckout, b as setCheckout, s as state } from './mutations2.js';
import { c as createErrorNotice } from './mutations3.js';
import { u as updateFormState } from './mutations5.js';
import { f as formBusy } from './getters3.js';
import { d as defineCustomElement$9 } from './sc-alert2.js';
import { d as defineCustomElement$8 } from './sc-block-ui2.js';
import { d as defineCustomElement$7 } from './sc-cart-session-provider2.js';
import { d as defineCustomElement$6 } from './sc-drawer2.js';
import { d as defineCustomElement$5 } from './sc-error2.js';
import { d as defineCustomElement$4 } from './sc-icon2.js';
import { d as defineCustomElement$3 } from './sc-line-items-provider2.js';
import { d as defineCustomElement$2 } from './sc-spinner2.js';
import { a as addQueryArgs } from './add-query-args.js';

const scCartCss = ":host{--sc-drawer-header-spacing:var(--sc-spacing-large);--sc-drawer-body-spacing:var(--sc-spacing-large);--sc-drawer-footer-spacing:var(--sc-spacing-large)}.cart{font-size:16px}.cart__header{display:flex;align-items:center;justify-content:space-between;width:100%;font-size:1em}.cart__close{opacity:0.75;transition:opacity 0.25s ease;cursor:pointer}.cart__close:hover{opacity:1}::slotted(*){padding:var(--sc-drawer-header-spacing);background:var(--sc-panel-background-color);position:relative}::slotted(sc-line-items){flex:1 1 auto;overflow:auto;-webkit-overflow-scrolling:touch;min-height:200px}::slotted(:last-child){border-bottom:0 !important}sc-drawer::part(body){display:flex;flex-direction:column;box-sizing:border-box;padding:0;overflow:hidden}";

const ScCart$1 = /*@__PURE__*/ proxyCustomElement(class ScCart extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.open = null;
    this.formId = undefined;
    this.header = undefined;
    this.checkoutLink = undefined;
    this.cartTemplate = undefined;
    this.mode = 'live';
    this.checkoutUrl = undefined;
    this.alwaysShow = undefined;
    this.floatingIconEnabled = true;
    this.uiState = 'idle';
  }
  handleOpenChange() {
    var _a, _b, _c;
    store.set('cart', { ...store.state.cart, ...{ open: this.open } });
    if (this.open === true) {
      this.fetchOrder();
    }
    else {
      (_c = (_b = (_a = document === null || document === void 0 ? void 0 : document.querySelector('sc-cart-icon')) === null || _a === void 0 ? void 0 : _a.shadowRoot) === null || _b === void 0 ? void 0 : _b.querySelector('.cart')) === null || _c === void 0 ? void 0 : _c.focus();
    }
  }
  order() {
    return getCheckout(this.formId, this.mode);
  }
  setCheckout(data) {
    setCheckout(data, this.formId);
  }
  /**
   * Search for the sc-checkout component on a page to make sure
   * we don't show the cart on a checkout page.
   */
  pageHasForm() {
    return !!document.querySelector('sc-checkout');
  }
  /** Count the number of items in the cart. */
  getItemsCount() {
    var _a, _b;
    const items = (_b = (_a = state.checkout) === null || _a === void 0 ? void 0 : _a.line_items) === null || _b === void 0 ? void 0 : _b.data;
    let count = 0;
    (items || []).forEach(item => {
      count = count + (item === null || item === void 0 ? void 0 : item.quantity);
    });
    return count;
  }
  handleSetState(e) {
    this.uiState = e.detail;
  }
  handleCloseCart() {
    this.open = false;
  }
  /** Fetch the order */
  async fetchOrder() {
    var _a;
    try {
      updateFormState('FETCH');
      state.checkout = (await apiFetch({
        method: 'GET',
        path: addQueryArgs(`${baseUrl}${(_a = state.checkout) === null || _a === void 0 ? void 0 : _a.id}`, {
          expand,
        }),
      }));
      updateFormState('RESOLVE');
    }
    catch (e) {
      console.error(e);
      updateFormState('REJECT');
      createErrorNotice(e);
    }
  }
  componentWillLoad() {
    this.open = !!store.state.cart.open;
    store.onChange('cart', cart => {
      this.open = cart.open;
    });
  }
  state() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
    return {
      uiState: this.uiState,
      checkoutLink: this.checkoutLink,
      loading: this.uiState === 'loading',
      busy: this.uiState === 'busy',
      navigating: this.uiState === 'navigating',
      empty: !((_c = (_b = (_a = state.checkout) === null || _a === void 0 ? void 0 : _a.line_items) === null || _b === void 0 ? void 0 : _b.pagination) === null || _c === void 0 ? void 0 : _c.count),
      order: state.checkout,
      lineItems: ((_e = (_d = state.checkout) === null || _d === void 0 ? void 0 : _d.line_items) === null || _e === void 0 ? void 0 : _e.data) || [],
      tax_status: (_f = state.checkout) === null || _f === void 0 ? void 0 : _f.tax_status,
      customerShippingAddress: typeof ((_g = state.checkout) === null || _g === void 0 ? void 0 : _g.customer) !== 'string' ? (_j = (_h = state.checkout) === null || _h === void 0 ? void 0 : _h.customer) === null || _j === void 0 ? void 0 : _j.shipping_address : {},
      shippingAddress: (_k = state.checkout) === null || _k === void 0 ? void 0 : _k.shipping_address,
      taxStatus: (_l = state.checkout) === null || _l === void 0 ? void 0 : _l.tax_status,
      formId: this.formId,
    };
  }
  render() {
    return (h("sc-cart-session-provider", null, h("sc-drawer", { open: this.open, onScAfterShow: () => (this.open = true), onScAfterHide: () => {
        this.open = false;
      } }, this.open === true && (h(Fragment, null, h("div", { class: "cart__header-suffix", slot: "header" }, h("slot", { name: "cart-header" }), h("sc-error", { style: { '--sc-alert-border-radius': '0' }, slot: "header" })), h("slot", null))), formBusy() && h("sc-block-ui", { "z-index": 9 }))));
  }
  get el() { return this; }
  static get watchers() { return {
    "open": ["handleOpenChange"]
  }; }
  static get style() { return scCartCss; }
}, [1, "sc-cart", {
    "formId": [513, "form-id"],
    "header": [1],
    "checkoutLink": [1, "checkout-link"],
    "cartTemplate": [1, "cart-template"],
    "mode": [1],
    "checkoutUrl": [1, "checkout-url"],
    "alwaysShow": [4, "always-show"],
    "floatingIconEnabled": [4, "floating-icon-enabled"],
    "open": [32],
    "uiState": [32]
  }, [[0, "scSetState", "handleSetState"], [0, "scCloseCart", "handleCloseCart"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-cart", "sc-alert", "sc-block-ui", "sc-cart-session-provider", "sc-drawer", "sc-error", "sc-icon", "sc-line-items-provider", "sc-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-cart":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScCart$1);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "sc-block-ui":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "sc-cart-session-provider":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "sc-drawer":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-error":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-line-items-provider":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const ScCart = ScCart$1;
const defineCustomElement = defineCustomElement$1;

export { ScCart, defineCustomElement };

//# sourceMappingURL=sc-cart.js.map