import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { _ as __, s as sprintf } from './default-i18n.js';
import { a as apiFetch } from './fetch.js';
import { o as onFirstVisible } from './lazy.js';
import { d as defineCustomElement$i } from './sc-alert2.js';
import { d as defineCustomElement$h } from './sc-block-ui2.js';
import { d as defineCustomElement$g } from './sc-button2.js';
import { d as defineCustomElement$f } from './sc-card2.js';
import { d as defineCustomElement$e } from './sc-dashboard-module2.js';
import { d as defineCustomElement$d } from './sc-flex2.js';
import { d as defineCustomElement$c } from './sc-format-date2.js';
import { d as defineCustomElement$b } from './sc-format-number2.js';
import { d as defineCustomElement$a } from './sc-icon2.js';
import { d as defineCustomElement$9 } from './sc-pagination2.js';
import { d as defineCustomElement$8 } from './sc-skeleton2.js';
import { d as defineCustomElement$7 } from './sc-spinner2.js';
import { d as defineCustomElement$6 } from './sc-stacked-list2.js';
import { d as defineCustomElement$5 } from './sc-stacked-list-row2.js';
import { d as defineCustomElement$4 } from './sc-tag2.js';
import { d as defineCustomElement$3 } from './sc-text2.js';
import { d as defineCustomElement$2 } from './sc-visually-hidden2.js';
import { a as addQueryArgs } from './add-query-args.js';

const scChargesListCss = ":host{display:block;position:relative}.charges-list{display:grid;gap:1em}";

const ScChargesList$1 = /*@__PURE__*/ proxyCustomElement(class ScChargesList extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.query = {
      page: 1,
      per_page: 10,
    };
    this.heading = undefined;
    this.showPagination = true;
    this.allLink = undefined;
    this.charges = [];
    this.loading = undefined;
    this.loaded = undefined;
    this.error = undefined;
    this.pagination = {
      total: 0,
      total_pages: 0,
    };
  }
  /** Only fetch if visible */
  componentWillLoad() {
    onFirstVisible(this.el, () => {
      this.getItems();
    });
  }
  /** Get items */
  async getItems() {
    try {
      this.loading = true;
      const response = (await apiFetch({
        path: addQueryArgs(`surecart/v1/charges/`, {
          expand: ['checkout', 'checkout.order'],
          ...this.query,
        }),
        parse: false,
      }));
      this.pagination = {
        total: parseInt(response.headers.get('X-WP-Total')),
        total_pages: parseInt(response.headers.get('X-WP-TotalPages')),
      };
      this.charges = (await response.json());
    }
    catch (e) {
      if (e === null || e === void 0 ? void 0 : e.message) {
        this.error = e.message;
      }
      else {
        this.error = __('Something went wrong', 'surecart');
      }
      console.error(this.error);
    }
    finally {
      this.loading = false;
      this.loaded = true;
    }
  }
  renderRefundStatus(charge) {
    if (charge === null || charge === void 0 ? void 0 : charge.fully_refunded) {
      return h("sc-tag", { type: "danger" }, __('Refunded', 'surecart'));
    }
    if (charge === null || charge === void 0 ? void 0 : charge.refunded_amount) {
      return h("sc-tag", { type: "warning" }, __('Partially Refunded', 'surecart'));
    }
    return h("sc-tag", { type: "success" }, __('Paid', 'surecart'));
  }
  renderEmpty() {
    return (h("sc-stacked-list-row", { "mobile-size": 0 }, h("slot", { name: "empty" }, __('You have no saved payment methods.', 'surecart'))));
  }
  renderLoading() {
    return (h("sc-stacked-list-row", { style: { '--columns': '2' }, "mobile-size": 0 }, h("div", { style: { padding: '0.5em' } }, h("sc-skeleton", { style: { width: '30%', marginBottom: '0.75em' } }), h("sc-skeleton", { style: { width: '20%', marginBottom: '0.75em' } }), h("sc-skeleton", { style: { width: '40%' } }))));
  }
  renderContent() {
    var _a;
    if (this.loading && !this.loaded) {
      return this.renderLoading();
    }
    if (((_a = this.charges) === null || _a === void 0 ? void 0 : _a.length) === 0) {
      return this.renderEmpty();
    }
    return this.charges.map(charge => {
      var _a;
      const { currency, amount, created_at } = charge;
      return (h("sc-stacked-list-row", { style: { '--columns': '4' }, "mobile-size": 600, href: addQueryArgs(window.location.href, {
          action: 'show',
          model: 'order',
          id: (_a = charge.checkout.order) === null || _a === void 0 ? void 0 : _a.id,
        }) }, h("strong", null, h("sc-format-date", { date: created_at, type: "timestamp", month: "short", day: "numeric", year: "numeric" })), h("sc-text", { style: { '--color': 'var(--sc-color-gray-500)' } }, sprintf(__('#%s', 'surecart'), charge.checkout.order.number)), h("div", null, this.renderRefundStatus(charge)), h("strong", null, h("sc-format-number", { type: "currency", value: amount, currency: currency }))));
    });
  }
  nextPage() {
    this.query.page = this.query.page + 1;
    this.getItems();
  }
  prevPage() {
    this.query.page = this.query.page - 1;
    this.getItems();
  }
  render() {
    var _a;
    return (h("sc-dashboard-module", { class: "charges-list", error: this.error }, h("span", { slot: "heading" }, h("slot", { name: "heading" }, this.heading || __('Payment History', 'surecart'))), !!this.allLink && (h("sc-button", { type: "link", href: this.allLink, slot: "end" }, __('View all', 'surecart'), h("sc-icon", { name: "chevron-right", slot: "suffix" }))), h("sc-card", { "no-padding": true, style: { '--overflow': 'hidden' } }, h("sc-stacked-list", null, this.renderContent())), this.showPagination && (h("sc-pagination", { page: this.query.page, perPage: this.query.per_page, total: this.pagination.total, totalPages: this.pagination.total_pages, totalShowing: (_a = this === null || this === void 0 ? void 0 : this.charges) === null || _a === void 0 ? void 0 : _a.length, onScNextPage: () => this.nextPage(), onScPrevPage: () => this.prevPage() })), this.loading && this.loaded && h("sc-block-ui", { spinner: true })));
  }
  get el() { return this; }
  static get style() { return scChargesListCss; }
}, [1, "sc-charges-list", {
    "query": [1040],
    "heading": [1],
    "showPagination": [4, "show-pagination"],
    "allLink": [1, "all-link"],
    "charges": [32],
    "loading": [32],
    "loaded": [32],
    "error": [32],
    "pagination": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-charges-list", "sc-alert", "sc-block-ui", "sc-button", "sc-card", "sc-dashboard-module", "sc-flex", "sc-format-date", "sc-format-number", "sc-icon", "sc-pagination", "sc-skeleton", "sc-spinner", "sc-stacked-list", "sc-stacked-list-row", "sc-tag", "sc-text", "sc-visually-hidden"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-charges-list":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScChargesList$1);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$i();
      }
      break;
    case "sc-block-ui":
      if (!customElements.get(tagName)) {
        defineCustomElement$h();
      }
      break;
    case "sc-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$g();
      }
      break;
    case "sc-card":
      if (!customElements.get(tagName)) {
        defineCustomElement$f();
      }
      break;
    case "sc-dashboard-module":
      if (!customElements.get(tagName)) {
        defineCustomElement$e();
      }
      break;
    case "sc-flex":
      if (!customElements.get(tagName)) {
        defineCustomElement$d();
      }
      break;
    case "sc-format-date":
      if (!customElements.get(tagName)) {
        defineCustomElement$c();
      }
      break;
    case "sc-format-number":
      if (!customElements.get(tagName)) {
        defineCustomElement$b();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$a();
      }
      break;
    case "sc-pagination":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "sc-skeleton":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "sc-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "sc-stacked-list":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-stacked-list-row":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-tag":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-text":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-visually-hidden":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const ScChargesList = ScChargesList$1;
const defineCustomElement = defineCustomElement$1;

export { ScChargesList, defineCustomElement };

//# sourceMappingURL=sc-charges-list.js.map