import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { g as getAdditionalErrorMessages } from './getters4.js';
import { s as state } from './store2.js';
import { c as currentFormState } from './getters3.js';
import { o as onChange } from './store3.js';
import { r as removeNotice } from './mutations3.js';
import { d as defineCustomElement$2 } from './sc-alert2.js';
import { d as defineCustomElement$1 } from './sc-icon2.js';

const scCheckoutFormErrorsCss = ":host{display:block}ul{margin:6px 0px;padding:0px;list-style:none}";

const ScCheckoutFormErrors = /*@__PURE__*/ proxyCustomElement(class ScCheckoutFormErrors extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.removeStateListener = () => { };
  }
  /**
   * Get the alert type.
   * @returns string
   */
  getAlertType() {
    switch (state === null || state === void 0 ? void 0 : state.type) {
      case 'error':
        return 'danger';
      case 'default':
        return 'primary';
      default:
        return state === null || state === void 0 ? void 0 : state.type;
    }
  }
  componentWillLoad() {
    // remove notice if finalizing or updating.
    this.removeStateListener = onChange('formState', () => {
      if (['finalizing', 'updating'].includes(currentFormState())) {
        removeNotice();
      }
    });
  }
  disconnectedCallback() {
    this.removeStateListener();
  }
  getTopLevelError() {
    var _a;
    // checkout invalid is not friendly.
    if ((state === null || state === void 0 ? void 0 : state.code) === 'checkout.invalid' && ((_a = getAdditionalErrorMessages()) === null || _a === void 0 ? void 0 : _a.length)) {
      return '';
    }
    return state === null || state === void 0 ? void 0 : state.message;
  }
  render() {
    // don't show component if no error message or is finalizing or updating.
    if (!(state === null || state === void 0 ? void 0 : state.message) || ['finalizing', 'updating'].includes(currentFormState())) {
      return h(Host, { style: { display: 'none' } });
    }
    return (h(Host, null, h("sc-alert", { type: this.getAlertType(), scrollOnOpen: true, open: !!(state === null || state === void 0 ? void 0 : state.message), closable: !!(state === null || state === void 0 ? void 0 : state.dismissible) }, !!this.getTopLevelError() && h("span", { slot: "title", innerHTML: this.getTopLevelError() }), (getAdditionalErrorMessages() || []).map((message, index) => (h("div", { innerHTML: message, key: index })))), h("slot", null)));
  }
  static get style() { return scCheckoutFormErrorsCss; }
}, [1, "sc-checkout-form-errors"]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-checkout-form-errors", "sc-alert", "sc-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-checkout-form-errors":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScCheckoutFormErrors);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ScCheckoutFormErrors as S, defineCustomElement as d };

//# sourceMappingURL=sc-checkout-form-errors2.js.map