import { proxyCustomElement, HTMLElement } from '@stencil/core/internal/client';
import { s as se } from './inline.js';
import { s as sprintf, _ as __ } from './default-i18n.js';
import { s as state$1 } from './mutations2.js';
import { s as state } from './watchers5.js';
import { o as onChange } from './store3.js';
import { c as currentFormState } from './getters3.js';
import { u as updateFormState } from './mutations5.js';
import { c as createErrorNotice } from './mutations3.js';

const ScCheckoutPaystackPaymentProvider = /*@__PURE__*/ proxyCustomElement(class ScCheckoutPaystackPaymentProvider extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
  }
  componentWillLoad() {
    // we need to listen to the form state and pay when the form state enters the paying state.
    this.unlistenToFormState = onChange('formState', () => {
      // are we paying?
      if ('paying' === currentFormState()) {
        this.confirm();
      }
    });
  }
  disconnectedCallback() {
    this.unlistenToFormState();
  }
  async confirm() {
    var _a, _b, _c, _d;
    // this processor is not selected.
    if ((state === null || state === void 0 ? void 0 : state.id) !== 'paystack')
      return;
    // Must be a paystack session
    if (!((_b = (_a = state$1 === null || state$1 === void 0 ? void 0 : state$1.checkout) === null || _a === void 0 ? void 0 : _a.payment_intent) === null || _b === void 0 ? void 0 : _b.processor_data.paystack))
      return;
    // Prevent if already paid.
    if (((_c = state$1 === null || state$1 === void 0 ? void 0 : state$1.checkout) === null || _c === void 0 ? void 0 : _c.status) === 'paid')
      return;
    try {
      // must have a public key and access code.
      const { public_key, access_code } = (_d = state$1 === null || state$1 === void 0 ? void 0 : state$1.checkout) === null || _d === void 0 ? void 0 : _d.payment_intent.processor_data.paystack;
      if (!public_key || !access_code) {
        createErrorNotice({ message: sprintf(__('Payment gateway configuration incomplete. Please ensure Paystack is properly configured for transactions.', 'surecart')) });
        return;
      }
      const paystack = new se();
      await paystack.newTransaction({
        key: public_key,
        accessCode: access_code,
        onSuccess: async (transaction) => {
          if ((transaction === null || transaction === void 0 ? void 0 : transaction.status) !== 'success') {
            throw { message: sprintf(__('Paystack transaction could not be finished. Status: %s', 'surecart'), transaction === null || transaction === void 0 ? void 0 : transaction.status) };
          }
          return updateFormState('PAID');
        },
        onClose: () => updateFormState('REJECT'),
      });
    }
    catch (err) {
      createErrorNotice(err);
      console.error(err);
      updateFormState('REJECT');
    }
  }
}, [1, "sc-checkout-paystack-payment-provider"]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-checkout-paystack-payment-provider"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-checkout-paystack-payment-provider":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScCheckoutPaystackPaymentProvider);
      }
      break;
  } });
}

export { ScCheckoutPaystackPaymentProvider as S, defineCustomElement as d };

//# sourceMappingURL=sc-checkout-paystack-payment-provider2.js.map