import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { _ as __ } from './default-i18n.js';
import { s as state } from './mutations2.js';
import { c as updateCheckout } from './index5.js';
import { c as currentFormState } from './getters3.js';
import { d as defineCustomElement$c } from './sc-alert2.js';
import { d as defineCustomElement$b } from './sc-block-ui2.js';
import { d as defineCustomElement$a } from './sc-button2.js';
import { d as defineCustomElement$9 } from './sc-card2.js';
import { d as defineCustomElement$8 } from './sc-dashboard-module2.js';
import { d as defineCustomElement$7 } from './sc-dialog2.js';
import { d as defineCustomElement$6 } from './sc-flex2.js';
import { d as defineCustomElement$5 } from './sc-icon2.js';
import { d as defineCustomElement$4 } from './sc-spinner2.js';
import { d as defineCustomElement$3 } from './sc-table2.js';
import { d as defineCustomElement$2 } from './sc-table-cell2.js';
import { d as defineCustomElement$1 } from './sc-table-row2.js';

const scCheckoutStockAlertCss = ":host{display:block}sc-table{height:auto}h4{display:block;margin:0;font-weight:var(--sc-font-weight-bold);font-size:var(--sc-font-size-medium)}.stock-alert{--body-spacing:var(--sc-spacing-x-large);--width:500px}.stock-alert__image{width:50px;height:50px;object-fit:cover;margin-right:10px;display:block}.stock-alert__quantity{color:var(--sc-color-gray-500);font-weight:var(--sc-font-weight-bold);display:flex;align-items:center;justify-content:flex-end;gap:var(--sc-spacing-xx-small)}";

const ScCheckoutStockAlert = /*@__PURE__*/ proxyCustomElement(class ScCheckoutStockAlert extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.scUpdateLineItem = createEvent(this, "scUpdateLineItem", 7);
    this.stockErrors = [];
    this.busy = undefined;
    this.error = undefined;
  }
  /** Get the out of stock line items. */
  getOutOfStockLineItems() {
    var _a, _b;
    return (((_b = (_a = state.checkout) === null || _a === void 0 ? void 0 : _a.line_items) === null || _b === void 0 ? void 0 : _b.data) || []).filter(lineItem => {
      var _a, _b, _c;
      const product = (_a = lineItem.price) === null || _a === void 0 ? void 0 : _a.product;
      // no stock handling.
      if (!(product === null || product === void 0 ? void 0 : product.stock_enabled) || (product === null || product === void 0 ? void 0 : product.allow_out_of_stock_purchases))
        return;
      // check the variant stock.
      if ((_b = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _b === void 0 ? void 0 : _b.id) {
        return ((_c = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _c === void 0 ? void 0 : _c.available_stock) < lineItem.quantity;
      }
      return (product === null || product === void 0 ? void 0 : product.available_stock) < lineItem.quantity;
    });
  }
  /**
   * Update the checkout line items stock to the max available.
   */
  async onSubmit() {
    const lineItems = this.getOutOfStockLineItems().map(lineItem => {
      var _a, _b, _c;
      const product = (_a = lineItem.price) === null || _a === void 0 ? void 0 : _a.product;
      if ((_b = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _b === void 0 ? void 0 : _b.id) {
        return {
          ...lineItem,
          quantity: Math.max(((_c = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _c === void 0 ? void 0 : _c.available_stock) || 0, 0),
        };
      }
      return {
        ...lineItem,
        quantity: Math.max((product === null || product === void 0 ? void 0 : product.available_stock) || 0, 0),
      };
    });
    try {
      this.busy = true;
      state.checkout = (await updateCheckout({
        id: state.checkout.id,
        data: {
          line_items: (lineItems || [])
            .filter(lineItem => !!lineItem.quantity)
            .map(lineItem => {
            var _a, _b;
            return {
              id: lineItem.id,
              price_id: (_a = lineItem.price) === null || _a === void 0 ? void 0 : _a.id,
              quantity: lineItem.quantity,
              ...(((_b = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _b === void 0 ? void 0 : _b.id) ? { variant: lineItem.variant.id } : {}),
            };
          }),
        },
      }));
    }
    catch (error) {
      const additionalErrors = ((error === null || error === void 0 ? void 0 : error.additional_errors) || []).map(error => error === null || error === void 0 ? void 0 : error.message).filter(n => n);
      this.error = `${(error === null || error === void 0 ? void 0 : error.message) || __('Something went wrong.', 'surecart')} ${(additionalErrors === null || additionalErrors === void 0 ? void 0 : additionalErrors.length) && ` ${additionalErrors.join('. ')}`}`;
    }
    finally {
      this.busy = false;
    }
  }
  render() {
    // stock errors.
    const stockErrors = (this.getOutOfStockLineItems() || []).map(lineItem => {
      var _a, _b, _c, _d, _e, _f;
      const product = (_a = lineItem.price) === null || _a === void 0 ? void 0 : _a.product;
      const variantImage = typeof ((_b = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _b === void 0 ? void 0 : _b.image) !== 'string' ? (_d = (_c = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _c === void 0 ? void 0 : _c.image) === null || _d === void 0 ? void 0 : _d.url : null;
      const available_stock = ((_e = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _e === void 0 ? void 0 : _e.id) ? (_f = lineItem === null || lineItem === void 0 ? void 0 : lineItem.variant) === null || _f === void 0 ? void 0 : _f.available_stock : product === null || product === void 0 ? void 0 : product.available_stock;
      return {
        name: product === null || product === void 0 ? void 0 : product.name,
        image_url: variantImage || (product === null || product === void 0 ? void 0 : product.image_url),
        quantity: lineItem.quantity,
        available_stock,
      };
    });
    // we have at least one quantity change.
    const hasOutOfStockItems = stockErrors === null || stockErrors === void 0 ? void 0 : stockErrors.some(item => (item === null || item === void 0 ? void 0 : item.available_stock) < 1);
    return (h(Host, null, h("sc-dialog", { open: !!stockErrors.length && currentFormState() === 'draft', noHeader: true, onScRequestClose: e => e.preventDefault(), class: "stock-alert" }, h("sc-dashboard-module", { class: "subscription-cancel", error: this.error, style: { '--sc-dashboard-module-spacing': '1em' } }, h("sc-flex", { slot: "heading", "align-items": "center", "justify-content": "flex-start" }, h("sc-icon", { name: "alert-circle", style: { color: 'var(--sc-color-primary-500' } }), hasOutOfStockItems ? __('Out of Stock', 'surecart') : __('Quantity Update', 'surecart')), h("span", { slot: "description" }, hasOutOfStockItems
      ? __('Some items are no longer available. Your cart will be updated.', 'surecart')
      : __('Available quantities for these items have changed. Your cart will be updated.', 'surecart')), h("sc-card", { "no-padding": true }, h("sc-table", null, h("sc-table-cell", { slot: "head" }, __('Description', 'surecart')), h("sc-table-cell", { slot: "head", style: { width: '100px', textAlign: 'right' } }, __('Quantity', 'surecart')), stockErrors.map((item, index) => {
      const isLastChild = index === stockErrors.length - 1;
      return (h("sc-table-row", { style: {
          '--columns': '2',
          ...(isLastChild ? { border: 'none' } : {}),
        } }, h("sc-table-cell", null, h("sc-flex", { justifyContent: "flex-start", alignItems: "center" }, h("img", { class: "stock-alert__image", src: `https://surecart.com/cdn-cgi/image/fit=scale-down,format=auto,width=100/${item === null || item === void 0 ? void 0 : item.image_url}` }), h("h4", null, item.name))), h("sc-table-cell", { style: { width: '100px', textAlign: 'right' } }, h("span", { class: "stock-alert__quantity" }, h("span", null, item === null || item === void 0 ? void 0 : item.quantity), " ", h("sc-icon", { name: "arrow-right" }), " ", h("span", null, Math.max(item === null || item === void 0 ? void 0 : item.available_stock, 0))))));
    })))), h("sc-button", { slot: "footer", type: "primary", loading: this.busy, onClick: () => this.onSubmit() }, __('Continue', 'surecart'), h("sc-icon", { name: "arrow-right", slot: "suffix" })), this.busy && h("sc-block-ui", { spinner: true }))));
  }
  static get style() { return scCheckoutStockAlertCss; }
}, [1, "sc-checkout-stock-alert", {
    "stockErrors": [32],
    "busy": [32],
    "error": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-checkout-stock-alert", "sc-alert", "sc-block-ui", "sc-button", "sc-card", "sc-dashboard-module", "sc-dialog", "sc-flex", "sc-icon", "sc-spinner", "sc-table", "sc-table-cell", "sc-table-row"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-checkout-stock-alert":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScCheckoutStockAlert);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$c();
      }
      break;
    case "sc-block-ui":
      if (!customElements.get(tagName)) {
        defineCustomElement$b();
      }
      break;
    case "sc-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$a();
      }
      break;
    case "sc-card":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "sc-dashboard-module":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "sc-dialog":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "sc-flex":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-table":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-table-cell":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "sc-table-row":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ScCheckoutStockAlert as S, defineCustomElement as d };

//# sourceMappingURL=sc-checkout-stock-alert2.js.map