import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { g as getProcessorByType } from './getters5.js';
import { f as formBusy } from './getters3.js';
import { d as defineCustomElement$7 } from './sc-alert2.js';
import { d as defineCustomElement$6 } from './sc-block-ui2.js';
import { d as defineCustomElement$5 } from './sc-divider2.js';
import { d as defineCustomElement$4 } from './sc-icon2.js';
import { d as defineCustomElement$3 } from './sc-spinner2.js';
import { d as defineCustomElement$2 } from './sc-stripe-payment-request2.js';

const scExpressPaymentCss = "sc-express-payment{display:block}";

const ScExpressPayment$1 = /*@__PURE__*/ proxyCustomElement(class ScExpressPayment extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.processor = undefined;
    this.dividerText = undefined;
    this.debug = undefined;
    this.hasPaymentOptions = undefined;
  }
  onPaymentRequestLoaded() {
    this.hasPaymentOptions = true;
  }
  renderStripePaymentRequest() {
    const { processor_data } = getProcessorByType('stripe') || {};
    return h("sc-stripe-payment-request", { debug: this.debug, stripeAccountId: processor_data === null || processor_data === void 0 ? void 0 : processor_data.account_id, publishableKey: processor_data === null || processor_data === void 0 ? void 0 : processor_data.publishable_key });
  }
  render() {
    return (h(Host, { class: { 'is-empty': !this.hasPaymentOptions && !this.debug } }, this.renderStripePaymentRequest(), (this.hasPaymentOptions || this.debug) && h("sc-divider", { style: { '--spacing': 'calc(var(--sc-form-row-spacing)/2)' } }, this.dividerText), !!formBusy() && h("sc-block-ui", null)));
  }
  static get style() { return scExpressPaymentCss; }
}, [0, "sc-express-payment", {
    "processor": [1],
    "dividerText": [1, "divider-text"],
    "debug": [4],
    "hasPaymentOptions": [1028, "has-payment-options"]
  }, [[0, "scPaymentRequestLoaded", "onPaymentRequestLoaded"]]]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-express-payment", "sc-alert", "sc-block-ui", "sc-divider", "sc-icon", "sc-spinner", "sc-stripe-payment-request"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-express-payment":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScExpressPayment$1);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "sc-block-ui":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-divider":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-stripe-payment-request":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const ScExpressPayment = ScExpressPayment$1;
const defineCustomElement = defineCustomElement$1;

export { ScExpressPayment, defineCustomElement };

//# sourceMappingURL=sc-express-payment.js.map