import { proxyCustomElement, HTMLElement, h, Fragment } from '@stencil/core/internal/client';
import { o as onFirstVisible } from './lazy.js';
import { _ as __ } from './default-i18n.js';
import { a as apiFetch } from './fetch.js';
import { d as defineCustomElement$k } from './sc-alert2.js';
import { d as defineCustomElement$j } from './sc-block-ui2.js';
import { d as defineCustomElement$i } from './sc-button2.js';
import { d as defineCustomElement$h } from './sc-card2.js';
import { d as defineCustomElement$g } from './sc-dashboard-module2.js';
import { d as defineCustomElement$f } from './sc-dialog2.js';
import { d as defineCustomElement$e } from './sc-empty2.js';
import { d as defineCustomElement$d } from './sc-flex2.js';
import { d as defineCustomElement$c } from './sc-form-control2.js';
import { d as defineCustomElement$b } from './sc-format-date2.js';
import { d as defineCustomElement$a } from './sc-icon2.js';
import { d as defineCustomElement$9 } from './sc-input2.js';
import { d as defineCustomElement$8 } from './sc-skeleton2.js';
import { d as defineCustomElement$7 } from './sc-spacing2.js';
import { d as defineCustomElement$6 } from './sc-spinner2.js';
import { d as defineCustomElement$5 } from './sc-stacked-list2.js';
import { d as defineCustomElement$4 } from './sc-stacked-list-row2.js';
import { d as defineCustomElement$3 } from './sc-tag2.js';
import { d as defineCustomElement$2 } from './sc-visually-hidden2.js';
import { a as addQueryArgs } from './add-query-args.js';

const scLicenseCss = ":host{display:block}.license__date{font-weight:var(--sc-font-weight-semibold)}.license__heading{display:flex;align-items:center;gap:1rem}.license__key{display:block}.close__button{position:absolute;top:0;right:0;font-size:22px;z-index:1}.license-cancel{display:grid;gap:0.5em}";

const ScLicense$1 = /*@__PURE__*/ proxyCustomElement(class ScLicense extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.deleteActivation = async () => {
      try {
        this.busy = true;
        await apiFetch({
          path: `surecart/v1/activations/${this.selectedActivationId}`,
          method: 'DELETE',
        });
        this.onCloseDeleteModal();
        await this.initialFetch();
      }
      catch (e) {
        console.error(e);
        this.deleteActivationError = (e === null || e === void 0 ? void 0 : e.message) || __('Something went wrong', 'surecart');
      }
      finally {
        this.busy = false;
      }
    };
    this.onCloseDeleteModal = () => {
      this.selectedActivationId = '';
      this.showConfirmDelete = false;
      this.busy = false;
      this.deleteActivationError = '';
    };
    this.licenseId = undefined;
    this.loading = false;
    this.error = '';
    this.license = undefined;
    this.copied = false;
    this.showConfirmDelete = false;
    this.selectedActivationId = '';
    this.deleteActivationError = '';
    this.busy = false;
  }
  /** Only fetch if visible */
  componentWillLoad() {
    onFirstVisible(this.el, () => {
      this.initialFetch();
    });
  }
  async initialFetch() {
    try {
      this.loading = true;
      await this.getLicense();
    }
    catch (e) {
      console.error(e);
      this.error = (e === null || e === void 0 ? void 0 : e.message) || __('Something went wrong', 'surecart');
    }
    finally {
      this.loading = false;
    }
  }
  async getLicense() {
    this.license = await apiFetch({
      path: addQueryArgs(`surecart/v1/licenses/${this.licenseId}`, {
        expand: ['activations', 'purchase', 'purchase.product'],
      }),
    });
  }
  async copyKey(key) {
    try {
      await navigator.clipboard.writeText(key);
      this.copied = true;
      setTimeout(() => {
        this.copied = false;
      }, 2000);
    }
    catch (err) {
      console.error(err);
      alert(__('Error copying to clipboard', 'surecart'));
    }
  }
  renderStatus() {
    var _a, _b, _c, _d;
    if (((_a = this.license) === null || _a === void 0 ? void 0 : _a.status) === 'active') {
      return h("sc-tag", { type: "success" }, __('Active', 'surecart'));
    }
    if (((_b = this.license) === null || _b === void 0 ? void 0 : _b.status) === 'revoked') {
      return h("sc-tag", { type: "danger" }, __('Revoked', 'surecart'));
    }
    if (((_c = this.license) === null || _c === void 0 ? void 0 : _c.status) === 'inactive') {
      return h("sc-tag", { type: "info" }, __('Inactive', 'surecart'));
    }
    return h("sc-tag", { type: "info" }, (_d = this.license) === null || _d === void 0 ? void 0 : _d.status);
  }
  renderLoading() {
    return (h("sc-dashboard-module", null, h("span", { slot: "heading" }, h("sc-skeleton", { style: { width: '120px' } })), h("sc-card", null, h("sc-stacked-list", null, h("sc-flex", { flexDirection: "column", style: { gap: '1em' } }, h("sc-skeleton", { style: { width: '20%', display: 'inline-block' } }), h("sc-skeleton", { style: { width: '60%', display: 'inline-block' } }), h("sc-skeleton", { style: { width: '40%', display: 'inline-block' } }))))));
  }
  renderEmpty() {
    return h("sc-empty", { icon: "activity" }, __('License not found.', 'surecart'));
  }
  renderLicenseHeader() {
    var _a;
    const purchase = (_a = this.license) === null || _a === void 0 ? void 0 : _a.purchase;
    const product = purchase === null || purchase === void 0 ? void 0 : purchase.product;
    return (h(Fragment, null, h("span", { slot: "heading" }, h("div", { class: "license__heading" }, product === null || product === void 0 ? void 0 :
      product.name, !this.loading && !purchase.live_mode && (h("sc-tag", { type: "warning", size: "small" }, __('Test Mode', 'surecart')))))));
  }
  renderContent() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
    if (this.loading && !((_a = this.license) === null || _a === void 0 ? void 0 : _a.id)) {
      return this.renderLoading();
    }
    if (!((_b = this.license) === null || _b === void 0 ? void 0 : _b.id)) {
      return this.renderEmpty();
    }
    return (h(Fragment, null, h("sc-dashboard-module", { error: this.error }, this.renderLicenseHeader(), h("sc-card", { noPadding: true }, h("sc-stacked-list", null, h("sc-stacked-list-row", { style: { '--columns': '2', '--sc-stacked-list-row-align-items': 'center' } }, h("div", null, __('License Status', 'surecart')), this.renderStatus()), h("sc-stacked-list-row", { style: { '--columns': '2' } }, h("div", null, __('License Key', 'surecart')), h("div", { class: "license__key" }, h("sc-input", { value: (_c = this.license) === null || _c === void 0 ? void 0 : _c.key, readonly: true }, h("sc-button", { class: "license__copy", type: "default", size: "small", slot: "suffix", onClick: () => { var _a; return this.copyKey((_a = this.license) === null || _a === void 0 ? void 0 : _a.key); } }, this.copied ? __('Copied!', 'surecart') : __('Copy', 'surecart'))))), h("sc-stacked-list-row", { style: { '--columns': '2' } }, h("div", null, __('Date', 'surecart')), h("sc-format-date", { date: (_d = this.license) === null || _d === void 0 ? void 0 : _d.created_at, type: "timestamp", month: "short", day: "numeric", year: "numeric" })), h("sc-stacked-list-row", { style: { '--columns': '2' } }, h("div", null, __('Activations Count', 'surecart')), h("span", null, (_e = this.license) === null || _e === void 0 ? void 0 :
      _e.activation_count, " / ", ((_f = this.license) === null || _f === void 0 ? void 0 : _f.activation_limit) || h("span", null, "\u221E")))))), h("sc-dashboard-module", null, h("span", { slot: "heading" }, h("slot", { name: "heading" }, __('Activations', 'surecart'))), h("sc-card", { noPadding: true }, !!((_j = (_h = (_g = this.license) === null || _g === void 0 ? void 0 : _g.activations) === null || _h === void 0 ? void 0 : _h.data) === null || _j === void 0 ? void 0 : _j.length) ? (h("sc-stacked-list", null, (_k = this.license) === null || _k === void 0 ? void 0 : _k.activations.data.map(activation => (h("sc-stacked-list-row", { style: { '--columns': '4' } }, h("sc-format-date", { class: "license__date", date: activation.created_at, type: "timestamp", month: "short", day: "numeric", year: "numeric" }), h("div", null, activation.name), h("div", null, activation.fingerprint), h("div", null, h("sc-button", { size: "small", onClick: () => {
        this.selectedActivationId = activation.id;
        this.showConfirmDelete = true;
      } }, "Delete"))))))) : (h("sc-empty", null, __('No activations present.', 'surecart'))), this.loading && h("sc-block-ui", { style: { '--sc-block-ui-opacity': '0.75' }, spinner: true })))));
  }
  renderConfirmDelete() {
    return (h("sc-dialog", { open: this.showConfirmDelete, style: { '--body-spacing': 'var(--sc-spacing-x-large)' }, noHeader: true, onScRequestClose: this.onCloseDeleteModal }, h("sc-button", { class: "close__button", type: "text", circle: true, onClick: this.onCloseDeleteModal, disabled: this.loading }, h("sc-icon", { name: "x" })), h("sc-dashboard-module", { heading: __('Delete Activation', 'surecart'), class: "license-cancel", error: this.error, style: { '--sc-dashboard-module-spacing': '1em' } }, h("span", { slot: "description" }, __('Are you sure you want to delete activation?', 'surecart')), h("sc-flex", { justifyContent: "flex-start" }, h("sc-button", { type: "primary", disabled: this.loading || this.busy, onClick: this.deleteActivation }, __('Delete Activation', 'surecart')), h("sc-button", { style: { color: 'var(--sc-color-gray-500' }, type: "text", onClick: this.onCloseDeleteModal, disabled: this.loading || this.busy }, __('Cancel', 'surecart'))), this.busy && h("sc-block-ui", { style: { '--sc-block-ui-opacity': '0.75' }, spinner: true }))));
  }
  render() {
    return (h("sc-spacing", { style: { '--spacing': 'var(--sc-spacing-large)' } }, this.renderContent(), this.renderConfirmDelete()));
  }
  get el() { return this; }
  static get style() { return scLicenseCss; }
}, [1, "sc-license", {
    "licenseId": [1, "license-id"],
    "loading": [32],
    "error": [32],
    "license": [32],
    "copied": [32],
    "showConfirmDelete": [32],
    "selectedActivationId": [32],
    "deleteActivationError": [32],
    "busy": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-license", "sc-alert", "sc-block-ui", "sc-button", "sc-card", "sc-dashboard-module", "sc-dialog", "sc-empty", "sc-flex", "sc-form-control", "sc-format-date", "sc-icon", "sc-input", "sc-skeleton", "sc-spacing", "sc-spinner", "sc-stacked-list", "sc-stacked-list-row", "sc-tag", "sc-visually-hidden"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-license":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScLicense$1);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$k();
      }
      break;
    case "sc-block-ui":
      if (!customElements.get(tagName)) {
        defineCustomElement$j();
      }
      break;
    case "sc-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$i();
      }
      break;
    case "sc-card":
      if (!customElements.get(tagName)) {
        defineCustomElement$h();
      }
      break;
    case "sc-dashboard-module":
      if (!customElements.get(tagName)) {
        defineCustomElement$g();
      }
      break;
    case "sc-dialog":
      if (!customElements.get(tagName)) {
        defineCustomElement$f();
      }
      break;
    case "sc-empty":
      if (!customElements.get(tagName)) {
        defineCustomElement$e();
      }
      break;
    case "sc-flex":
      if (!customElements.get(tagName)) {
        defineCustomElement$d();
      }
      break;
    case "sc-form-control":
      if (!customElements.get(tagName)) {
        defineCustomElement$c();
      }
      break;
    case "sc-format-date":
      if (!customElements.get(tagName)) {
        defineCustomElement$b();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$a();
      }
      break;
    case "sc-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "sc-skeleton":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "sc-spacing":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "sc-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-stacked-list":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-stacked-list-row":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-tag":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-visually-hidden":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const ScLicense = ScLicense$1;
const defineCustomElement = defineCustomElement$1;

export { ScLicense, defineCustomElement };

//# sourceMappingURL=sc-license.js.map