import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { _ as __, s as sprintf } from './default-i18n.js';
import { o as onFirstVisible } from './lazy.js';
import { a as apiFetch } from './fetch.js';
import { d as defineCustomElement$d } from './sc-alert2.js';
import { d as defineCustomElement$c } from './sc-button2.js';
import { d as defineCustomElement$b } from './sc-card2.js';
import { d as defineCustomElement$a } from './sc-dashboard-module2.js';
import { d as defineCustomElement$9 } from './sc-divider2.js';
import { d as defineCustomElement$8 } from './sc-empty2.js';
import { d as defineCustomElement$7 } from './sc-icon2.js';
import { d as defineCustomElement$6 } from './sc-skeleton2.js';
import { d as defineCustomElement$5 } from './sc-spinner2.js';
import { d as defineCustomElement$4 } from './sc-stacked-list2.js';
import { d as defineCustomElement$3 } from './sc-stacked-list-row2.js';
import { d as defineCustomElement$2 } from './sc-tag2.js';
import { a as addQueryArgs } from './add-query-args.js';

const scLicensesListCss = ":host{display:block}.license__name{font-weight:var(--sc-font-weight-semibold)}.license__details{display:grid;gap:0.25em;color:var(--sc-input-label-color)}";

const ScLicensesList$1 = /*@__PURE__*/ proxyCustomElement(class ScLicensesList extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.query = {
      page: 1,
      per_page: 10,
    };
    this.heading = __('Licenses', 'surecart');
    this.isCustomer = undefined;
    this.allLink = undefined;
    this.licenses = [];
    this.copied = false;
    this.loading = false;
    this.error = '';
    this.pagination = {
      total: 0,
      total_pages: 0,
    };
  }
  /** Only fetch if visible */
  componentWillLoad() {
    onFirstVisible(this.el, () => {
      this.initialFetch();
    });
  }
  async initialFetch() {
    try {
      this.loading = true;
      await this.getLicenses();
    }
    catch (e) {
      console.error(e);
      this.error = (e === null || e === void 0 ? void 0 : e.message) || __('Something went wrong', 'surecart');
    }
    finally {
      this.loading = false;
    }
  }
  async getLicenses() {
    if (!this.isCustomer) {
      return;
    }
    const response = (await await apiFetch({
      path: addQueryArgs('surecart/v1/licenses', {
        expand: ['purchase', 'purchase.product', 'activations'],
        ...this.query,
      }),
      parse: false,
    }));
    this.pagination = {
      total: parseInt(response.headers.get('X-WP-Total')),
      total_pages: parseInt(response.headers.get('X-WP-TotalPages')),
    };
    this.licenses = (await response.json());
    return this.licenses;
  }
  renderStatus(status) {
    if (status === 'active') {
      return h("sc-tag", { type: "success" }, __('Active', 'surecart'));
    }
    if (status === 'revoked') {
      return h("sc-tag", { type: "danger" }, __('Revoked', 'surecart'));
    }
    if (status === 'inactive') {
      return h("sc-tag", { type: "info" }, __('Not Activated', 'surecart'));
    }
    return h("sc-tag", { type: "info" }, status);
  }
  async copyKey(key) {
    try {
      await navigator.clipboard.writeText(key);
      this.copied = true;
      setTimeout(() => {
        this.copied = false;
      }, 2000);
    }
    catch (err) {
      console.error(err);
      alert(__('Error copying to clipboard', 'surecart'));
    }
  }
  renderLoading() {
    return (h("sc-card", { "no-padding": true, style: { '--overflow': 'hidden' } }, h("sc-stacked-list", null, h("sc-stacked-list-row", { style: { '--columns': '2' }, "mobile-size": 0 }, h("div", { style: { padding: '0.5em' } }, h("sc-skeleton", { style: { width: '30%', marginBottom: '0.75em' } }), h("sc-skeleton", { style: { width: '20%', marginBottom: '0.75em' } }), h("sc-skeleton", { style: { width: '40%' } }))))));
  }
  renderEmpty() {
    return (h("div", null, h("sc-divider", { style: { '--spacing': '0' } }), h("slot", { name: "empty" }, h("sc-empty", { icon: "file-text" }, __("You don't have any licenses.", 'surecart')))));
  }
  renderContent() {
    var _a, _b;
    if (this.loading) {
      return this.renderLoading();
    }
    if (((_a = this.licenses) === null || _a === void 0 ? void 0 : _a.length) === 0) {
      return this.renderEmpty();
    }
    return (h("sc-card", { "no-padding": true }, h("sc-stacked-list", null, (_b = this.licenses) === null || _b === void 0 ? void 0 : _b.map(({ id, purchase, status, activation_limit, activation_count }) => {
      var _a;
      return (h("sc-stacked-list-row", { key: id, href: addQueryArgs(window.location.href, {
          action: 'show',
          model: 'license',
          id,
        }), "mobile-size": 0 }, h("div", { class: "license__details" }, h("div", { class: "license__name" }, (_a = purchase === null || purchase === void 0 ? void 0 : purchase.product) === null || _a === void 0 ? void 0 : _a.name), h("div", null, this.renderStatus(status), " ", sprintf(__('%1s of %2s Activations Used'), activation_count || 0, activation_limit || '∞'))), h("sc-icon", { name: "chevron-right", slot: "suffix" })));
    }))));
  }
  render() {
    var _a;
    return (h("sc-dashboard-module", { class: "purchase", part: "base", error: this.error }, h("span", { slot: "heading" }, h("slot", { name: "heading" }, this.heading || __('License Keys', 'surecart'))), !!this.allLink && !!((_a = this.licenses) === null || _a === void 0 ? void 0 : _a.length) && (h("sc-button", { type: "link", href: this.allLink, slot: "end" }, __('View all', 'surecart'), h("sc-icon", { name: "chevron-right", slot: "suffix" }))), this.renderContent()));
  }
  get el() { return this; }
  static get style() { return scLicensesListCss; }
}, [1, "sc-licenses-list", {
    "query": [1040],
    "heading": [1],
    "isCustomer": [4, "is-customer"],
    "allLink": [1, "all-link"],
    "licenses": [1040],
    "copied": [32],
    "loading": [32],
    "error": [32],
    "pagination": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-licenses-list", "sc-alert", "sc-button", "sc-card", "sc-dashboard-module", "sc-divider", "sc-empty", "sc-icon", "sc-skeleton", "sc-spinner", "sc-stacked-list", "sc-stacked-list-row", "sc-tag"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-licenses-list":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScLicensesList$1);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$d();
      }
      break;
    case "sc-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$c();
      }
      break;
    case "sc-card":
      if (!customElements.get(tagName)) {
        defineCustomElement$b();
      }
      break;
    case "sc-dashboard-module":
      if (!customElements.get(tagName)) {
        defineCustomElement$a();
      }
      break;
    case "sc-divider":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "sc-empty":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "sc-skeleton":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-stacked-list":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-stacked-list-row":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-tag":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const ScLicensesList = ScLicensesList$1;
const defineCustomElement = defineCustomElement$1;

export { ScLicensesList, defineCustomElement };

//# sourceMappingURL=sc-licenses-list.js.map