import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { s as state } from './mutations2.js';
import { h as hasSubscription } from './index6.js';
import { i as intervalString } from './price.js';
import { g as getFeaturedProductMediaAttributes } from './media.js';
import { u as updateCheckoutLineItem, r as removeCheckoutLineItem } from './mutations4.js';
import { f as formBusy } from './getters3.js';
import { g as getMaxStockQuantity } from './quantity.js';
import { d as defineCustomElement$7 } from './sc-format-number2.js';
import { d as defineCustomElement$6 } from './sc-icon2.js';
import { d as defineCustomElement$5 } from './sc-line-item2.js';
import { d as defineCustomElement$4 } from './sc-product-line-item2.js';
import { d as defineCustomElement$3 } from './sc-quantity-select2.js';
import { d as defineCustomElement$2 } from './sc-skeleton2.js';

const scLineItemsCss = ":host{display:block}:slotted(*~*){margin-top:20px}.line-items{display:grid;gap:var(--sc-form-row-spacing)}.line-item{display:grid;gap:var(--sc-spacing-small)}.fee__description{opacity:0.75}";

const ScLineItems$1 = /*@__PURE__*/ proxyCustomElement(class ScLineItems extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.editable = undefined;
    this.removable = undefined;
  }
  /**
   * Is the line item editable?
   */
  isEditable(item) {
    var _a;
    // ad_hoc prices and bumps cannot have quantity.
    if (((_a = item === null || item === void 0 ? void 0 : item.price) === null || _a === void 0 ? void 0 : _a.ad_hoc) || (item === null || item === void 0 ? void 0 : item.bump_amount)) {
      return false;
    }
    return this.editable;
  }
  render() {
    var _a, _b, _c, _d, _e;
    if (!!formBusy() && !((_c = (_b = (_a = state === null || state === void 0 ? void 0 : state.checkout) === null || _a === void 0 ? void 0 : _a.line_items) === null || _b === void 0 ? void 0 : _b.data) === null || _c === void 0 ? void 0 : _c.length)) {
      return (h("sc-line-item", null, h("sc-skeleton", { style: { 'width': '50px', 'height': '50px', '--border-radius': '0' }, slot: "image" }), h("sc-skeleton", { slot: "title", style: { width: '120px', display: 'inline-block' } }), h("sc-skeleton", { slot: "description", style: { width: '60px', display: 'inline-block' } }), h("sc-skeleton", { style: { width: '120px', display: 'inline-block' }, slot: "price" }), h("sc-skeleton", { style: { width: '60px', display: 'inline-block' }, slot: "price-description" })));
    }
    return (h("div", { class: "line-items", part: "base", tabindex: "0" }, (((_e = (_d = state === null || state === void 0 ? void 0 : state.checkout) === null || _d === void 0 ? void 0 : _d.line_items) === null || _e === void 0 ? void 0 : _e.data) || []).map(item => {
      var _a, _b, _c, _d, _e, _f, _g, _h, _j;
      const { url, title, alt } = getFeaturedProductMediaAttributes((_a = item === null || item === void 0 ? void 0 : item.price) === null || _a === void 0 ? void 0 : _a.product, item === null || item === void 0 ? void 0 : item.variant);
      const max = getMaxStockQuantity((_b = item === null || item === void 0 ? void 0 : item.price) === null || _b === void 0 ? void 0 : _b.product, item === null || item === void 0 ? void 0 : item.variant);
      return (h("div", { class: "line-item" }, h("sc-product-line-item", { key: item.id, imageUrl: url, imageTitle: title, imageAlt: alt, name: (_d = (_c = item === null || item === void 0 ? void 0 : item.price) === null || _c === void 0 ? void 0 : _c.product) === null || _d === void 0 ? void 0 : _d.name, priceName: (_e = item === null || item === void 0 ? void 0 : item.price) === null || _e === void 0 ? void 0 : _e.name, variantLabel: ((item === null || item === void 0 ? void 0 : item.variant_options) || []).filter(Boolean).join(' / ') || null, ...(max ? { max } : {}), editable: this.isEditable(item), removable: this.removable, quantity: item.quantity, fees: (_f = item === null || item === void 0 ? void 0 : item.fees) === null || _f === void 0 ? void 0 : _f.data, setupFeeTrialEnabled: (_g = item === null || item === void 0 ? void 0 : item.price) === null || _g === void 0 ? void 0 : _g.setup_fee_trial_enabled, amount: item.ad_hoc_amount !== null ? item.ad_hoc_amount : item.subtotal_amount, scratchAmount: item.ad_hoc_amount == null && (item === null || item === void 0 ? void 0 : item.scratch_amount), currency: (_h = state === null || state === void 0 ? void 0 : state.checkout) === null || _h === void 0 ? void 0 : _h.currency, trialDurationDays: (_j = item === null || item === void 0 ? void 0 : item.price) === null || _j === void 0 ? void 0 : _j.trial_duration_days, interval: !!(item === null || item === void 0 ? void 0 : item.price) && intervalString(item === null || item === void 0 ? void 0 : item.price, { showOnce: hasSubscription(state === null || state === void 0 ? void 0 : state.checkout) }), onScUpdateQuantity: e => updateCheckoutLineItem({ id: item.id, data: { quantity: e.detail } }), onScRemove: () => removeCheckoutLineItem(item === null || item === void 0 ? void 0 : item.id), exportparts: "base:line-item, product-line-item, image:line-item__image, text:line-item__text, title:line-item__title, suffix:line-item__suffix, price:line-item__price, price__amount:line-item__price-amount, price__description:line-item__price-description, price__scratch:line-item__price-scratch, static-quantity:line-item__static-quantity, remove-icon__base:line-item__remove-icon, quantity:line-item__quantity, quantity__minus:line-item__quantity-minus, quantity__minus-icon:line-item__quantity-minus-icon, quantity__plus:line-item__quantity-plus, quantity__plus-icon:line-item__quantity-plus-icon, quantity__input:line-item__quantity-input, line-item__price-description:line-item__price-description" })));
    })));
  }
  static get style() { return scLineItemsCss; }
}, [1, "sc-line-items", {
    "editable": [4],
    "removable": [4]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-line-items", "sc-format-number", "sc-icon", "sc-line-item", "sc-product-line-item", "sc-quantity-select", "sc-skeleton"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-line-items":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScLineItems$1);
      }
      break;
    case "sc-format-number":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-line-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-product-line-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-quantity-select":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-skeleton":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const ScLineItems = ScLineItems$1;
const defineCustomElement = defineCustomElement$1;

export { ScLineItems, defineCustomElement };

//# sourceMappingURL=sc-line-items.js.map