import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { _ as __ } from './default-i18n.js';
import { s as speak } from './index3.js';
import { a as apiFetch } from './fetch.js';
import { e as expand } from './index5.js';
import { s as state } from './mutations2.js';
import { s as state$1 } from './store3.js';
import { c as createErrorNotice } from './mutations3.js';
import { c as clearCheckout } from './mutations4.js';
import { d as defineCustomElement$6 } from './sc-alert2.js';
import { d as defineCustomElement$5 } from './sc-button2.js';
import { d as defineCustomElement$4 } from './sc-dashboard-module2.js';
import { d as defineCustomElement$3 } from './sc-dialog2.js';
import { d as defineCustomElement$2 } from './sc-icon2.js';
import { d as defineCustomElement$1 } from './sc-spinner2.js';
import { a as addQueryArgs } from './add-query-args.js';

const scOrderConfirmProviderCss = ".confirm__icon{margin-bottom:var(--sc-spacing-medium);display:flex;justify-content:center}.confirm__icon-container{background:var(--sc-color-primary-500);width:55px;height:55px;border-radius:999999px;display:flex;align-items:center;justify-content:center;font-size:26px;line-height:1;color:white}sc-dialog::part(overlay){backdrop-filter:blur(4px)}";

const ScOrderConfirmProvider = /*@__PURE__*/ proxyCustomElement(class ScOrderConfirmProvider extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.scOrderPaid = createEvent(this, "scOrderPaid", 7);
    this.scSetState = createEvent(this, "scSetState", 7);
    this.showSuccessModal = false;
    this.checkoutStatus = undefined;
    this.successUrl = undefined;
  }
  /**
   * Watch for paid checkout machine state.
   * This is triggered by Stripe, Paypal or Paystack when payment succeeds.
   */
  handleConfirmOrderEvent() {
    if (this.checkoutStatus === 'confirming') {
      this.confirmOrder();
    }
    else if (this.checkoutStatus === 'confirmed') {
      speak(__('Order has been confirmed. Please select continue to go to the next step.', 'surecart'));
    }
  }
  /** Confirm the order. */
  async confirmOrder() {
    var _a, _b, _c, _d, _e;
    try {
      state.checkout = (await apiFetch({
        method: 'PATCH',
        path: addQueryArgs(`surecart/v1/checkouts/${(_a = state === null || state === void 0 ? void 0 : state.checkout) === null || _a === void 0 ? void 0 : _a.id}/confirm`, { expand }),
      }));
      this.scSetState.emit('CONFIRMED');
    }
    catch (e) {
      console.error(e);
      createErrorNotice(e);
    }
    finally {
      // If there is an initial upsell redirect to it.
      if (!!((_c = (_b = state === null || state === void 0 ? void 0 : state.checkout) === null || _b === void 0 ? void 0 : _b.current_upsell) === null || _c === void 0 ? void 0 : _c.permalink)) {
        setTimeout(() => {
          var _a, _b, _c;
          return window.location.assign(addQueryArgs((_b = (_a = state === null || state === void 0 ? void 0 : state.checkout) === null || _a === void 0 ? void 0 : _a.current_upsell) === null || _b === void 0 ? void 0 : _b.permalink, {
            sc_checkout_id: (_c = state.checkout) === null || _c === void 0 ? void 0 : _c.id,
            sc_form_id: state.formId,
          }));
        }, 50);
        clearCheckout();
        return;
      }
      // get success url.
      const successUrl = ((_e = (_d = state.checkout) === null || _d === void 0 ? void 0 : _d.metadata) === null || _e === void 0 ? void 0 : _e.success_url) || this.successUrl;
      if (successUrl) {
        // set state to redirecting.
        this.scSetState.emit('REDIRECT');
        setTimeout(() => { var _a; return window.location.assign(addQueryArgs(successUrl, { sc_order: (_a = state.checkout) === null || _a === void 0 ? void 0 : _a.id })); }, 50);
      }
      else {
        this.showSuccessModal = true;
      }
      clearCheckout();
    }
  }
  getSuccessUrl() {
    var _a, _b, _c, _d, _e;
    const url = ((_b = (_a = state.checkout) === null || _a === void 0 ? void 0 : _a.metadata) === null || _b === void 0 ? void 0 : _b.success_url) || this.successUrl;
    return url ? addQueryArgs(url, { sc_order: (_c = state.checkout) === null || _c === void 0 ? void 0 : _c.id }) : (_e = (_d = window === null || window === void 0 ? void 0 : window.scData) === null || _d === void 0 ? void 0 : _d.pages) === null || _e === void 0 ? void 0 : _e.dashboard;
  }
  handleSuccessModal() {
    if (this.showSuccessModal) {
      setTimeout(() => {
        var _a;
        (_a = this.continueButton) === null || _a === void 0 ? void 0 : _a.focus();
      }, 50);
    }
  }
  render() {
    var _a, _b, _c, _d, _e, _f, _g;
    const manualPaymentMethod = (_a = state.checkout) === null || _a === void 0 ? void 0 : _a.manual_payment_method;
    return (h(Host, null, h("slot", null), h("sc-dialog", { open: !!this.showSuccessModal, style: { '--body-spacing': 'var(--sc-spacing-xxx-large)' }, noHeader: true, onScRequestClose: e => e.preventDefault() }, h("div", { class: "confirm__icon" }, h("div", { class: "confirm__icon-container" }, h("sc-icon", { name: "check" }))), h("sc-dashboard-module", { heading: ((_c = (_b = state$1 === null || state$1 === void 0 ? void 0 : state$1.text) === null || _b === void 0 ? void 0 : _b.success) === null || _c === void 0 ? void 0 : _c.title) || __('Thanks for your order!', 'surecart'), style: { '--sc-dashboard-module-spacing': 'var(--sc-spacing-x-large)', 'textAlign': 'center' } }, h("span", { slot: "description" }, ((_e = (_d = state$1 === null || state$1 === void 0 ? void 0 : state$1.text) === null || _d === void 0 ? void 0 : _d.success) === null || _e === void 0 ? void 0 : _e.description) || __('Your payment was successful. A receipt is on its way to your inbox.', 'surecart')), !!(manualPaymentMethod === null || manualPaymentMethod === void 0 ? void 0 : manualPaymentMethod.name) && !!(manualPaymentMethod === null || manualPaymentMethod === void 0 ? void 0 : manualPaymentMethod.instructions) && (h("sc-alert", { type: "info", open: true, style: { 'text-align': 'left' } }, h("span", { slot: "title" }, manualPaymentMethod === null || manualPaymentMethod === void 0 ? void 0 : manualPaymentMethod.name), h("div", { innerHTML: manualPaymentMethod === null || manualPaymentMethod === void 0 ? void 0 : manualPaymentMethod.instructions }))), h("sc-button", { href: this.getSuccessUrl(), size: "large", type: "primary", ref: el => (this.continueButton = el) }, ((_g = (_f = state$1 === null || state$1 === void 0 ? void 0 : state$1.text) === null || _f === void 0 ? void 0 : _f.success) === null || _g === void 0 ? void 0 : _g.button) || __('Continue', 'surecart'), h("sc-icon", { name: "arrow-right", slot: "suffix" }))))));
  }
  get el() { return this; }
  static get watchers() { return {
    "checkoutStatus": ["handleConfirmOrderEvent"],
    "showSuccessModal": ["handleSuccessModal"]
  }; }
  static get style() { return scOrderConfirmProviderCss; }
}, [1, "sc-order-confirm-provider", {
    "checkoutStatus": [1, "checkout-status"],
    "successUrl": [1, "success-url"],
    "showSuccessModal": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-order-confirm-provider", "sc-alert", "sc-button", "sc-dashboard-module", "sc-dialog", "sc-icon", "sc-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-order-confirm-provider":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScOrderConfirmProvider);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-dashboard-module":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-dialog":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "sc-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ScOrderConfirmProvider as S, defineCustomElement as d };

//# sourceMappingURL=sc-order-confirm-provider2.js.map