import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { s as state, o as onChange } from './mutations2.js';
import { l as lockCheckout, b as unLockCheckout } from './mutations4.js';
import { _ as __ } from './default-i18n.js';
import { d as createOrUpdateCheckout } from './index5.js';
import { f as fullShippingAddressRequired } from './getters2.js';
import { a as formLoading } from './getters3.js';
import { d as defineCustomElement$d } from './sc-address2.js';
import { d as defineCustomElement$c } from './sc-block-ui2.js';
import { d as defineCustomElement$b } from './sc-compact-address2.js';
import { d as defineCustomElement$a } from './dropdown.js';
import { d as defineCustomElement$9 } from './sc-form-control2.js';
import { d as defineCustomElement$8 } from './sc-icon2.js';
import { d as defineCustomElement$7 } from './sc-input2.js';
import { d as defineCustomElement$6 } from './sc-menu2.js';
import { d as defineCustomElement$5 } from './sc-menu-item2.js';
import { d as defineCustomElement$4 } from './sc-menu-label2.js';
import { d as defineCustomElement$3 } from './sc-select2.js';
import { d as defineCustomElement$2 } from './sc-spinner2.js';
import { d as defineCustomElement$1 } from './sc-visually-hidden2.js';

const scOrderShippingAddressCss = ":host{display:block}.sc-order-shipping__loading{display:flex;flex-direction:column;gap:0.5em}";

const ScOrderShippingAddress = /*@__PURE__*/ proxyCustomElement(class ScOrderShippingAddress extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.label = undefined;
    this.required = false;
    this.full = undefined;
    this.showName = undefined;
    this.namePlaceholder = __('Name or Company Name', 'surecart');
    this.countryPlaceholder = __('Country', 'surecart');
    this.cityPlaceholder = __('City', 'surecart');
    this.line1Placeholder = __('Address', 'surecart');
    this.line2Placeholder = __('Address Line 2', 'surecart');
    this.postalCodePlaceholder = __('Postal Code/Zip', 'surecart');
    this.statePlaceholder = __('State/Province/Region', 'surecart');
    this.defaultCountry = undefined;
    this.requireName = false;
    this.placeholders = {
      name: __('Name or Company Name', 'surecart'),
      country: __('Country', 'surecart'),
      city: __('City', 'surecart'),
      line_1: __('Address', 'surecart'),
      line_2: __('Address Line 2', 'surecart'),
      postal_code: __('Postal Code/Zip', 'surecart'),
      state: __('State/Province/Region', 'surecart'),
    };
    this.address = {
      country: null,
      city: null,
      line_1: null,
      line_2: null,
      postal_code: null,
      state: null,
    };
  }
  async updateAddressState(address) {
    if (JSON.stringify(address) === JSON.stringify(this.address))
      return; // no change, don't update.
    this.address = address;
    try {
      lockCheckout('shipping-address');
      state.checkout = (await createOrUpdateCheckout({
        id: state.checkout.id,
        data: {
          shipping_address: this.address,
        },
      }));
    }
    catch (e) {
      console.error(e);
    }
    finally {
      unLockCheckout('shipping-address');
    }
  }
  async reportValidity() {
    var _a, _b;
    return (_b = (_a = this.input) === null || _a === void 0 ? void 0 : _a.reportValidity) === null || _b === void 0 ? void 0 : _b.call(_a);
  }
  componentWillLoad() {
    if (this.defaultCountry && !this.address.country) {
      this.address.country = this.defaultCountry;
    }
    onChange('checkout', () => {
      var _a;
      // check if address keys are empty, if so, update them.
      const addressKeys = Object.keys(this.address).filter(key => key !== 'country');
      const emptyAddressKeys = addressKeys.filter(key => !this.address[key]);
      if (emptyAddressKeys.length === addressKeys.length) {
        this.address = { ...this.address, ...(_a = state.checkout) === null || _a === void 0 ? void 0 : _a.shipping_address };
      }
    });
  }
  render() {
    // use full if checkout requires it, it's set, or we're showing/requiring name field.
    if (fullShippingAddressRequired() || this.full || this.requireName || this.showName) {
      return (h("sc-address", { exportparts: "label, help-text, form-control, input__base, select__base, columns, search__base, menu__base", ref: el => (this.input = el), label: this.label || __('Shipping Address', 'surecart'), placeholders: {
          name: this.namePlaceholder,
          country: this.countryPlaceholder,
          city: this.cityPlaceholder,
          line_1: this.line1Placeholder,
          line_2: this.line2Placeholder,
          postal_code: this.postalCodePlaceholder,
          state: this.statePlaceholder,
        }, required: this.required, loading: formLoading(), address: this.address, "show-name": this.showName, "require-name": this.requireName, onScChangeAddress: e => this.updateAddressState(e.detail) }));
    }
    return (h("sc-compact-address", { ref: el => (this.input = el), required: this.required, loading: formLoading(), address: this.address, placeholders: {
        name: this.namePlaceholder,
        country: this.countryPlaceholder,
        city: this.cityPlaceholder,
        line_1: this.line1Placeholder,
        line_2: this.line2Placeholder,
        postal_code: this.postalCodePlaceholder,
        state: this.statePlaceholder,
      }, label: this.label, onScChangeAddress: e => this.updateAddressState(e.detail) }));
  }
  static get style() { return scOrderShippingAddressCss; }
}, [1, "sc-order-shipping-address", {
    "label": [1],
    "required": [1540],
    "full": [1028],
    "showName": [516, "show-name"],
    "namePlaceholder": [1, "name-placeholder"],
    "countryPlaceholder": [1, "country-placeholder"],
    "cityPlaceholder": [1, "city-placeholder"],
    "line1Placeholder": [1, "line-1-placeholder"],
    "line2Placeholder": [1, "line-2-placeholder"],
    "postalCodePlaceholder": [1, "postal-code-placeholder"],
    "statePlaceholder": [1, "state-placeholder"],
    "defaultCountry": [1, "default-country"],
    "requireName": [516, "require-name"],
    "placeholders": [16],
    "address": [32],
    "reportValidity": [64]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-order-shipping-address", "sc-address", "sc-block-ui", "sc-compact-address", "sc-dropdown", "sc-form-control", "sc-icon", "sc-input", "sc-menu", "sc-menu-item", "sc-menu-label", "sc-select", "sc-spinner", "sc-visually-hidden"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-order-shipping-address":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScOrderShippingAddress);
      }
      break;
    case "sc-address":
      if (!customElements.get(tagName)) {
        defineCustomElement$d();
      }
      break;
    case "sc-block-ui":
      if (!customElements.get(tagName)) {
        defineCustomElement$c();
      }
      break;
    case "sc-compact-address":
      if (!customElements.get(tagName)) {
        defineCustomElement$b();
      }
      break;
    case "sc-dropdown":
      if (!customElements.get(tagName)) {
        defineCustomElement$a();
      }
      break;
    case "sc-form-control":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "sc-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "sc-menu":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-menu-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-menu-label":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-select":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "sc-visually-hidden":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ScOrderShippingAddress as S, defineCustomElement as d };

//# sourceMappingURL=sc-order-shipping-address2.js.map