import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { l as loadScript, g as getScriptLoadParams } from './functions.js';
import { _ as __ } from './default-i18n.js';
import { a as apiFetch } from './fetch.js';
import { d as defineCustomElement$3 } from './sc-alert2.js';
import { d as defineCustomElement$2 } from './sc-icon2.js';

const scPaypalAddMethodCss = ":host{display:block}.paypal-buttons{position:relative;line-height:0;text-align:center}.paypal-buttons:after{content:\" \";border-bottom:1px solid var(--sc-input-border-color);width:100%;height:0;top:50%;left:0;right:0;position:absolute}";

const ScPaypalAddMethod$1 = /*@__PURE__*/ proxyCustomElement(class ScPaypalAddMethod extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.liveMode = true;
    this.customerId = undefined;
    this.successUrl = undefined;
    this.currency = undefined;
    this.loading = undefined;
    this.loaded = undefined;
    this.error = undefined;
    this.paymentIntent = undefined;
  }
  componentWillLoad() {
    this.createPaymentIntent();
  }
  async handlePaymentIntentCreate() {
    var _a, _b;
    const { external_intent_id } = this.paymentIntent || {};
    const { client_id, account_id, merchant_initiated } = ((_b = (_a = this.paymentIntent) === null || _a === void 0 ? void 0 : _a.processor_data) === null || _b === void 0 ? void 0 : _b.paypal) || {};
    // we need this data.
    if (!client_id || !account_id || !external_intent_id)
      return;
    // check if stripe has been initialized
    if (!this.paypal) {
      try {
        this.paypal = await loadScript(getScriptLoadParams({
          clientId: client_id,
          merchantId: account_id,
          merchantInitiated: merchant_initiated,
          reusable: true,
        }));
        this.paypal
          .Buttons({
          onInit: () => {
            this.loaded = true;
          },
          createBillingAgreement: () => {
            return new Promise(resolve => resolve(external_intent_id));
          },
          onApprove: async () => {
            var _a;
            try {
              this.loading = true;
              const intent = (await apiFetch({
                method: 'PATCH',
                path: `surecart/v1/payment_intents/${(_a = this.paymentIntent) === null || _a === void 0 ? void 0 : _a.id}/capture`,
              }));
              if (['succeeded', 'pending', 'requires_approval'].includes(intent === null || intent === void 0 ? void 0 : intent.status)) {
                window.location.assign(this.successUrl);
              }
              else {
                throw { message: __('The payment did not process. Please try again.', 'surecart') };
              }
            }
            catch (err) {
              console.error(err);
              this.error = (err === null || err === void 0 ? void 0 : err.message) || __('The payment did not process. Please try again.', 'surecart');
              this.loading = false;
            }
          },
          onError: err => {
            console.error(err);
            alert((err === null || err === void 0 ? void 0 : err.message) || __('The payment did not process. Please try again.', 'surecart'));
          },
        })
          .render(this.container);
      }
      catch (err) {
        console.error('Failed to load the PayPal JS SDK script', err);
        this.error = __('Failed to load the PayPal JS SDK script', 'surecart');
      }
    }
  }
  async createPaymentIntent() {
    var _a, _b;
    try {
      this.loading = true;
      this.error = '';
      this.paymentIntent = await apiFetch({
        method: 'POST',
        path: 'surecart/v1/payment_intents',
        data: {
          processor_type: 'paypal',
          reusable: true,
          live_mode: this.liveMode,
          customer_id: this.customerId,
          currency: this.currency,
          refresh_status: true,
        },
      });
    }
    catch (e) {
      this.error = ((_b = (_a = e === null || e === void 0 ? void 0 : e.additional_errors) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.message) || (e === null || e === void 0 ? void 0 : e.message) || __('Something went wrong', 'surecart');
    }
    finally {
      this.loading = false;
    }
  }
  render() {
    return (h(Host, null, this.error && (h("sc-alert", { open: !!this.error, type: "danger" }, h("span", { slot: "title" }, __('Error', 'surecart')), this.error)), h("div", { class: "sc-paypal-button-container", hidden: !this.loaded, ref: el => (this.container = el) })));
  }
  static get watchers() { return {
    "paymentIntent": ["handlePaymentIntentCreate"]
  }; }
  static get style() { return scPaypalAddMethodCss; }
}, [0, "sc-paypal-add-method", {
    "liveMode": [4, "live-mode"],
    "customerId": [1, "customer-id"],
    "successUrl": [1, "success-url"],
    "currency": [1],
    "loading": [32],
    "loaded": [32],
    "error": [32],
    "paymentIntent": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-paypal-add-method", "sc-alert", "sc-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-paypal-add-method":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScPaypalAddMethod$1);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const ScPaypalAddMethod = ScPaypalAddMethod$1;
const defineCustomElement = defineCustomElement$1;

export { ScPaypalAddMethod, defineCustomElement };

//# sourceMappingURL=sc-paypal-add-method.js.map