import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { s as sprintf, _ as __ } from './default-i18n.js';
import { s as se } from './inline.js';
import { a as apiFetch } from './fetch.js';
import { d as defineCustomElement$5 } from './sc-alert2.js';
import { d as defineCustomElement$4 } from './sc-button2.js';
import { d as defineCustomElement$3 } from './sc-icon2.js';
import { d as defineCustomElement$2 } from './sc-spinner2.js';

const scPaystackAddMethodCss = ":host{display:block}";

const ScPaystackAddMethod$1 = /*@__PURE__*/ proxyCustomElement(class ScPaystackAddMethod extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.liveMode = true;
    this.customerId = undefined;
    this.successUrl = undefined;
    this.currency = undefined;
    this.loading = undefined;
    this.loaded = undefined;
    this.error = undefined;
    this.paymentIntent = undefined;
  }
  async handlePaymentIntentCreate() {
    var _a, _b;
    const { public_key, access_code } = ((_b = (_a = this.paymentIntent) === null || _a === void 0 ? void 0 : _a.processor_data) === null || _b === void 0 ? void 0 : _b.paystack) || {};
    // we need this data.
    if (!public_key || !access_code)
      return;
    const paystack = new se();
    await paystack.newTransaction({
      key: public_key,
      accessCode: access_code,
      onSuccess: async (transaction) => {
        if ((transaction === null || transaction === void 0 ? void 0 : transaction.status) !== 'success') {
          throw { message: sprintf(__('Paystack transaction could not be finished. Status: %s', 'surecart'), transaction === null || transaction === void 0 ? void 0 : transaction.status) };
        }
        window.location.assign(this.successUrl);
      },
      onClose: err => {
        console.error(err);
        alert((err === null || err === void 0 ? void 0 : err.message) || __('The payment did not process. Please try again.', 'surecart'));
      },
    });
  }
  async createPaymentIntent() {
    var _a, _b;
    try {
      this.loading = true;
      this.error = '';
      this.paymentIntent = await apiFetch({
        method: 'POST',
        path: 'surecart/v1/payment_intents',
        data: {
          processor_type: 'paystack',
          reusable: true,
          live_mode: this.liveMode,
          customer_id: this.customerId,
          currency: this.currency,
          refresh_status: true,
        },
      });
    }
    catch (e) {
      this.error = ((_b = (_a = e === null || e === void 0 ? void 0 : e.additional_errors) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b.message) || (e === null || e === void 0 ? void 0 : e.message) || __('Something went wrong', 'surecart');
    }
    finally {
      this.loading = false;
    }
  }
  render() {
    return (h(Host, null, this.error && (h("sc-alert", { open: !!this.error, type: "danger" }, h("span", { slot: "title" }, __('Error', 'surecart')), this.error)), h("div", { class: "sc-paystack-button-container" }, h("sc-alert", { open: true, type: "warning" }, __('In order to add a new card, we will need to make a small transaction to authenticate it. This is for authentication purposes and will be immediately refunded.', 'surecart'), h("div", null, h("sc-button", { loading: this.loading, type: "primary", onClick: () => this.createPaymentIntent(), style: { marginTop: 'var(--sc-spacing-medium)' } }, __('Add New Card', 'surecart')))))));
  }
  static get watchers() { return {
    "paymentIntent": ["handlePaymentIntentCreate"]
  }; }
  static get style() { return scPaystackAddMethodCss; }
}, [0, "sc-paystack-add-method", {
    "liveMode": [4, "live-mode"],
    "customerId": [1, "customer-id"],
    "successUrl": [1, "success-url"],
    "currency": [1],
    "loading": [32],
    "loaded": [32],
    "error": [32],
    "paymentIntent": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-paystack-add-method", "sc-alert", "sc-button", "sc-icon", "sc-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-paystack-add-method":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScPaystackAddMethod$1);
      }
      break;
    case "sc-alert":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const ScPaystackAddMethod = ScPaystackAddMethod$1;
const defineCustomElement = defineCustomElement$1;

export { ScPaystackAddMethod, defineCustomElement };

//# sourceMappingURL=sc-paystack-add-method.js.map