import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { c as getCurrencySymbol } from './price.js';
import { F as FormSubmitController } from './form-data.js';
import { m as maybeConvertAmount, i as isZeroDecimal } from './currency.js';
import { s as sprintf, _ as __ } from './default-i18n.js';
import { d as defineCustomElement$3 } from './sc-form-control2.js';
import { d as defineCustomElement$2 } from './sc-input2.js';
import { d as defineCustomElement$1 } from './sc-visually-hidden2.js';

const scPriceInputCss = ":host{display:block}";

const ScPriceInput = /*@__PURE__*/ proxyCustomElement(class ScPriceInput extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.scChange = createEvent(this, "scChange", 7);
    this.scInput = createEvent(this, "scInput", 7);
    this.scFocus = createEvent(this, "scFocus", 7);
    this.scBlur = createEvent(this, "scBlur", 7);
    this.size = 'medium';
    this.name = undefined;
    this.value = '';
    this.pill = false;
    this.label = undefined;
    this.showLabel = true;
    this.help = '';
    this.clearable = false;
    this.placeholder = undefined;
    this.disabled = false;
    this.readonly = false;
    this.minlength = undefined;
    this.maxlength = undefined;
    this.max = undefined;
    this.min = undefined;
    this.required = false;
    this.invalid = false;
    this.autofocus = undefined;
    this.hasFocus = undefined;
    this.currencyCode = undefined;
    this.showCode = undefined;
  }
  async reportValidity() {
    const input = this.input.shadowRoot.querySelector('input');
    input.setCustomValidity('');
    if (this.min && this.value && parseFloat(this.value) < this.min) {
      this.invalid = true;
      input.setCustomValidity(sprintf(__('Must be %d or more.', 'surecart'), maybeConvertAmount(this.min, this.currencyCode).toString()));
    }
    if (this.max && this.value && parseFloat(this.value) > this.max) {
      this.invalid = true;
      input.setCustomValidity(sprintf(__('Must be %d or less.', 'surecart'), maybeConvertAmount(this.max, this.currencyCode).toString()));
    }
    return input.reportValidity();
  }
  /** Sets focus on the input. */
  async triggerFocus(options) {
    return this.input.triggerFocus(options);
  }
  /** Sets a custom validation message. If `message` is not empty, the field will be considered invalid. */
  async setCustomValidity(message) {
    this.input.setCustomValidity(message);
  }
  /** Removes focus from the input. */
  async triggerBlur() {
    return this.input.blur();
  }
  handleFocusChange() {
    var _a, _b, _c, _d;
    this.hasFocus ? (_b = (_a = this.input) === null || _a === void 0 ? void 0 : _a.focus) === null || _b === void 0 ? void 0 : _b.call(_a) : (_d = (_c = this.input) === null || _c === void 0 ? void 0 : _c.blur) === null || _d === void 0 ? void 0 : _d.call(_c);
  }
  handleChange() {
    this.updateValue();
    this.scChange.emit();
  }
  handleInput() {
    this.updateValue();
    this.scInput.emit();
  }
  updateValue() {
    // This fixes issues on mobile Safari where a decimal point is added to the end of the input value
    // does not have an input value.
    const parsed = parseFloat(this.input.value);
    if (isNaN(parsed)) {
      this.value = '';
      return;
    }
    const val = isZeroDecimal(this.currencyCode) ? parsed : (parsed * 100).toFixed(2);
    this.value = val.toString();
    this.setCustomValidity('');
  }
  componentDidLoad() {
    this.handleFocusChange();
    this.formController = new FormSubmitController(this.el).addFormData();
    document.addEventListener('wheel', () => {
      this.input.triggerBlur();
    });
  }
  disconnectedCallback() {
    var _a;
    (_a = this.formController) === null || _a === void 0 ? void 0 : _a.removeFormData();
  }
  getFormattedValue() {
    if (!this.value)
      return '';
    const parsedAmount = parseFloat(this.value);
    if (isNaN(parsedAmount))
      return '';
    return maybeConvertAmount(parsedAmount, this.currencyCode).toString();
  }
  render() {
    return (h("sc-input", { exportparts: "base, input, form-control, label, help-text, prefix, suffix", size: this.size, label: this.label, showLabel: this.showLabel, help: this.help, ref: el => (this.input = el), type: "text" // we cannot use number because it's basically the worst. https://stackoverflow.blog/2022/12/26/why-the-number-input-is-the-worst-input/
      ,
      name: this.name, disabled: this.disabled, readonly: this.readonly, required: this.required, placeholder: this.placeholder, minlength: this.minlength, maxlength: this.maxlength, min: !!this.min ? this.min / 100 : 0.0, step: 0.01, max: !!this.max ? this.max / 100 : null,
      // TODO: Test These below
      autofocus: this.autofocus, inputmode: 'decimal', onScChange: () => this.handleChange(), onScInput: () => this.handleInput(), onScBlur: () => this.scBlur.emit(), onScFocus: () => this.scFocus.emit(), pattern: "^\\d*(\\.\\d{0,2})?$" // This prevents more than two decimal places
      ,
      value: this.getFormattedValue() }, h("span", { style: { opacity: '0.5' }, slot: "prefix" }, getCurrencySymbol(this.currencyCode)), h("span", { slot: "suffix" }, h("slot", { name: "suffix" }, this.showCode && (this === null || this === void 0 ? void 0 : this.currencyCode) && h("span", { style: { opacity: '0.5' } }, this.currencyCode.toUpperCase())))));
  }
  get el() { return this; }
  static get watchers() { return {
    "hasFocus": ["handleFocusChange"]
  }; }
  static get style() { return scPriceInputCss; }
}, [1, "sc-price-input", {
    "size": [513],
    "name": [1],
    "value": [1025],
    "pill": [516],
    "label": [1],
    "showLabel": [4, "show-label"],
    "help": [1],
    "clearable": [4],
    "placeholder": [1],
    "disabled": [516],
    "readonly": [516],
    "minlength": [2],
    "maxlength": [2],
    "max": [514],
    "min": [514],
    "required": [516],
    "invalid": [1540],
    "autofocus": [4],
    "hasFocus": [1540, "has-focus"],
    "currencyCode": [513, "currency-code"],
    "showCode": [4, "show-code"],
    "reportValidity": [64],
    "triggerFocus": [64],
    "setCustomValidity": [64],
    "triggerBlur": [64]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-price-input", "sc-form-control", "sc-input", "sc-visually-hidden"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-price-input":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScPriceInput);
      }
      break;
    case "sc-form-control":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-input":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "sc-visually-hidden":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ScPriceInput as S, defineCustomElement as d };

//# sourceMappingURL=sc-price-input2.js.map