import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { _ as __ } from './default-i18n.js';
import { d as defineCustomElement$2 } from './sc-format-number2.js';
import { d as defineCustomElement$1 } from './sc-visually-hidden2.js';

const scPriceRangeCss = ":host{display:block;line-height:1}";

const ScPriceRange = /*@__PURE__*/ proxyCustomElement(class ScPriceRange extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.prices = undefined;
    this.minPrice = undefined;
    this.maxPrice = undefined;
  }
  handlePricesChange() {
    let min, max;
    (this.prices || [])
      .filter(p => !(p === null || p === void 0 ? void 0 : p.archived))
      .forEach(price => {
      if (!max || price.amount > max.amount) {
        max = price;
      }
      if (!min || price.amount < min.amount) {
        min = price;
      }
    });
    this.minPrice = min;
    this.maxPrice = max;
  }
  componentWillLoad() {
    this.handlePricesChange();
  }
  render() {
    if (!this.maxPrice || !this.minPrice) {
      return h(Host, null);
    }
    return (h(Host, null, this.maxPrice.amount == this.minPrice.amount ? (h("span", null, h("sc-format-number", { type: "currency", currency: this.maxPrice.currency, value: this.maxPrice.amount }))) : (h("span", null, h("sc-visually-hidden", null, __('Price range from', 'surecart'), " "), h("sc-format-number", { type: "currency", currency: this.minPrice.currency, value: this.minPrice.amount }), h("span", { "aria-hidden": true }, ' — '), h("sc-visually-hidden", null, __('to', 'surecart')), h("sc-format-number", { type: "currency", currency: this.maxPrice.currency, value: this.maxPrice.amount })))));
  }
  static get watchers() { return {
    "prices": ["handlePricesChange"]
  }; }
  static get style() { return scPriceRangeCss; }
}, [1, "sc-price-range", {
    "prices": [16],
    "minPrice": [32],
    "maxPrice": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-price-range", "sc-format-number", "sc-visually-hidden"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-price-range":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScPriceRange);
      }
      break;
    case "sc-format-number":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "sc-visually-hidden":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ScPriceRange as S, defineCustomElement as d };

//# sourceMappingURL=sc-price-range2.js.map