import { proxyCustomElement, HTMLElement, h, Host, Fragment } from '@stencil/core/internal/client';
import { _ as __, s as sprintf, a as _n } from './default-i18n.js';
import { i as intervalString } from './price.js';
import { d as defineCustomElement$3 } from './sc-format-number2.js';
import { d as defineCustomElement$2 } from './sc-tag2.js';
import { d as defineCustomElement$1 } from './sc-visually-hidden2.js';

const scPriceCss = ":host{display:block}.price{display:inline-flex;flex-direction:column;gap:var(--sc-spacing-xxx-small);text-align:var(--sc-product-price-alignment, left);justify-content:var(--sc-product-price-alignment, left)}.price__amounts{display:inline-flex;flex-wrap:wrap;align-items:baseline;gap:var(--sc-spacing-xx-small);justify-content:var(--sc-product-price-alignment, left);text-align:var(--sc-product-price-alignment, left)}.price__scratch{text-decoration:line-through;opacity:0.75}.price__interval{font-size:min(var(--sc-font-size-small), 16px);opacity:0.75}.price__details{font-size:min(var(--sc-font-size-small), 16px);opacity:0.75}.price__sale-badge{font-size:min(1em, 14px);align-self:center}";

const ScProductPrice = /*@__PURE__*/ proxyCustomElement(class ScProductPrice extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.currency = undefined;
    this.amount = undefined;
    this.scratchAmount = undefined;
    this.saleText = undefined;
    this.adHoc = undefined;
    this.recurringPeriodCount = undefined;
    this.recurringIntervalCount = undefined;
    this.recurringInterval = undefined;
    this.setupFeeAmount = undefined;
    this.trialDurationDays = undefined;
    this.setupFeeName = undefined;
  }
  render() {
    if (this.adHoc) {
      return h(Host, { role: "paragraph" }, __('Custom Amount', 'surecart'));
    }
    return (h(Host, { role: "paragraph" }, h("div", { class: "price", id: "price" }, h("div", { class: "price__amounts" }, !!this.scratchAmount && this.scratchAmount !== this.amount && (h(Fragment, null, this.scratchAmount === 0 ? (__('Free', 'surecart')) : (h(Fragment, null, h("sc-visually-hidden", null, __('The price was', 'surecart'), " "), h("sc-format-number", { class: "price__scratch", part: "price__scratch", type: "currency", currency: this.currency, value: this.scratchAmount }), h("sc-visually-hidden", null, " ", __('now discounted to', 'surecart')))))), this.amount === 0 ? __('Free', 'surecart') : h("sc-format-number", { class: "price__amount", type: "currency", value: this.amount, currency: this.currency }), h("div", { class: "price__interval" }, this.recurringPeriodCount && 1 < this.recurringPeriodCount && (h("sc-visually-hidden", null, ' ', __('This is a repeating price. Payment will happen', 'surecart'), ' ', intervalString({
      recurring_interval_count: this.recurringIntervalCount,
      recurring_interval: this.recurringInterval,
      recurring_period_count: this.recurringPeriodCount,
    }, {
      showOnce: true,
      abbreviate: false,
      labels: {
        interval: __('every', 'surecart'),
        period: 
        /** translators: used as in time period: "for 3 months" */
        __('for', 'surecart'),
      },
    }))), h("span", { "aria-hidden": "true" }, intervalString({
      recurring_interval_count: this.recurringIntervalCount,
      recurring_interval: this.recurringInterval,
      recurring_period_count: this.recurringPeriodCount,
    }, {
      showOnce: true,
      abbreviate: false,
      labels: {
        interval: '/',
        period: 
        /** translators: used as in time period: "for 3 months" */
        __('for', 'surecart'),
      },
    }))), !!this.scratchAmount && (h("sc-tag", { type: "primary", pill: true, class: "price__sale-badge" }, this.saleText || (h(Fragment, null, h("sc-visually-hidden", null, __('This product is available for sale.', 'surecart'), " "), h("span", { "aria-hidden": "true" }, __('Sale', 'surecart'))))))), (!!(this === null || this === void 0 ? void 0 : this.trialDurationDays) || !!(this === null || this === void 0 ? void 0 : this.setupFeeAmount)) && (h("div", { class: "price__details" }, !!(this === null || this === void 0 ? void 0 : this.trialDurationDays) && (h(Fragment, null, h("sc-visually-hidden", null, sprintf(__('You have a %d-day trial before payment becomes necessary.', 'surecart'), this === null || this === void 0 ? void 0 : this.trialDurationDays)), h("span", { class: "price__trial", "aria-hidden": "true" }, sprintf(_n('Starting in %s day.', 'Starting in %s days.', this === null || this === void 0 ? void 0 : this.trialDurationDays, 'surecart'), this === null || this === void 0 ? void 0 : this.trialDurationDays)))), !!(this === null || this === void 0 ? void 0 : this.setupFeeAmount) && (h("span", { class: "price__setup-fee" }, h("sc-visually-hidden", null, __('This product has', 'surecart'), " "), ' ', h("sc-format-number", { type: "currency", value: this === null || this === void 0 ? void 0 : this.setupFeeAmount, currency: this.currency }), " ", (this === null || this === void 0 ? void 0 : this.setupFeeName) || __('Setup Fee', 'surecart'), ".")))))));
  }
  static get style() { return scPriceCss; }
}, [1, "sc-price", {
    "currency": [1],
    "amount": [2],
    "scratchAmount": [2, "scratch-amount"],
    "saleText": [1, "sale-text"],
    "adHoc": [4, "ad-hoc"],
    "recurringPeriodCount": [2, "recurring-period-count"],
    "recurringIntervalCount": [2, "recurring-interval-count"],
    "recurringInterval": [1, "recurring-interval"],
    "setupFeeAmount": [2, "setup-fee-amount"],
    "trialDurationDays": [2, "trial-duration-days"],
    "setupFeeName": [1, "setup-fee-name"]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-price", "sc-format-number", "sc-tag", "sc-visually-hidden"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-price":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScProductPrice);
      }
      break;
    case "sc-format-number":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-tag":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "sc-visually-hidden":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ScProductPrice as S, defineCustomElement as d };

//# sourceMappingURL=sc-price2.js.map