import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { d as defineCustomElement$3 } from './sc-format-number2.js';
import { d as defineCustomElement$2 } from './sc-price-range2.js';
import { d as defineCustomElement$1 } from './sc-visually-hidden2.js';

const scProductItemPriceCss = ":host{display:block;line-height:1}.product-price{padding-top:var(--sc-product-price-padding-top, 0);padding-bottom:var(--sc-product-price-padding-bottom, 0);padding-left:var(--sc-product-price-padding-left, 0);padding-right:var(--sc-product-price-padding-right, 0);margin-top:var(--sc-product-price-margin-top, 0);margin-bottom:var(--sc-product-price-margin-bottom, 0);margin-left:var(--sc-product-price-margin-left, 0);margin-right:var(--sc-product-price-margin-right, 0);text-align:var(--sc-product-price-align);font-size:var(--sc-product-price-font-size);font-weight:var(--sc-product-price-font-weight);color:var(--sc-product-price-text-color)}";

const ScProductItemPrice = /*@__PURE__*/ proxyCustomElement(class ScProductItemPrice extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.prices = undefined;
    this.range = true;
    this.metrics = undefined;
  }
  componentWillLoad() {
    var _a, _b, _c, _d, _e, _f;
    // If min-max price is different, then generate a price range.
    if (this.range && ((_a = this.metrics) === null || _a === void 0 ? void 0 : _a.min_price_amount) !== ((_b = this.metrics) === null || _b === void 0 ? void 0 : _b.max_price_amount)) {
      this.prices = [
        {
          amount: (_c = this.metrics) === null || _c === void 0 ? void 0 : _c.min_price_amount,
          currency: (_d = this.metrics) === null || _d === void 0 ? void 0 : _d.currency,
        },
        {
          amount: (_e = this.metrics) === null || _e === void 0 ? void 0 : _e.max_price_amount,
          currency: (_f = this.metrics) === null || _f === void 0 ? void 0 : _f.currency,
        },
      ];
    }
  }
  render() {
    var _a;
    const price = (this.prices || []).sort((a, b) => (a === null || a === void 0 ? void 0 : a.position) - (b === null || b === void 0 ? void 0 : b.position)).find(price => !(price === null || price === void 0 ? void 0 : price.archived));
    return (h("div", { class: "product-price", part: "base" }, !this.range && ((_a = this.prices) === null || _a === void 0 ? void 0 : _a.length) ? (h("sc-format-number", { type: "currency", currency: (price === null || price === void 0 ? void 0 : price.currency) || 'usd', value: price === null || price === void 0 ? void 0 : price.amount })) : (h("sc-price-range", { prices: this.prices }))));
  }
  static get style() { return scProductItemPriceCss; }
}, [1, "sc-product-item-price", {
    "prices": [16],
    "range": [4],
    "metrics": [16]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-product-item-price", "sc-format-number", "sc-price-range", "sc-visually-hidden"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-product-item-price":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScProductItemPrice);
      }
      break;
    case "sc-format-number":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-price-range":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "sc-visually-hidden":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { ScProductItemPrice as S, defineCustomElement as d };

//# sourceMappingURL=sc-product-item-price2.js.map