import { proxyCustomElement, HTMLElement, h, Fragment, Host } from '@stencil/core/internal/client';
import { _ as __ } from './default-i18n.js';
import { i as intervalString } from './price.js';
import { j as availablePrices, s as state, b as setProduct } from './watchers.js';
import { d as defineCustomElement$8 } from './sc-choice-container2.js';
import { d as defineCustomElement$7 } from './sc-choices2.js';
import { d as defineCustomElement$6 } from './sc-form-control2.js';
import { d as defineCustomElement$5 } from './sc-format-number2.js';
import { d as defineCustomElement$4 } from './sc-price-choice-container2.js';
import { d as defineCustomElement$3 } from './sc-skeleton2.js';
import { d as defineCustomElement$2 } from './sc-visually-hidden2.js';

const scProductPriceChoicesCss = ":host{display:block;text-align:left;position:relative;z-index:1}";

const ScProductPriceChoices$1 = /*@__PURE__*/ proxyCustomElement(class ScProductPriceChoices extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.label = undefined;
    this.showPrice = undefined;
    this.productId = undefined;
  }
  renderPrice(price) {
    return (h(Fragment, null, h("sc-format-number", { type: "currency", value: price.amount, currency: price.currency }), h("span", { slot: "per" }, intervalString(price, {
      labels: {
        interval: __('Every', 'surecart'),
        period: __('for', 'surecart'),
        once: __('Once', 'surecart'),
      },
      showOnce: true,
    }))));
  }
  render() {
    const prices = availablePrices(this.productId);
    if ((prices === null || prices === void 0 ? void 0 : prices.length) < 2)
      return h(Host, { style: { display: 'none' } });
    return (h("sc-choices", { label: this.label, required: true, style: { '--sc-input-required-indicator': ' ' } }, (prices || []).map(price => {
      var _a, _b, _c, _d;
      return (h("sc-price-choice-container", { label: (price === null || price === void 0 ? void 0 : price.name) || ((_b = (_a = state[this.productId]) === null || _a === void 0 ? void 0 : _a.product) === null || _b === void 0 ? void 0 : _b.name), showPrice: !!this.showPrice, price: price, checked: ((_d = (_c = state[this.productId]) === null || _c === void 0 ? void 0 : _c.selectedPrice) === null || _d === void 0 ? void 0 : _d.id) === (price === null || price === void 0 ? void 0 : price.id), onScChange: e => {
          if (e.target.checked) {
            setProduct(this.productId, { selectedPrice: price });
          }
        } }));
    })));
  }
  static get style() { return scProductPriceChoicesCss; }
}, [1, "sc-product-price-choices", {
    "label": [1],
    "showPrice": [4, "show-price"],
    "productId": [1, "product-id"]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-product-price-choices", "sc-choice-container", "sc-choices", "sc-form-control", "sc-format-number", "sc-price-choice-container", "sc-skeleton", "sc-visually-hidden"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-product-price-choices":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScProductPriceChoices$1);
      }
      break;
    case "sc-choice-container":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "sc-choices":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "sc-form-control":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-format-number":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-price-choice-container":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-skeleton":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-visually-hidden":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const ScProductPriceChoices = ScProductPriceChoices$1;
const defineCustomElement = defineCustomElement$1;

export { ScProductPriceChoices, defineCustomElement };

//# sourceMappingURL=sc-product-price-choices.js.map