import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { s as state } from './watchers.js';
import { a as getDiscountedAmount, b as getScratchAmount } from './getters.js';
import { d as defineCustomElement$6 } from './sc-format-number2.js';
import { d as defineCustomElement$5 } from './sc-price2.js';
import { d as defineCustomElement$4 } from './sc-price-range2.js';
import { d as defineCustomElement$3 } from './sc-tag2.js';
import { d as defineCustomElement$2 } from './sc-visually-hidden2.js';

const scProductPriceCss = ":host{display:block}";

const ScProductPrice$1 = /*@__PURE__*/ proxyCustomElement(class ScProductPrice extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.prices = undefined;
    this.saleText = undefined;
    this.productId = undefined;
  }
  renderRange() {
    var _a, _b, _c, _d;
    if (((_b = (_a = state[this.productId]) === null || _a === void 0 ? void 0 : _a.prices) === null || _b === void 0 ? void 0 : _b.length) === 1) {
      return this.renderPrice((_c = state[this.productId]) === null || _c === void 0 ? void 0 : _c.prices[0]);
    }
    return h("sc-price-range", { prices: (_d = state[this.productId]) === null || _d === void 0 ? void 0 : _d.prices });
  }
  renderVariantPrice(selectedVariant) {
    var _a, _b;
    const variant = (_b = (_a = state[this.productId]) === null || _a === void 0 ? void 0 : _a.variants) === null || _b === void 0 ? void 0 : _b.find(variant => (variant === null || variant === void 0 ? void 0 : variant.id) === (selectedVariant === null || selectedVariant === void 0 ? void 0 : selectedVariant.id));
    return this.renderPrice(state[this.productId].selectedPrice, variant === null || variant === void 0 ? void 0 : variant.amount);
  }
  renderPrice(price, variantAmount) {
    var _a;
    const originalAmount = (_a = variantAmount !== null && variantAmount !== void 0 ? variantAmount : price === null || price === void 0 ? void 0 : price.amount) !== null && _a !== void 0 ? _a : 0;
    const amount = getDiscountedAmount(originalAmount);
    const scratch_amount = getScratchAmount(price === null || price === void 0 ? void 0 : price.scratch_amount);
    return (h("sc-price", { currency: price === null || price === void 0 ? void 0 : price.currency, amount: amount, scratchAmount: scratch_amount, saleText: this.saleText, adHoc: price === null || price === void 0 ? void 0 : price.ad_hoc, trialDurationDays: price === null || price === void 0 ? void 0 : price.trial_duration_days, setupFeeAmount: (price === null || price === void 0 ? void 0 : price.setup_fee_enabled) ? price === null || price === void 0 ? void 0 : price.setup_fee_amount : null, setupFeeName: (price === null || price === void 0 ? void 0 : price.setup_fee_enabled) ? price === null || price === void 0 ? void 0 : price.setup_fee_name : null, recurringPeriodCount: price === null || price === void 0 ? void 0 : price.recurring_period_count, recurringInterval: price === null || price === void 0 ? void 0 : price.recurring_interval, recurringIntervalCount: price === null || price === void 0 ? void 0 : price.recurring_interval_count }));
  }
  render() {
    return (h(Host, { role: "paragraph" }, (() => {
      var _a, _b, _c, _d, _e;
      if ((_a = state[this.productId]) === null || _a === void 0 ? void 0 : _a.selectedVariant) {
        return this.renderVariantPrice((_b = state[this.productId]) === null || _b === void 0 ? void 0 : _b.selectedVariant);
      }
      if ((_c = state[this.productId]) === null || _c === void 0 ? void 0 : _c.selectedPrice) {
        return this.renderPrice(state[this.productId].selectedPrice);
      }
      if ((_e = (_d = state[this.productId]) === null || _d === void 0 ? void 0 : _d.prices) === null || _e === void 0 ? void 0 : _e.length) {
        return this.renderRange();
      }
      return h("slot", null);
    })()));
  }
  static get style() { return scProductPriceCss; }
}, [1, "sc-product-price", {
    "prices": [16],
    "saleText": [1, "sale-text"],
    "productId": [1, "product-id"]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-product-price", "sc-format-number", "sc-price", "sc-price-range", "sc-tag", "sc-visually-hidden"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-product-price":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScProductPrice$1);
      }
      break;
    case "sc-format-number":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "sc-price":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "sc-price-range":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "sc-tag":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "sc-visually-hidden":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const ScProductPrice = ScProductPrice$1;
const defineCustomElement = defineCustomElement$1;

export { ScProductPrice, defineCustomElement };

//# sourceMappingURL=sc-product-price.js.map