import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { i as isRtl } from './page-align.js';

const scRadioGroupCss = ":host{display:block}.radio-group{border:none;padding:0;margin:0;min-width:0}.radio-group .radio-group__label{display:inline-block;padding:0;color:var(--sc-input-label-color);font-weight:var(--sc-input-label-font-weight);text-transform:var(--sc-input-label-text-transform, none);letter-spacing:var(--sc-input-label-letter-spacing, 0);margin-bottom:var(--sc-input-label-margin)}.radio-group__hidden-input{position:absolute;opacity:0;padding:0px;margin:0px;pointer-events:none}.radio-group--is-required .radio-group__label:after{content:\" *\";color:var(--sc-color-danger-500)}::slotted(sc-radio:not(:last-of-type)){display:block;margin-bottom:var(--sc-spacing-x-small)}.radio-group--is-rtl.radio-group,.radio-group--is-rtl.radio-group .radio-group__label{text-align:right}";

const ScRadioGroup = /*@__PURE__*/ proxyCustomElement(class ScRadioGroup extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.scChange = createEvent(this, "scChange", 7);
    this.label = '';
    this.invalid = undefined;
    this.value = '';
    this.required = undefined;
  }
  /** Checks for validity and shows the browser's validation message if the control is invalid. */
  async reportValidity() {
    this.invalid = !this.input.checkValidity();
    return this.input.reportValidity();
  }
  handleRadioClick(event) {
    if (event.target.tagName !== 'SC-RADIO')
      return;
    event.stopImmediatePropagation();
    const target = event.target;
    if (target.disabled) {
      return;
    }
    if (target.checked) {
      this.value = target.value;
      this.scChange.emit(target.value);
    }
  }
  componentDidLoad() {
    const choices = [...this.el.querySelectorAll('sc-radio')];
    choices.forEach(choice => {
      if (choice.checked) {
        this.value = choice.value;
      }
    });
  }
  render() {
    return (h("fieldset", { part: "base", class: {
        'radio-group': true,
        'radio-group--invalid': this.invalid,
        'radio-group--is-required': this.required,
        'radio-group--is-rtl': isRtl(),
      }, "aria-invalid": this.invalid, role: "radiogroup" }, h("legend", { part: "label", class: "radio-group__label" }, h("slot", { name: "label" }, this.label)), h("input", { type: "text", class: "radio-group__hidden-input", ref: el => (this.input = el), required: this.required, value: this.value, tabindex: "-1" }), h("div", { part: "items", class: "radio-group__items" }, h("slot", null))));
  }
  get el() { return this; }
  static get style() { return scRadioGroupCss; }
}, [1, "sc-radio-group", {
    "label": [1],
    "invalid": [1540],
    "value": [1537],
    "required": [4],
    "reportValidity": [64]
  }, [[0, "scChange", "handleRadioClick"]]]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["sc-radio-group"];
  components.forEach(tagName => { switch (tagName) {
    case "sc-radio-group":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, ScRadioGroup);
      }
      break;
  } });
}

export { ScRadioGroup as S, defineCustomElement as d };

//# sourceMappingURL=sc-radio-group2.js.map