import { s as state } from './store-77f83bce.js';

/**
 * Is it busy
 */
const isBusy = () => ['loading', 'busy', 'redirecting'].includes(state.loading);
/**
 * Get the exit url.
 */
const getExitUrl = () => { var _a, _b; return ((_b = (_a = state === null || state === void 0 ? void 0 : state.checkout) === null || _a === void 0 ? void 0 : _a.metadata) === null || _b === void 0 ? void 0 : _b.success_url) || state.success_url || null; };
/**
 * Get the discounted amount.
 */
const getDiscountedAmount = amount => { var _a, _b; return (_b = (_a = state === null || state === void 0 ? void 0 : state.line_item) === null || _a === void 0 ? void 0 : _a.total_amount) !== null && _b !== void 0 ? _b : amount; };
/**
 * Get the scratch amount.
 */
const getScratchAmount = amount => { var _a, _b, _c; return (!((_a = state === null || state === void 0 ? void 0 : state.line_item) === null || _a === void 0 ? void 0 : _a.total_savings_amount) ? amount : -((_b = state === null || state === void 0 ? void 0 : state.line_item) === null || _b === void 0 ? void 0 : _b.total_savings_amount) + ((_c = state === null || state === void 0 ? void 0 : state.line_item) === null || _c === void 0 ? void 0 : _c.total_amount)); };
/**
 * Get upsell remaining time.
 */
const getUpsellRemainingTime = (timeFormat = 'seconds') => {
  var _a;
  // Get upsell expiration timestamp from checkout.
  const expiresAt = (_a = state.checkout) === null || _a === void 0 ? void 0 : _a.upsells_expire_at; // in seconds
  // If no expiration timestamp, return 0.
  if (!expiresAt)
    return null;
  // Get current timestamp.
  const now = Date.now();
  // Get remaining time in seconds.
  const remaining = Math.floor((expiresAt * 1000 - now) / 1000);
  // If remaining time is less than 0, return 0.
  if (remaining < 0)
    return 0;
  // Check time format - seconds, minues, hours.
  if (timeFormat === 'seconds')
    return remaining;
  if (timeFormat === 'minutes')
    return Math.floor(remaining / 60);
  if (timeFormat === 'hours')
    return Math.floor(remaining / 60 / 60);
};
/**
 * Format time unit - add a zero if unit is less than 10.
 */
const formatTimeUnit = unit => (unit < 10 ? `0${unit}` : `${unit}`);
/**
 * Get formatted remaining time.
 */
const getFormattedRemainingTime = () => {
  var _a;
  // not loaded.
  if (!((_a = state.checkout) === null || _a === void 0 ? void 0 : _a.upsells_expire_at))
    return '--:--';
  const time = getUpsellRemainingTime('seconds');
  const days = Math.floor(time / (60 * 60 * 24));
  const hours = Math.floor((time % (60 * 60 * 24)) / (60 * 60));
  const minutes = Math.floor((time % (60 * 60)) / 60);
  const seconds = Math.floor(time % 60);
  if (days > 0) {
    return `${formatTimeUnit(days)}:${formatTimeUnit(hours)}:${formatTimeUnit(minutes)}:${formatTimeUnit(seconds)}`;
  }
  if (hours > 0) {
    return `${formatTimeUnit(hours)}:${formatTimeUnit(minutes)}:${formatTimeUnit(seconds)}`;
  }
  return `${formatTimeUnit(minutes)}:${formatTimeUnit(seconds)}`;
};
/**
 * Is upsell expired.
 */
const isUpsellExpired = () => {
  // Get remaining time in seconds.
  const remaining = getUpsellRemainingTime();
  // Make sure we wait until it's set.
  return getUpsellRemainingTime() === null ? false : remaining <= 0;
};

export { getDiscountedAmount as a, getScratchAmount as b, isBusy as c, getFormattedRemainingTime as d, getExitUrl as g, isUpsellExpired as i };

//# sourceMappingURL=getters-2e810784.js.map