import { _ as __ } from './default-i18n-62fa2f9c.js';
import { s as speak } from './index-5d62922a.js';
import { c as createStore } from './index-1046c77e.js';

const store = createStore({
  type: 'default',
  code: '',
  message: '',
  data: {
    status: 0,
    type: '',
    http_status: '',
  },
  additional_errors: [],
  dismissible: false,
}, (newValue, oldValue) => {
  return JSON.stringify(newValue) !== JSON.stringify(oldValue);
});
const { state, onChange, on, dispose, forceUpdate } = store;

/**
 * External dependencies.
 */
/**
 * Default notice options.
 */
const defaultOptions = {
  dismissible: false,
};
/**
 * Create a notice.
 *
 * @param {NoticeType} status
 * @param {ScNoticeStore} notice
 */
const createNotice = (status, notice, options = defaultOptions) => {
  // if notice is a string, then it is message, else the notice object.
  if (typeof notice === 'string') {
    notice = {
      type: status,
      message: notice,
      code: '',
    };
  }
  // If no notice message, then set the default message.
  if (!(notice === null || notice === void 0 ? void 0 : notice.message)) {
    notice.message = __('Something went wrong. Please try again.', 'surecart');
  }
  // Set the notice type.
  state.type = status;
  // Merge options and notice.
  notice = { ...options, ...notice };
  // speak the error notice.
  speak(notice.message, 'assertive');
  // Set notice properties to the state.
  Object.keys(notice).forEach(key => {
    state[key] = notice[key];
  });
};
/**
 * Create an error notice.
 *
 * @param {ScNoticeStore} notice
 * @param {object} options
 */
const createErrorNotice = (notice, options = defaultOptions) => {
  createNotice('error', notice, options);
};
/**
 * Create an info notice.
 *
 * @param {ScNoticeStore} notice
 * @param {object} options
 */
const createInfoNotice = (notice, options = defaultOptions) => {
  createNotice('info', notice, options);
};
/**
 * Remove the notice.
 */
const removeNotice = () => {
  state.type = 'default';
  state.code = '';
  state.message = '';
  state.data = {
    status: 0,
    type: '',
    http_status: '',
  };
  state.additional_errors = [];
};

export { createInfoNotice as a, createErrorNotice as c, removeNotice as r, state as s };

//# sourceMappingURL=mutations-7adc8e81.js.map