import { c as clearCheckout$1, s as state } from './mutations-375ca3f1.js';
import { u as updateFormState } from './mutations-2805d514.js';
import { c as createErrorNotice } from './mutations-7adc8e81.js';
import { u as updateLineItem, r as removeLineItem, a as addLineItem } from './index-b47940cd.js';

/**
 * Clear the current checkout.
 */
const clearCheckout = () => clearCheckout$1(state.formId, state.mode);
/**
 * Lock the checkout (disables input and submission)
 * Pass a lock name to prevent conflicts and allow multiple locks.
 */
const lockCheckout = lockName => (state.locks = [...state.locks, lockName]);
/**
 * Unlock the checkout.
 * Pass an optional lock name to only unlock a specific lock
 */
const unLockCheckout = (lockName = '') => (state.locks = !!lockName ? state.locks.filter(name => name !== lockName) : []);
/**
 * Update the checkout line item
 */
const updateCheckoutLineItem = async ({ id, data }) => {
  try {
    updateFormState('FETCH');
    state.checkout = await updateLineItem({
      id: id,
      data,
    });
    updateFormState('RESOLVE');
  }
  catch (e) {
    console.error(e);
    createErrorNotice(e);
    updateFormState('REJECT');
  }
};
/**
 * Remove the checkout line item.
 */
const removeCheckoutLineItem = async (id) => {
  try {
    updateFormState('FETCH');
    state.checkout = await removeLineItem({
      checkoutId: state.checkout.id,
      itemId: id,
    });
    updateFormState('RESOLVE');
  }
  catch (e) {
    console.error(e);
    createErrorNotice(e);
    updateFormState('REJECT');
  }
};
/**
 * Add the checkout line item.
 */
const addCheckoutLineItem = async (data) => {
  try {
    updateFormState('FETCH');
    state.checkout = await addLineItem({
      checkout: state.checkout,
      data,
      live_mode: (state === null || state === void 0 ? void 0 : state.mode) === 'live',
    });
    updateFormState('RESOLVE');
  }
  catch (e) {
    console.error(e);
    createErrorNotice(e);
    updateFormState('REJECT');
  }
};

export { addCheckoutLineItem as a, unLockCheckout as b, clearCheckout as c, lockCheckout as l, removeCheckoutLineItem as r, updateCheckoutLineItem as u };

//# sourceMappingURL=mutations-f4aa55bd.js.map