import { a as on } from './watchers-1fa5c294.js';
import { i as isUpsellExpired, g as getExitUrl } from './getters-2e810784.js';
import { p as preview } from './mutations-fdafb249.js';
import { s as state, o as onChange } from './store-77f83bce.js';
import { a as addQueryArgs } from './add-query-args-f4c5962b.js';

/**
 * Internal dependencies.
 */
/**
 * When line item changes, update totals.
 */
on('set', (_, newValue, oldValue) => {
  if (JSON.stringify(newValue === null || newValue === void 0 ? void 0 : newValue.line_item) !== JSON.stringify(oldValue === null || oldValue === void 0 ? void 0 : oldValue.line_item)) {
    preview();
  }
});
/**
 * Watch for upsell to expire every second.
 */
setInterval(() => {
  if (isUpsellExpired()) {
    state.loading = 'complete';
  }
}, 1000);
/**
 * Dynamically update amount_due when line_item changes.
 */
onChange('line_item', () => {
  var _a, _b, _c;
  state.amount_due = ((_a = state === null || state === void 0 ? void 0 : state.line_item) === null || _a === void 0 ? void 0 : _a.total_amount) + ((_c = (_b = state === null || state === void 0 ? void 0 : state.line_item) === null || _b === void 0 ? void 0 : _b.trial_amount) !== null && _c !== void 0 ? _c : 0);
});
/**
 * When the upsell changes, complete or redirect.
 */
onChange('upsell', val => {
  var _a;
  // completed.
  if (!(val === null || val === void 0 ? void 0 : val.permalink)) {
    return (state.loading = 'complete');
  }
  // redirect to next upsell.
  state.loading = 'redirecting';
  window.location.assign(addQueryArgs(val === null || val === void 0 ? void 0 : val.permalink, {
    sc_checkout_id: (_a = state.checkout) === null || _a === void 0 ? void 0 : _a.id,
    sc_form_id: state.form_id,
  }));
});
/**
 * When the loading state changes, redirect if complete.
 */
onChange('loading', val => {
  if (val === 'complete') {
    const nextLink = getExitUrl();
    if (!nextLink) {
      return (state.loading = 'complete');
    }
    state.loading = 'redirecting';
    window.location.assign(nextLink);
  }
});

//# sourceMappingURL=watchers-c10626c0.js.map